@@ -18,4 +18,7 @@ void misra_8_7_external(void);
 // cppcheck-suppress misra-c2012-2.5
 #define MISRA_2_5_VIOLATION 0
 
+// #12362
+extern void misra_8_7_compliant( void );
 
+#define MISRA_2_5_OK_3 This
\ No newline at end of file
