@@ -8,7 +8,7 @@ import sys
 import os
 
 from .util import dump_create, dump_remove, convert_json_output
-
+from addons.misra import C11_STDLIB_IDENTIFIERS, C99_STDLIB_IDENTIFIERS,C90_STDLIB_IDENTIFIERS, isStdLibId, isKeyword
 
 TEST_SOURCE_FILES = [os.path.join('addons','test','misra','misra-test.c')]
 
@@ -181,3 +181,64 @@ def test_platform(checker):
     dump_create(test_file, "--language=c")
     checker.parseDump(test_file + ".dump")
     assert checker.is_cpp is False
+
+def test_std99_identifiers():
+    for headerfile in C90_STDLIB_IDENTIFIERS:
+        for identifier in C90_STDLIB_IDENTIFIERS[headerfile]:
+            assert identifier in C99_STDLIB_IDENTIFIERS[headerfile], f"{identifier} of C90 not found in C99_STDLIB_IDENTIFIERS"
+
+def test_stdC11_identifiers():
+    for headerfile in C90_STDLIB_IDENTIFIERS:
+        for identifier in C90_STDLIB_IDENTIFIERS[headerfile]:
+            assert identifier in C99_STDLIB_IDENTIFIERS[headerfile], f"{identifier} of C90 not found in C11_STDLIB_IDENTIFIERS"
+    for headerfile in C99_STDLIB_IDENTIFIERS:
+        for identifier in C99_STDLIB_IDENTIFIERS[headerfile]:
+            assert identifier in C11_STDLIB_IDENTIFIERS[headerfile], f"{identifier} of C99 not found in C11_STDLIB_IDENTIFIERS"
+
+def test_isStdLibId():
+    # Check that Identifiers from C90 are correctly classified
+    assert isStdLibId("assert", 'c89') is True
+    assert isStdLibId("assert", 'c99') is True
+    assert isStdLibId("assert", 'c11') is True
+    assert isStdLibId("assert", 'c23') is True
+
+    # Check that Identifiers from C99 are correctly classified
+    assert isStdLibId("UINT32_C", 'c89') is False
+    assert isStdLibId("UINT32_C", 'c99') is True
+    assert isStdLibId("UINT32_C", 'c11') is True
+    assert isStdLibId("UINT32_C", 'c23') is True
+
+    # Check that Identifiers from C11 are correctly classified
+    assert isStdLibId("sprintf_s", 'c89') is False
+    assert isStdLibId("sprintf_s", 'c99') is False
+    assert isStdLibId("sprintf_s", 'c11') is True
+    assert isStdLibId("sprintf_s", 'c23') is True
+
+    # Function Defaulting to C99
+    assert isStdLibId("assert") is True
+    assert isStdLibId("UINT32_C") is True
+    assert isStdLibId("sprintf_s") is False
+
+def test_isKeyword():
+    # Check that Keywords from C90 are correctly classified
+    assert isKeyword("if", 'c89') is True
+    assert isKeyword("if", 'c99') is True
+    assert isKeyword("if", 'c11') is True
+    assert isKeyword("if", 'c23') is True
+
+    # Check that Keywords from C99 are correctly classified
+    assert isKeyword("inline", 'c89') is False
+    assert isKeyword("inline", 'c99') is True
+    assert isKeyword("inline", 'c11') is True
+    assert isKeyword("inline", 'c23') is True
+
+    # Check that Keywords from C11 are correctly classified
+    assert isKeyword("static_assert", 'c89') is False
+    assert isKeyword("static_assert", 'c99') is False
+    assert isKeyword("static_assert", 'c11') is True
+    assert isKeyword("static_assert", 'c23') is True
+
+    # Function Defaulting to C99
+    assert isKeyword("if") is True
+    assert isKeyword("inline") is True
+    assert isKeyword("static_assert") is False
