@@ -21,17 +21,14 @@ def find_cppcheck_binary():
 def dump_create(fpath, *argv):
     cppcheck_binary = find_cppcheck_binary()
     cmd = [cppcheck_binary, "--dump", "-DDUMMY", "--quiet", fpath] + list(argv)
-    p = subprocess.Popen(cmd)
-    p.communicate()
-    if p.returncode != 0:
-        raise OSError("cppcheck returns error code: %d" % p.returncode)
-    p = subprocess.Popen(["sync"])
-    p.communicate()
+    with subprocess.Popen(cmd) as p:
+        p.communicate()
+        if p.returncode != 0:
+            raise OSError("cppcheck returns error code: %d" % p.returncode)
 
 
 def dump_remove(fpath):
-    p = subprocess.Popen(["rm", "-f", fpath + ".dump"])
-    p.communicate()
+    os.remove(fpath + ".dump")
 
 
 def convert_json_output(raw_json_strings):
