@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2021 Cppcheck team.
+ * Copyright (C) 2007-2023 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,9 +18,11 @@
 
 #include "application.h"
 
-Application::Application(const QString &name, const QString &path,
-                         const QString &params)
-    : mName(name)
-    , mPath(path)
-    , mParameters(params)
+#include <utility>
+
+Application::Application(QString name, QString path,
+                         QString params)
+    : mName(std::move(name))
+    , mPath(std::move(path))
+    , mParameters(std::move(params))
 {}
