@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2024 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,10 +30,7 @@ CheckStatistics::CheckStatistics(QObject *parent)
 
 static void addItem(QMap<QString,unsigned> &m, const QString &key)
 {
-    if (m.contains(key))
-        m[key]++;
-    else
-        m[key] = 0;
+    m[key]++;
 }
 
 void CheckStatistics::addItem(const QString &tool, ShowTypes::ShowType type)
