@@ -25,7 +25,6 @@
 #include "errorlogger.h"
 #include "errortypes.h"
 #include "filesettings.h"
-#include "path.h"
 #include "settings.h"
 #include "standards.h"
 #include "threadresult.h"
@@ -90,7 +89,10 @@ int CheckThread::executeCommand(std::string exe, std::vector<std::string> args,
     }
 
     process.start(e, args2);
-    process.waitForFinished();
+    while (!Settings::terminated() && !process.waitForFinished(1000)) {
+        if (process.state() == QProcess::ProcessState::NotRunning)
+            break;
+    }
 
     if (redirect == "2>&1") {
         QString s1 = process.readAllStandardOutput();
@@ -118,7 +120,7 @@ void CheckThread::setSettings(const Settings &settings, std::shared_ptr<Suppress
     mSuppressions = std::move(supprs);
 }
 
-void CheckThread::analyseWholeProgram(const QStringList &files, const std::string& ctuInfo)
+void CheckThread::analyseWholeProgram(const std::list<FileWithDetails> &files, const std::string& ctuInfo)
 {
     mFiles = files;
     mAnalyseWholeProgram = true;
@@ -133,40 +135,39 @@ void CheckThread::run()
 
     CppCheck cppcheck(mSettings, *mSuppressions, mResult, true, executeCommand);
 
-    if (!mFiles.isEmpty() || mAnalyseWholeProgram) {
+    if (!mFiles.empty() || mAnalyseWholeProgram) {
         mAnalyseWholeProgram = false;
         std::string ctuInfo;
         ctuInfo.swap(mCtuInfo);
         qDebug() << "Whole program analysis";
-        std::list<FileWithDetails> files2;
-        std::transform(mFiles.cbegin(), mFiles.cend(), std::back_inserter(files2), [&](const QString& file) {
-            return FileWithDetails{file.toStdString(), Path::identify(file.toStdString(), mSettings.cppHeaderProbe), 0};
-        });
-        cppcheck.analyseWholeProgram(mSettings.buildDir, files2, {}, ctuInfo);
+        cppcheck.analyseWholeProgram(mSettings.buildDir, mFiles, {}, ctuInfo);
         mFiles.clear();
         emit done();
         return;
     }
 
-    QString file = mResult.getNextFile();
-    while (!file.isEmpty() && mState == Running) {
-        qDebug() << "Checking file" << file;
-        cppcheck.check(FileWithDetails(file.toStdString()));
-        runAddonsAndTools(mSettings, nullptr, file);
-        emit fileChecked(file);
+    // TODO: apply enforcedLanguage
+    const FileWithDetails* file = nullptr;
+    mResult.getNextFile(file);
+    while (file && mState == Running) {
+        const std::string& fname = file->spath();
+        qDebug() << "Checking file" << QString::fromStdString(fname);
+        cppcheck.check(*file);
+        runAddonsAndTools(mSettings, nullptr, QString::fromStdString(fname));
+        emit fileChecked(QString::fromStdString(fname));
 
         if (mState == Running)
-            file = mResult.getNextFile();
+            mResult.getNextFile(file);
     }
 
     const FileSettings* fileSettings = nullptr;
     mResult.getNextFileSettings(fileSettings);
     while (fileSettings && mState == Running) {
-        file = QString::fromStdString(fileSettings->filename());
-        qDebug() << "Checking file" << file;
+        const std::string& fname = fileSettings->filename();
+        qDebug() << "Checking file" << QString::fromStdString(fname);
         cppcheck.check(*fileSettings);
-        runAddonsAndTools(mSettings, fileSettings, QString::fromStdString(fileSettings->filename()));
-        emit fileChecked(file);
+        runAddonsAndTools(mSettings, fileSettings, QString::fromStdString(fname));
+        emit fileChecked(QString::fromStdString(fname));
 
         if (mState == Running)
             mResult.getNextFileSettings(fileSettings);
@@ -242,7 +243,7 @@ void CheckThread::runAddonsAndTools(const Settings& settings, const FileSettings
 
             const std::string &buildDir = settings.buildDir;
             if (!buildDir.empty()) {
-                analyzerInfoFile = QString::fromStdString(AnalyzerInformation::getAnalyzerInfoFile(buildDir, fileSettings->filename(), fileSettings->cfg));
+                analyzerInfoFile = QString::fromStdString(AnalyzerInformation::getAnalyzerInfoFile(buildDir, fileSettings->filename(), fileSettings->cfg, fileSettings->fileIndex));
 
                 QStringList args2(args);
                 args2.insert(0,"-E");
@@ -433,15 +434,15 @@ void CheckThread::parseClangErrors(const QString &tool, const QString &file0, QS
         const std::string f0 = file0.toStdString();
         const std::string msg = e.message.toStdString();
         const std::string id = e.errorId.toStdString();
-        ErrorMessage errmsg(callstack, f0, e.severity, msg, id, Certainty::normal);
+        ErrorMessage errmsg(std::move(callstack), f0, e.severity, msg, id, Certainty::normal);
         mResult.reportErr(errmsg);
     }
 }
 
 bool CheckThread::isSuppressed(const SuppressionList::ErrorMessage &errorMessage) const
 {
-    return std::any_of(mSuppressionsUi.cbegin(), mSuppressionsUi.cend(), [&](const SuppressionList::Suppression& s) {
-        return s.isSuppressed(errorMessage);
+    return std::any_of(mSuppressionsUi.cbegin(), mSuppressionsUi.cend(), [&](const SuppressionList::Suppression& s) -> bool {
+        return s.isSuppressed(errorMessage) == SuppressionList::Suppression::Result::Matched;
     });
 }
 
