@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2024 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -122,7 +122,7 @@ void ComplianceReportDialog::buttonClicked(QAbstractButton* button)
         break;
     default:
         break;
-    };
+    }
 }
 
 void ComplianceReportDialog::save()
@@ -197,7 +197,7 @@ void ComplianceReportDialog::save()
                 QCryptographicHash hash(QCryptographicHash::Algorithm::Md5);
                 if (hash.addData(&f)) {
                     for (auto b: hash.result())
-                        out << QString::number((unsigned char)b,16);
+                        out << QString::number(static_cast<unsigned char>(b),16);
                     out << " " << fileName << "\n";
                 }
             }
