@@ -1,6 +1,6 @@
-/*
+/* -*- C++ -*-
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ class ComplianceReportDialog final : public QDialog
     Q_OBJECT
 
 public:
-    explicit ComplianceReportDialog(ProjectFile* projectFile, QString resultsFile);
+    explicit ComplianceReportDialog(ProjectFile* projectFile, QString resultsFile, QString checkersReport);
     ~ComplianceReportDialog() final;
 
 private slots:
@@ -46,7 +46,8 @@ private:
 
     Ui::ComplianceReportDialog *mUI;
     ProjectFile* mProjectFile;
-    QString mResultsFile;
+    const QString mResultsFile;
+    const QString mCheckersReport;
 };
 
 #endif // COMPLIANCEREPORTDIALOG_H
