@@ -35,6 +35,7 @@
 #include "helpdialog.h"
 #include "importproject.h"
 #include "librarydialog.h"
+#include "path.h"
 #include "platform.h"
 #include "projectfile.h"
 #include "projectfiledialog.h"
@@ -53,7 +54,11 @@
 
 #include "ui_mainwindow.h"
 
+#include "frontend.h"
+
 #include <algorithm>
+#include <cstddef>
+#include <fstream>
 #include <iterator>
 #include <list>
 #include <memory>
@@ -309,7 +314,7 @@ MainWindow::MainWindow(TranslationHandler* th, QSettings* settings) :
 #else
     constexpr Platform::Type defaultPlatform = Platform::Type::Unspecified;
 #endif
-    PlatformData &platform = mPlatforms.get((Platform::Type)mSettings->value(SETTINGS_CHECKED_PLATFORM, defaultPlatform).toInt());
+    PlatformData &platform = mPlatforms.get(static_cast<Platform::Type>(mSettings->value(SETTINGS_CHECKED_PLATFORM, defaultPlatform).toInt()));
     platform.mActMainWindow->setChecked(true);
 
     mNetworkAccessManager = new QNetworkAccessManager(this);
@@ -385,12 +390,14 @@ void MainWindow::loadSettings()
                mSettings->value(SETTINGS_WINDOW_HEIGHT, 600).toInt());
     }
 
-    const ReportType reportType = (ReportType)mSettings->value(SETTINGS_REPORT_TYPE, (int)ReportType::normal).toInt();
+    const ReportType reportType = static_cast<ReportType>(mSettings->value(SETTINGS_REPORT_TYPE, static_cast<int>(ReportType::normal)).toInt());
     mUI->mActionReportNormal->setChecked(reportType <= ReportType::normal);
     mUI->mActionReportAutosar->setChecked(reportType == ReportType::autosar);
     mUI->mActionReportCertC->setChecked(reportType == ReportType::certC);
     mUI->mActionReportCertCpp->setChecked(reportType == ReportType::certCpp);
-    mUI->mActionReportMisraC->setChecked(reportType == ReportType::misraC);
+    mUI->mActionReportMisraC->setChecked(reportType == ReportType::misraC2012 ||
+                                         reportType == ReportType::misraC2023 ||
+                                         reportType == ReportType::misraC2025);
     mUI->mActionReportMisraCpp2008->setChecked(reportType == ReportType::misraCpp2008);
     mUI->mActionReportMisraCpp2023->setChecked(reportType == ReportType::misraCpp2023);
 
@@ -433,7 +440,7 @@ void MainWindow::loadSettings()
     mUI->mActionToolBarFilter->setChecked(showFilterToolbar);
     mUI->mToolBarFilter->setVisible(showFilterToolbar);
 
-    const Standards::Language enforcedLanguage = (Standards::Language)mSettings->value(SETTINGS_ENFORCED_LANGUAGE, 0).toInt();
+    const Standards::Language enforcedLanguage = static_cast<Standards::Language>(mSettings->value(SETTINGS_ENFORCED_LANGUAGE, 0).toInt());
     if (enforcedLanguage == Standards::Language::CPP)
         mUI->mActionEnforceCpp->setChecked(true);
     else if (enforcedLanguage == Standards::Language::C)
@@ -469,6 +476,15 @@ void MainWindow::loadSettings()
     }
 }
 
+static ReportType getMisraCReportType(const QStringList &standards)
+{
+    if (standards.contains(CODING_STANDARD_MISRA_C_2023))
+        return ReportType::misraC2023;
+    if (standards.contains(CODING_STANDARD_MISRA_C_2025))
+        return ReportType::misraC2025;
+    return ReportType::misraC2012;
+}
+
 void MainWindow::saveSettings() const
 {
     // Window/dialog sizes
@@ -479,11 +495,11 @@ void MainWindow::saveSettings() const
     const ReportType reportType = mUI->mActionReportAutosar->isChecked() ? ReportType::autosar :
                                   mUI->mActionReportCertC->isChecked() ? ReportType::certC :
                                   mUI->mActionReportCertCpp->isChecked() ? ReportType::certCpp :
-                                  mUI->mActionReportMisraC->isChecked() ? ReportType::misraC :
+                                  mUI->mActionReportMisraC->isChecked() ? (mProjectFile ? getMisraCReportType(mProjectFile->getCodingStandards()) : ReportType::misraC2012) :
                                   mUI->mActionReportMisraCpp2008->isChecked() ? ReportType::misraCpp2008 :
                                   mUI->mActionReportMisraCpp2023->isChecked() ? ReportType::misraCpp2023 :
                                   ReportType::normal;
-    mSettings->setValue(SETTINGS_REPORT_TYPE, (int)reportType);
+    mSettings->setValue(SETTINGS_REPORT_TYPE, static_cast<int>(reportType));
 
     // Show * states
     mSettings->setValue(SETTINGS_SHOW_STYLE, mUI->mActionShowStyle->isChecked());
@@ -559,7 +575,7 @@ void MainWindow::doAnalyzeProject(ImportProject p, const bool checkLibrary, cons
         p.ignorePaths(v);
 
         if (!mProjectFile->getAnalyzeAllVsConfigs()) {
-            const Platform::Type platform = (Platform::Type) mSettings->value(SETTINGS_CHECKED_PLATFORM, 0).toInt();
+            const Platform::Type platform = static_cast<Platform::Type>(mSettings->value(SETTINGS_CHECKED_PLATFORM, 0).toInt());
             std::vector<std::string> configurations;
             const QStringList configs = mProjectFile->getVsConfigurations();
             std::transform(configs.cbegin(), configs.cend(), std::back_inserter(configurations), [](const QString& e) {
@@ -603,6 +619,10 @@ void MainWindow::doAnalyzeProject(ImportProject p, const bool checkLibrary, cons
         mThread->setClangIncludePaths(clangHeaders.split(";"));
         mThread->setSuppressions(mProjectFile->getSuppressions());
     }
+
+    const Standards::Language enforcedLang = static_cast<Standards::Language>(mSettings->value(SETTINGS_ENFORCED_LANGUAGE, 0).toInt());
+    frontend::applyLang(p.fileSettings, checkSettings, enforcedLang);
+
     mThread->setProject(p);
     mThread->check(checkSettings, supprs);
     mUI->mResults->setCheckSettings(checkSettings);
@@ -643,9 +663,11 @@ void MainWindow::doAnalyzeFiles(const QStringList &files, const bool checkLibrar
         return;
     }
 
-    mUI->mResults->checkingStarted(fileNames.count());
+    std::list<FileWithDetails> fdetails = enrichFilesForAnalysis(fileNames, checkSettings);
 
-    mThread->setFiles(fileNames);
+    // TODO: lock UI here?
+    mUI->mResults->checkingStarted(fdetails.size());
+    mThread->setFiles(std::move(fdetails));
     if (mProjectFile && !checkConfiguration)
         mThread->setAddonsAndTools(mProjectFile->getAddonsAndTools());
     mThread->setSuppressions(mProjectFile ? mProjectFile->getCheckingSuppressions() : QList<SuppressionList::Suppression>());
@@ -683,9 +705,9 @@ void MainWindow::analyzeCode(const QString& code, const QString& filename)
     if (!getCppcheckSettings(checkSettings, supprs))
         return;
 
+    // TODO: split ErrorLogger from ThreadResult
     // Initialize dummy ThreadResult as ErrorLogger
     ThreadResult result;
-    result.setFiles(QStringList(filename));
     connect(&result, SIGNAL(progress(int,QString)),
             mUI->mResults, SLOT(progress(int,QString)));
     connect(&result, SIGNAL(error(ErrorItem)),
@@ -702,7 +724,8 @@ void MainWindow::analyzeCode(const QString& code, const QString& filename)
     checkLockDownUI();
     clearResults();
     mUI->mResults->checkingStarted(1);
-    cppcheck.check(FileWithDetails(filename.toStdString()), code.toStdString());
+    // TODO: apply enforcedLanguage?
+    cppcheck.check(FileWithDetails(filename.toStdString(), Path::identify(filename.toStdString(), false), 0), code.toStdString());
     analysisDone();
 
     // Expand results
@@ -796,7 +819,7 @@ void MainWindow::analyzeFiles()
             p.ignoreOtherConfigs(cfg.toStdString());
         }
 
-        doAnalyzeProject(p);
+        doAnalyzeProject(p); // TODO: avoid copy
         return;
     }
 
@@ -1009,10 +1032,7 @@ QString MainWindow::loadAddon(Settings &settings, const QString &filesDir, const
         if (!misraFile.isEmpty()) {
             QString arg;
             picojson::array arr;
-            if (misraFile.endsWith(".pdf", Qt::CaseInsensitive))
-                arg = "--misra-pdf=" + misraFile;
-            else
-                arg = "--rule-texts=" + misraFile;
+            arg = "--rule-texts=" + misraFile;
             arr.emplace_back(arg.toStdString());
             obj["args"] = picojson::value(arr);
         }
@@ -1038,6 +1058,7 @@ bool MainWindow::getCppcheckSettings(Settings& settings, Suppressions& supprs)
     Settings::terminate(true);
 
     settings.exename = QCoreApplication::applicationFilePath().toStdString();
+    settings.templateFormat = "{file}:{line}:{column}: {severity}:{inconclusive:inconclusive:} {message} [{id}]";
 
     // default to --check-level=normal for GUI for now
     settings.setCheckLevel(Settings::CheckLevel::normal);
@@ -1125,7 +1146,7 @@ bool MainWindow::getCppcheckSettings(Settings& settings, Suppressions& supprs)
             settings.platform.loadFromFile(applicationFilePath.toStdString().c_str(), platform.toStdString());
         } else {
             for (int i = Platform::Type::Native; i <= Platform::Type::Unix64; i++) {
-                const auto p = (Platform::Type)i;
+                const auto p = static_cast<Platform::Type>(i);
                 if (platform == Platform::toString(p)) {
                     settings.platform.set(p);
                     break;
@@ -1145,7 +1166,7 @@ bool MainWindow::getCppcheckSettings(Settings& settings, Suppressions& supprs)
         case ProjectFile::CheckLevel::exhaustive:
             settings.setCheckLevel(Settings::CheckLevel::exhaustive);
             break;
-        };
+        }
         settings.checkHeaders = mProjectFile->getCheckHeaders();
         settings.checkUnusedTemplates = mProjectFile->getCheckUnusedTemplates();
         settings.safeChecks.classes = mProjectFile->safeChecks.classes;
@@ -1156,6 +1177,8 @@ bool MainWindow::getCppcheckSettings(Settings& settings, Suppressions& supprs)
             settings.checkUnknownFunctionReturn.insert(s.toStdString());
 
         for (const QString& addon : mProjectFile->getAddons()) {
+            if (isCppcheckPremium() && addon == "misra")
+                continue;
             const QString addonError = loadAddon(settings, filesDir, pythonCmd, addon);
             if (!addonError.isEmpty()) {
                 QMessageBox::critical(this, tr("Error"), tr("%1\n\nAnalysis is aborted.").arg(addonError));
@@ -1171,10 +1194,9 @@ bool MainWindow::getCppcheckSettings(Settings& settings, Suppressions& supprs)
                 premiumArgs += " --cert-c-int-precision=" + QString::number(mProjectFile->getCertIntPrecision());
             for (const QString& c: mProjectFile->getCodingStandards())
                 premiumArgs += " --" + c;
-            if (!premiumArgs.contains("misra") && mProjectFile->getAddons().contains("misra"))
+            if (!premiumArgs.contains("--misra-c-") && mProjectFile->getAddons().contains("misra"))
                 premiumArgs += " --misra-c-2012";
             settings.premiumArgs = premiumArgs.mid(1).toStdString();
-            settings.setMisraRuleTexts(CheckThread::executeCommand);
         }
     }
     else
@@ -1205,10 +1227,9 @@ bool MainWindow::getCppcheckSettings(Settings& settings, Suppressions& supprs)
     settings.jobs = mSettings->value(SETTINGS_CHECK_THREADS, 1).toInt();
     settings.certainty.setEnabled(Certainty::inconclusive, mSettings->value(SETTINGS_INCONCLUSIVE_ERRORS, false).toBool());
     if (!mProjectFile || settings.platform.type == Platform::Type::Unspecified)
-        settings.platform.set((Platform::Type) mSettings->value(SETTINGS_CHECKED_PLATFORM, 0).toInt());
+        settings.platform.set(static_cast<Platform::Type>(mSettings->value(SETTINGS_CHECKED_PLATFORM, 0).toInt()));
     settings.standards.setCPP(mSettings->value(SETTINGS_STD_CPP, QString()).toString().toStdString());
     settings.standards.setC(mSettings->value(SETTINGS_STD_C, QString()).toString().toStdString());
-    settings.enforcedLang = (Standards::Language)mSettings->value(SETTINGS_ENFORCED_LANGUAGE, 0).toInt();
 
     settings.jobs = std::max(settings.jobs, 1u);
 
@@ -1363,10 +1384,12 @@ void MainWindow::reAnalyzeSelected(const QStringList& files)
     pathList.addPathList(files);
     if (mProjectFile)
         pathList.addExcludeList(mProjectFile->getExcludedPaths());
-    QStringList fileNames = pathList.getFileList();
+
+    std::list<FileWithDetails> fdetails = enrichFilesForAnalysis(pathList.getFileList(), checkSettings);
+
     checkLockDownUI(); // lock UI while checking
-    mUI->mResults->checkingStarted(fileNames.size());
-    mThread->setCheckFiles(fileNames);
+    mUI->mResults->checkingStarted(fdetails.size());
+    mThread->setCheckFiles(std::move(fdetails));
 
     // Saving last check start time, otherwise unchecked modified files will not be
     // considered in "Modified Files Check"  performed after "Selected Files Check"
@@ -1379,7 +1402,7 @@ void MainWindow::reAnalyzeSelected(const QStringList& files)
 
 void MainWindow::reAnalyze(bool all)
 {
-    const QStringList files = mThread->getReCheckFiles(all);
+    const std::list<FileWithDetails> files = mThread->getReCheckFiles(all);
     if (files.empty())
         return;
 
@@ -1392,8 +1415,8 @@ void MainWindow::reAnalyze(bool all)
     mUI->mResults->clear(all);
 
     // Clear results for changed files
-    for (int i = 0; i < files.size(); ++i)
-        mUI->mResults->clear(files[i]);
+    for (const auto& f : files)
+        mUI->mResults->clear(QString::fromStdString(f.path()));
 
     checkLockDownUI(); // lock UI while checking
     mUI->mResults->checkingStarted(files.size());
@@ -1960,7 +1983,7 @@ void MainWindow::analyzeProject(const ProjectFile *projectFile, const QStringLis
             msg.exec();
             return;
         }
-        doAnalyzeProject(p, checkLibrary, checkConfiguration);
+        doAnalyzeProject(p, checkLibrary, checkConfiguration);  // TODO: avoid copy
         return;
     }
 
@@ -2133,7 +2156,7 @@ void MainWindow::updateMRUMenuItems()
     if (removed)
         mSettings->setValue(SETTINGS_MRU_PROJECTS, projects);
 
-    const int numRecentProjects = qMin(projects.size(), (int)MaxRecentProjects);
+    const int numRecentProjects = qMin(projects.size(), static_cast<int>(MaxRecentProjects));
     for (int i = 0; i < numRecentProjects; i++) {
         const QString filename = QFileInfo(projects[i]).fileName();
         const QString text = QString("&%1 %2").arg(i + 1).arg(filename);
@@ -2172,7 +2195,7 @@ void MainWindow::selectPlatform()
 {
     auto *action = qobject_cast<QAction *>(sender());
     if (action) {
-        const Platform::Type platform = (Platform::Type) action->data().toInt();
+        const Platform::Type platform = static_cast<Platform::Type>(action->data().toInt());
         mSettings->setValue(SETTINGS_CHECKED_PLATFORM, platform);
     }
 }
@@ -2283,7 +2306,7 @@ void MainWindow::changeReportType() {
     const ReportType reportType = mUI->mActionReportAutosar->isChecked() ? ReportType::autosar :
                                   mUI->mActionReportCertC->isChecked() ? ReportType::certC :
                                   mUI->mActionReportCertCpp->isChecked() ? ReportType::certCpp :
-                                  mUI->mActionReportMisraC->isChecked() ? ReportType::misraC :
+                                  mUI->mActionReportMisraC->isChecked() ? (mProjectFile ? getMisraCReportType(mProjectFile->getCodingStandards()) : ReportType::misraC2012) :
                                   mUI->mActionReportMisraCpp2008->isChecked() ? ReportType::misraCpp2008 :
                                   mUI->mActionReportMisraCpp2023->isChecked() ? ReportType::misraCpp2023 :
                                   ReportType::normal;
@@ -2332,3 +2355,12 @@ void MainWindow::changeReportType() {
     }
 }
 
+std::list<FileWithDetails> MainWindow::enrichFilesForAnalysis(const QStringList& fileNames, const Settings& settings) const {
+    std::list<FileWithDetails> fdetails;
+    std::transform(fileNames.cbegin(), fileNames.cend(), std::back_inserter(fdetails), [](const QString& f) {
+        return FileWithDetails{f.toStdString(), Standards::Language::None, static_cast<std::size_t>(QFile(f).size())};
+    });
+    const Standards::Language enforcedLang = static_cast<Standards::Language>(mSettings->value(SETTINGS_ENFORCED_LANGUAGE, 0).toInt());
+    frontend::applyLang(fdetails, settings, enforcedLang);
+    return fdetails;
+}
