@@ -23,11 +23,11 @@
 #include "platforms.h"
 
 #include <cstdint>
+#include <list>
 
 #include <QFileDialog>
 #include <QMainWindow>
 #include <QObject>
-#include <QPair>
 #include <QString>
 #include <QStringList>
 
@@ -46,6 +46,7 @@ class QNetworkAccessManager;
 class QNetworkReply;
 class Settings;
 struct Suppressions;
+class FileWithDetails;
 namespace Ui {
     class MainWindow;
 }
@@ -424,6 +425,9 @@ private:
      */
     void removeProjectMRU(const QString &project);
 
+    /** @brief Generate list of detailed files from list of filenames. */
+    std::list<FileWithDetails> enrichFilesForAnalysis(const QStringList& fileNames, const Settings& settings) const;
+
     /** @brief Program settings */
     QSettings *mSettings;
 
