@@ -64,6 +64,7 @@
 #include <QVariant>
 #include <QVariantMap>
 #include <Qt>
+#include <QHeaderView>
 
 static constexpr char COLUMN[] = "column";
 static constexpr char CWE[] = "cwe";
@@ -666,6 +667,7 @@ void ResultsTree::refreshTree()
         // Show the file if any of it's errors are visible
         setRowHidden(i, QModelIndex(), !showFile);
     }
+    sortByColumn(header()->sortIndicatorSection(), header()->sortIndicatorOrder());
 }
 
 QStandardItem *ResultsTree::ensureFileItem(const QString &fullpath, const QString &file0, bool hide)
@@ -745,21 +747,35 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
                 menu.addSeparator();
             }
 
+            int selectedFiles = 0;
+            int selectedResults = 0;
+
+            for (auto row : mSelectionModel->selectedRows()) {
+                auto *item = mModel.itemFromIndex(row);
+                if (!item->parent())
+                    selectedFiles++;
+                else if (!item->parent()->parent())
+                    selectedResults++;
+            }
+
             //Create an action for the application
-            auto *recheckAction          = new QAction(tr("Recheck"), &menu);
+            auto *recheckAction          = new QAction(tr("Recheck %1 file(s)").arg(selectedFiles), &menu);
             auto *copyAction             = new QAction(tr("Copy"), &menu);
-            auto *hide                   = new QAction(tr("Hide"), &menu);
+            auto *hide                   = new QAction(tr("Hide %1 result(s)").arg(selectedResults), &menu);
             auto *hideallid              = new QAction(tr("Hide all with id"), &menu);
             auto *opencontainingfolder   = new QAction(tr("Open containing folder"), &menu);
 
-            if (multipleSelection) {
-                hideallid->setDisabled(true);
-                opencontainingfolder->setDisabled(true);
-            }
-            if (mThread->isChecking())
+            if (selectedFiles == 0 || mThread->isChecking())
                 recheckAction->setDisabled(true);
-            else
-                recheckAction->setDisabled(false);
+
+            if (selectedResults == 0)
+                hide->setDisabled(true);
+
+            if (selectedResults == 0 || multipleSelection)
+                hideallid->setDisabled(true);
+
+            if (multipleSelection)
+                opencontainingfolder->setDisabled(true);
 
             menu.addAction(recheckAction);
             menu.addSeparator();
@@ -772,7 +788,9 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
             {
                 QVariantMap itemdata = mContextItem->data().toMap();
                 const QString messageId = itemdata[ERRORID].toString();
-                suppress->setEnabled(!ErrorLogger::isCriticalErrorId(messageId.toStdString()));
+
+                if (selectedResults == 0 || ErrorLogger::isCriticalErrorId(messageId.toStdString()))
+                    suppress->setDisabled(true);
             }
             menu.addAction(suppress);
             connect(suppress, &QAction::triggered, this, &ResultsTree::suppressSelectedIds);
@@ -1006,7 +1024,7 @@ void ResultsTree::copy()
         QString inconclusive = itemdata[INCONCLUSIVE].toBool() ? ",inconclusive" : "";
         text += itemdata[FILENAME].toString() + ':' + QString::number(itemdata[LINE].toInt()) + ':' + QString::number(itemdata[COLUMN].toInt())
                 + ": "
-                + QString::fromStdString(severityToString(ShowTypes::ShowTypeToSeverity((ShowTypes::ShowType)itemdata[SEVERITY].toInt()))) + inconclusive
+                + QString::fromStdString(severityToString(ShowTypes::ShowTypeToSeverity(static_cast<ShowTypes::ShowType>(itemdata[SEVERITY].toInt())))) + inconclusive
                 + ": "
                 + itemdata[MESSAGE].toString()
                 + " ["
@@ -1290,12 +1308,10 @@ void ResultsTree::saveErrors(Report *report, const QStandardItem *fileItem) cons
 
 static int indexOf(const QList<ErrorItem> &list, const ErrorItem &item)
 {
-    for (int i = 0; i < list.size(); i++) {
-        if (ErrorItem::sameCID(item, list[i])) {
-            return i;
-        }
-    }
-    return -1;
+    auto it = std::find_if(list.cbegin(), list.cend(), [&](const ErrorItem& e) {
+        return ErrorItem::sameCID(item, e);
+    });
+    return it == list.cend() ? -1 : static_cast<int>(std::distance(list.cbegin(), it));
 }
 
 void ResultsTree::updateFromOldReport(const QString &filename)
@@ -1536,7 +1552,9 @@ bool ResultsTree::isCertReport() const {
 
 bool ResultsTree::isAutosarMisraReport() const {
     return mReportType == ReportType::autosar ||
-           mReportType == ReportType::misraC ||
+           mReportType == ReportType::misraC2012 ||
+           mReportType == ReportType::misraC2023 ||
+           mReportType == ReportType::misraC2025 ||
            mReportType == ReportType::misraCpp2008 ||
            mReportType == ReportType::misraCpp2023;
 }
