@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -73,6 +73,8 @@
 #include <QVariantMap>
 #include <Qt>
 
+enum class ReportType : std::uint8_t;
+
 ResultsView::ResultsView(QWidget * parent) :
     QWidget(parent),
     mUI(new Ui::ResultsView),
@@ -153,6 +155,10 @@ const ShowTypes & ResultsView::getShowTypes() const
     return mUI->mTree->mShowSeverities;
 }
 
+void ResultsView::setReportType(ReportType reportType) {
+    mUI->mTree->setReportType(reportType);
+}
+
 void ResultsView::progress(int value, const QString& description)
 {
     mUI->mProgress->setValue(value);
@@ -204,7 +210,7 @@ void ResultsView::updateFromOldReport(const QString &filename) const
     mUI->mTree->updateFromOldReport(filename);
 }
 
-void ResultsView::save(const QString &filename, Report::Type type) const
+void ResultsView::save(const QString &filename, Report::Type type, const QString& productName) const
 {
     Report *report = nullptr;
 
@@ -216,7 +222,7 @@ void ResultsView::save(const QString &filename, Report::Type type) const
         report = new TxtReport(filename);
         break;
     case Report::XMLV2:
-        report = new XmlReportV2(filename);
+        report = new XmlReportV2(filename, productName);
         break;
     }
 
@@ -258,7 +264,7 @@ void ResultsView::printPreview()
     dialog.exec();
 }
 
-void ResultsView::print(QPrinter* printer)
+void ResultsView::print(QPrinter* printer) const
 {
     if (!hasResults()) {
         QMessageBox msgBox;
@@ -296,7 +302,7 @@ void ResultsView::setCheckDirectory(const QString &dir)
     mUI->mTree->setCheckDirectory(dir);
 }
 
-QString ResultsView::getCheckDirectory()
+QString ResultsView::getCheckDirectory() const
 {
     return mUI->mTree->getCheckDirectory();
 }
@@ -408,7 +414,7 @@ void ResultsView::readErrorsXml(const QString &filename)
         return;
     }
 
-    XmlReportV2 report(filename);
+    XmlReportV2 report(filename, QString());
     QList<ErrorItem> errors;
     if (report.open()) {
         errors = report.read();
@@ -436,7 +442,7 @@ void ResultsView::readErrorsXml(const QString &filename)
 
 void ResultsView::updateDetails(const QModelIndex &index)
 {
-    const QStandardItemModel *model = qobject_cast<const QStandardItemModel*>(mUI->mTree->model());
+    const auto *model = qobject_cast<const QStandardItemModel*>(mUI->mTree->model());
     QStandardItem *item = model->itemFromIndex(index);
 
     if (!item) {
@@ -449,39 +455,39 @@ void ResultsView::updateDetails(const QModelIndex &index)
     if (item->parent() && item->column() != 0)
         item = item->parent()->child(item->row(), 0);
 
-    QVariantMap data = item->data().toMap();
+    QVariantMap itemdata = item->data().toMap();
 
     // If there is no severity data then it is a parent item without summary and message
-    if (!data.contains("severity")) {
+    if (!itemdata.contains("severity")) {
         mUI->mCode->clear();
         mUI->mDetails->setText(QString());
         return;
     }
 
-    const QString message = data["message"].toString();
+    const QString message = itemdata["message"].toString();
     QString formattedMsg = message;
 
-    const QString file0 = data["file0"].toString();
-    if (!file0.isEmpty() && Path::isHeader(data["file"].toString().toStdString()))
+    const QString file0 = itemdata["file0"].toString();
+    if (!file0.isEmpty() && Path::isHeader(itemdata["file"].toString().toStdString()))
         formattedMsg += QString("\n\n%1: %2").arg(tr("First included by")).arg(QDir::toNativeSeparators(file0));
 
-    if (data["cwe"].toInt() > 0)
-        formattedMsg.prepend("CWE: " + QString::number(data["cwe"].toInt()) + "\n");
+    if (itemdata["cwe"].toInt() > 0)
+        formattedMsg.prepend("CWE: " + QString::number(itemdata["cwe"].toInt()) + "\n");
     if (mUI->mTree->showIdColumn())
-        formattedMsg.prepend(tr("Id") + ": " + data["id"].toString() + "\n");
-    if (data["incomplete"].toBool())
+        formattedMsg.prepend(tr("Id") + ": " + itemdata["id"].toString() + "\n");
+    if (itemdata["incomplete"].toBool())
         formattedMsg += "\n" + tr("Bug hunting analysis is incomplete");
     mUI->mDetails->setText(formattedMsg);
 
-    const int lineNumber = data["line"].toInt();
+    const int lineNumber = itemdata["line"].toInt();
 
-    QString filepath = data["file"].toString();
+    QString filepath = itemdata["file"].toString();
     if (!QFileInfo::exists(filepath) && QFileInfo::exists(mUI->mTree->getCheckDirectory() + '/' + filepath))
         filepath = mUI->mTree->getCheckDirectory() + '/' + filepath;
 
     QStringList symbols;
-    if (data.contains("symbolNames"))
-        symbols = data["symbolNames"].toString().split("\n");
+    if (itemdata.contains("symbolNames"))
+        symbols = itemdata["symbolNames"].toString().split("\n");
 
     if (filepath == mUI->mCode->getFileName()) {
         mUI->mCode->setError(lineNumber, symbols);
