@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,7 +89,7 @@ ShowTypes::ShowType ShowTypes::VariantToShowType(const QVariant &data)
     if (value < ShowTypes::ShowStyle || value > ShowTypes::ShowErrors) {
         return ShowTypes::ShowNone;
     }
-    return (ShowTypes::ShowType)value;
+    return static_cast<ShowTypes::ShowType>(value);
 }
 
 void ShowTypes::load()
