@@ -1,4 +1,4 @@
-/*
+/* -*- C++ -*-
  * Cppcheck - A tool for static C/C++ code analysis
  * Copyright (C) 2007-2021 Cppcheck team.
  *
@@ -17,7 +17,6 @@
  */
 
 #include <QObject>
-#include <QString>
 
 class TestTranslationHandler : public QObject {
     Q_OBJECT
