@@ -20,9 +20,11 @@
 #ifndef THREADHANDLER_H
 #define THREADHANDLER_H
 
+#include "settings.h"
 #include "suppressions.h"
 #include "threadresult.h"
 
+#include <list>
 #include <memory>
 #include <set>
 #include <string>
@@ -37,9 +39,9 @@
 class ResultsView;
 class CheckThread;
 class QSettings;
-class Settings;
 class ImportProject;
 class ErrorItem;
+class FileWithDetails;
 
 /// @addtogroup GUI
 /// @{
@@ -55,12 +57,6 @@ public:
     explicit ThreadHandler(QObject *parent = nullptr);
     ~ThreadHandler() override;
 
-    /**
-     * @brief Set the number of threads to use
-     * @param count The number of threads to use
-     */
-    void setThreadCount(int count);
-
     /**
      * @brief Initialize the threads (connect all signals to resultsview's slots)
      *
@@ -85,7 +81,7 @@ public:
     }
 
     void setSuppressions(const QList<SuppressionList::Suppression> &s) {
-        mSuppressions = s;
+        mSuppressionsUI = s;
     }
 
     void setClangIncludePaths(const QStringList &s) {
@@ -103,7 +99,7 @@ public:
      *
      * @param files files to check
      */
-    void setFiles(const QStringList &files);
+    void setFiles(std::list<FileWithDetails> files);
 
     /**
      * @brief Set project to check
@@ -132,7 +128,7 @@ public:
      *
      * @param files list of files to be checked
      */
-    void setCheckFiles(const QStringList& files);
+    void setCheckFiles(std::list<FileWithDetails> files);
 
     /**
      * @brief Is checking running?
@@ -166,7 +162,7 @@ public:
      * @brief Get files that should be rechecked because they have been
      * changed.
      */
-    QStringList getReCheckFiles(bool all) const;
+    std::list<FileWithDetails> getReCheckFiles(bool all) const;
 
     /**
      * @brief Get start time of last check
@@ -213,7 +209,7 @@ protected:
      * @brief List of files checked last time (used when rechecking)
      *
      */
-    QStringList mLastFiles;
+    std::list<FileWithDetails> mLastFiles;
 
     /** @brief date and time when current checking started */
     QDateTime mCheckStartTime;
@@ -235,12 +231,24 @@ protected:
      */
     int mScanDuration{};
 
+    /**
+     * @brief Create checker threads
+     * @param count The number of threads to spawn
+     */
+    void createThreads(int count);
+
     /**
      * @brief Function to delete all threads
      *
      */
     void removeThreads();
 
+    /*
+     * @brief Apply check settings to a checker thread
+     * @param thread The thread to setup
+     */
+    void setupCheckThread(CheckThread &thread) const;
+
     /**
      * @brief Thread results are stored here
      *
@@ -259,12 +267,24 @@ protected:
      */
     int mRunningThreadCount{};
 
+    /**
+     * @brief A whole program check is queued by check()
+     */
     bool mAnalyseWholeProgram{};
     std::string mCtuInfo;
 
     QStringList mAddonsAndTools;
-    QList<SuppressionList::Suppression> mSuppressions;
+    QList<SuppressionList::Suppression> mSuppressionsUI;
     QStringList mClangIncludePaths;
+
+    /// @{
+    /**
+     * @brief Settings specific to the current analysis
+     */
+    QStringList mCheckAddonsAndTools;
+    Settings mCheckSettings;
+    std::shared_ptr<Suppressions> mCheckSuppressions;
+    /// @}
 private:
 
     /**
