@@ -71,10 +71,10 @@ void Check::reportError(const std::list<const Token *> &callstack, Severity seve
         writeToErrorList(errmsg);
 }
 
-void Check::reportError(const ErrorPath &errorPath, Severity severity, const char id[], const std::string &msg, const CWE &cwe, Certainty certainty)
+void Check::reportError(ErrorPath errorPath, Severity severity, const char id[], const std::string &msg, const CWE &cwe, Certainty certainty)
 {
     // TODO: report debug warning when error is for a disabled severity
-    const ErrorMessage errmsg(errorPath, mTokenizer ? &mTokenizer->list : nullptr, severity, id, msg, cwe, certainty);
+    const ErrorMessage errmsg(std::move(errorPath), mTokenizer ? &mTokenizer->list : nullptr, severity, id, msg, cwe, certainty);
     if (mErrorLogger)
         mErrorLogger->reportErr(errmsg);
     else
@@ -106,7 +106,7 @@ std::string Check::getMessageId(const ValueFlow::Value &value, const char id[])
     if (value.condition != nullptr)
         return id + std::string("Cond");
     if (value.safe)
-        return std::string("safe") + (char)std::toupper(id[0]) + (id + 1);
+        return std::string("safe") + static_cast<char>(std::toupper(id[0])) + (id + 1);
     return id;
 }
 
