@@ -25,8 +25,6 @@
 #include "check.h"
 #include "config.h"
 #include "ctu.h"
-#include "mathlib.h"
-#include "vfvalue.h"
 
 #include <cstdint>
 #include <list>
@@ -42,6 +40,11 @@ class Variable;
 struct Dimension;
 enum class Certainty : std::uint8_t;
 
+namespace ValueFlow
+{
+    class Value;
+}
+
 /// @addtogroup Checks
 /// @{
 
@@ -69,7 +72,7 @@ private:
     void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings) const override;
 
     /** @brief Parse current TU and extract file info */
-    Check::FileInfo *getFileInfo(const Tokenizer &tokenizer, const Settings &settings) const override;
+    Check::FileInfo *getFileInfo(const Tokenizer &tokenizer, const Settings &settings, const std::string& /*currentConfig*/) const override;
 
     /** @brief Analyse all file infos for all TU */
     bool analyseWholeProgram(const CTU::FileInfo &ctu, const std::list<Check::FileInfo*> &fileInfo, const Settings& settings, ErrorLogger &errorLogger) override;
