@@ -1,6 +1,6 @@
-/*
+/* -*- C++ -*-
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@
 #include "config.h"
 #include "mathlib.h"
 #include "errortypes.h"
-#include "tokenize.h"
 
 #include <set>
 #include <string>
@@ -35,6 +34,7 @@ class Settings;
 class Token;
 class ErrorLogger;
 class ValueType;
+class Tokenizer;
 
 namespace ValueFlow {
     class Value;
@@ -57,35 +57,18 @@ private:
     CheckCondition(const Tokenizer *tokenizer, const Settings *settings, ErrorLogger *errorLogger)
         : Check(myName(), tokenizer, settings, errorLogger) {}
 
-    void runChecks(const Tokenizer &tokenizer, ErrorLogger *errorLogger) override {
-        CheckCondition checkCondition(&tokenizer, tokenizer.getSettings(), errorLogger);
-        checkCondition.multiCondition();
-        checkCondition.clarifyCondition();   // not simplified because ifAssign
-        checkCondition.multiCondition2();
-        checkCondition.checkIncorrectLogicOperator();
-        checkCondition.checkInvalidTestForOverflow();
-        checkCondition.duplicateCondition();
-        checkCondition.checkPointerAdditionResultNotNull();
-        checkCondition.checkDuplicateConditionalAssign();
-        checkCondition.assignIf();
-        checkCondition.checkBadBitmaskCheck();
-        checkCondition.comparison();
-        checkCondition.checkModuloAlwaysTrueFalse();
-        checkCondition.checkAssignmentInCondition();
-        checkCondition.checkCompareValueOutOfTypeRange();
-        checkCondition.alwaysTrueFalse();
-    }
+    void runChecks(const Tokenizer &tokenizer, ErrorLogger *errorLogger) override;
 
     /** mismatching assignment / comparison */
     void assignIf();
 
     /** parse scopes recursively */
-    bool assignIfParseScope(const Token * const assignTok,
-                            const Token * const startTok,
-                            const nonneg int varid,
-                            const bool islocal,
-                            const char bitop,
-                            const MathLib::bigint num);
+    bool assignIfParseScope(const Token * assignTok,
+                            const Token * startTok,
+                            nonneg int varid,
+                            bool islocal,
+                            char bitop,
+                            MathLib::bigint num);
 
     /** check bitmask using | instead of & */
     void checkBadBitmaskCheck();
@@ -133,9 +116,9 @@ private:
     std::set<const Token*> mCondDiags;
     bool diag(const Token* tok, bool insert=true);
     bool isAliased(const std::set<int> &vars) const;
-    bool isOverlappingCond(const Token * const cond1, const Token * const cond2, bool pure) const;
+    bool isOverlappingCond(const Token * cond1, const Token * cond2, bool pure) const;
     void assignIfError(const Token *tok1, const Token *tok2, const std::string &condition, bool result);
-    void mismatchingBitAndError(const Token *tok1, const MathLib::bigint num1, const Token *tok2, const MathLib::bigint num2);
+    void mismatchingBitAndError(const Token *tok1, MathLib::bigint num1, const Token *tok2, MathLib::bigint num2);
     void badBitmaskCheckError(const Token *tok, bool isNoOp = false);
     void comparisonError(const Token *tok,
                          const std::string &bitop,
@@ -170,33 +153,9 @@ private:
     void assignmentInCondition(const Token *eq);
 
     void checkCompareValueOutOfTypeRange();
-    void compareValueOutOfTypeRangeError(const Token *comparison, const std::string &type, long long value, bool result);
+    void compareValueOutOfTypeRangeError(const Token *comparison, const std::string &type, MathLib::bigint value, bool result);
 
-    void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings) const override {
-        CheckCondition c(nullptr, settings, errorLogger);
-
-        ErrorPath errorPath;
-
-        c.assignIfError(nullptr, nullptr, emptyString, false);
-        c.badBitmaskCheckError(nullptr);
-        c.comparisonError(nullptr, "&", 6, "==", 1, false);
-        c.duplicateConditionError(nullptr, nullptr, errorPath);
-        c.overlappingElseIfConditionError(nullptr, 1);
-        c.mismatchingBitAndError(nullptr, 0xf0, nullptr, 1);
-        c.oppositeInnerConditionError(nullptr, nullptr, errorPath);
-        c.identicalInnerConditionError(nullptr, nullptr, errorPath);
-        c.identicalConditionAfterEarlyExitError(nullptr, nullptr, errorPath);
-        c.incorrectLogicOperatorError(nullptr, "foo > 3 && foo < 4", true, false, errorPath);
-        c.redundantConditionError(nullptr, "If x > 11 the condition x > 10 is always true.", false);
-        c.moduloAlwaysTrueFalseError(nullptr, "1");
-        c.clarifyConditionError(nullptr, true, false);
-        c.alwaysTrueFalseError(nullptr, nullptr, nullptr);
-        c.invalidTestForOverflow(nullptr, nullptr, "false");
-        c.pointerAdditionResultNotNullError(nullptr, nullptr);
-        c.duplicateConditionalAssignError(nullptr, nullptr);
-        c.assignmentInCondition(nullptr);
-        c.compareValueOutOfTypeRangeError(nullptr, "unsigned char", 256, true);
-    }
+    void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings) const override;
 
     static std::string myName() {
         return "Condition";
