@@ -60,7 +60,7 @@ void CheckExceptionSafety::destructors()
         if (!function)
             continue;
         // only looking for destructors
-        if (function->type == Function::eDestructor) {
+        if (function->type == FunctionType::eDestructor) {
             // Inspect this destructor.
             for (const Token *tok = scope->bodyStart->next(); tok != scope->bodyEnd; tok = tok->next()) {
                 // Skip try blocks
@@ -178,7 +178,7 @@ void CheckExceptionSafety::checkRethrowCopy()
     const SymbolDatabase* const symbolDatabase = mTokenizer->getSymbolDatabase();
 
     for (const Scope &scope : symbolDatabase->scopeList) {
-        if (scope.type != Scope::eCatch)
+        if (scope.type != ScopeType::eCatch)
             continue;
 
         const unsigned int varid = scope.bodyStart->tokAt(-2)->varId();
@@ -222,7 +222,7 @@ void CheckExceptionSafety::checkCatchExceptionByValue()
     const SymbolDatabase* const symbolDatabase = mTokenizer->getSymbolDatabase();
 
     for (const Scope &scope : symbolDatabase->scopeList) {
-        if (scope.type != Scope::eCatch)
+        if (scope.type != ScopeType::eCatch)
             continue;
 
         // Find a pass-by-value declaration in the catch(), excluding basic types
@@ -257,7 +257,7 @@ static const Token * functionThrowsRecursive(const Function * function, std::set
             tok = tok->linkAt(1);  // skip till start of catch clauses
         if (tok->str() == "throw")
             return tok;
-        if (tok->function()) {
+        if (tok->function() && Token::simpleMatch(tok->astParent(), "(")) {
             const Function * called = tok->function();
             // check if called function has an exception specification
             if (called->isThrow() && called->throwArg)
