@@ -1,6 +1,6 @@
-/*
+/* -*- C++ -*-
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2024 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,9 +25,8 @@
 #include "check.h"
 #include "config.h"
 #include "errortypes.h"
-#include "tokenize.h"
-#include "vfvalue.h"
 
+#include <cstdint>
 #include <string>
 
 class Scope;
@@ -35,7 +34,11 @@ class Settings;
 class Token;
 class Variable;
 class ErrorLogger;
-
+class Tokenizer;
+namespace ValueFlow
+{
+    class Value;
+}
 
 /// @addtogroup Checks
 /// @{
@@ -53,41 +56,7 @@ private:
         : Check(myName(), tokenizer, settings, errorLogger) {}
 
     /** run checks, the token list is not simplified */
-    void runChecks(const Tokenizer &tokenizer, ErrorLogger *errorLogger) override {
-        if (!tokenizer.isCPP()) {
-            return;
-        }
-
-        CheckStl checkStl(&tokenizer, &tokenizer.getSettings(), errorLogger);
-        checkStl.erase();
-        checkStl.if_find();
-        checkStl.checkFindInsert();
-        checkStl.iterators();
-        checkStl.missingComparison();
-        checkStl.outOfBounds();
-        checkStl.outOfBoundsIndexExpression();
-        checkStl.redundantCondition();
-        checkStl.string_c_str();
-        checkStl.uselessCalls();
-        checkStl.useStlAlgorithm();
-
-        checkStl.stlOutOfBounds();
-        checkStl.negativeIndex();
-
-        checkStl.invalidContainer();
-        checkStl.mismatchingContainers();
-        checkStl.mismatchingContainerIterator();
-        checkStl.knownEmptyContainer();
-        checkStl.eraseIteratorOutOfBounds();
-
-        checkStl.stlBoundaries();
-        checkStl.checkDereferenceInvalidIterator();
-        checkStl.checkDereferenceInvalidIterator2();
-        checkStl.checkMutexes();
-
-        // Style check
-        checkStl.size();
-    }
+    void runChecks(const Tokenizer &tokenizer, ErrorLogger *errorLogger) override;
 
     /** Accessing container out of bounds using ValueFlow */
     void outOfBounds();
@@ -224,7 +193,7 @@ private:
 
     void uselessCallsReturnValueError(const Token* tok, const std::string& varname, const std::string& function);
     void uselessCallsSwapError(const Token* tok, const std::string& varname);
-    enum class SubstrErrorType { EMPTY, COPY, PREFIX, PREFIX_CONCAT };
+    enum class SubstrErrorType : std::uint8_t { EMPTY, COPY, PREFIX, PREFIX_CONCAT };
     void uselessCallsSubstrError(const Token* tok, SubstrErrorType type);
     void uselessCallsEmptyError(const Token* tok);
     void uselessCallsRemoveError(const Token* tok, const std::string& function);
@@ -242,45 +211,7 @@ private:
     void globalLockGuardError(const Token *tok);
     void localMutexError(const Token *tok);
 
-    void getErrorMessages(ErrorLogger* errorLogger, const Settings* settings) const override {
-        CheckStl c(nullptr, settings, errorLogger);
-        c.outOfBoundsError(nullptr, "container", nullptr, "x", nullptr);
-        c.invalidIteratorError(nullptr, "iterator");
-        c.iteratorsError(nullptr, "container1", "container2");
-        c.iteratorsError(nullptr, nullptr, "container0", "container1");
-        c.iteratorsError(nullptr, nullptr, "container");
-        c.invalidContainerLoopError(nullptr, nullptr, ErrorPath{});
-        c.invalidContainerError(nullptr, nullptr, nullptr, ErrorPath{});
-        c.mismatchingContainerIteratorError(nullptr, nullptr, nullptr);
-        c.mismatchingContainersError(nullptr, nullptr);
-        c.mismatchingContainerExpressionError(nullptr, nullptr);
-        c.sameIteratorExpressionError(nullptr);
-        c.dereferenceErasedError(nullptr, nullptr, "iter", false);
-        c.stlOutOfBoundsError(nullptr, "i", "foo", false);
-        c.negativeIndexError(nullptr, ValueFlow::Value(-1));
-        c.stlBoundariesError(nullptr);
-        c.if_findError(nullptr, false);
-        c.if_findError(nullptr, true);
-        c.checkFindInsertError(nullptr);
-        c.string_c_strError(nullptr);
-        c.string_c_strReturn(nullptr);
-        c.string_c_strParam(nullptr, 0);
-        c.string_c_strThrowError(nullptr);
-        c.sizeError(nullptr);
-        c.missingComparisonError(nullptr, nullptr);
-        c.redundantIfRemoveError(nullptr);
-        c.uselessCallsReturnValueError(nullptr, "str", "find");
-        c.uselessCallsSwapError(nullptr, "str");
-        c.uselessCallsSubstrError(nullptr, SubstrErrorType::COPY);
-        c.uselessCallsEmptyError(nullptr);
-        c.uselessCallsRemoveError(nullptr, "remove");
-        c.dereferenceInvalidIteratorError(nullptr, "i");
-        c.eraseIteratorOutOfBoundsError(nullptr, nullptr);
-        c.useStlAlgorithmError(nullptr, emptyString);
-        c.knownEmptyContainerError(nullptr, emptyString);
-        c.globalLockGuardError(nullptr);
-        c.localMutexError(nullptr);
-    }
+    void getErrorMessages(ErrorLogger* errorLogger, const Settings* settings) const override;
 
     static std::string myName() {
         return "STL usage";
