@@ -42,6 +42,7 @@
 #include <list>
 #include <map>
 #include <unordered_set>
+#include <utility>
 #include <vector>
 
 //---------------------------------------------------------------------------
@@ -251,7 +252,7 @@ void CheckUninitVar::checkStruct(const Token *tok, const Variable &structvar)
                 // is the variable declared in a inner union?
                 bool innerunion = false;
                 for (const Scope *innerScope : scope2->nestedList) {
-                    if (innerScope->type == Scope::eUnion) {
+                    if (innerScope->type == ScopeType::eUnion) {
                         if (var.typeStartToken()->linenr() >= innerScope->bodyStart->linenr() &&
                             var.typeStartToken()->linenr() <= innerScope->bodyEnd->linenr()) {
                             innerunion = true;
@@ -292,8 +293,8 @@ static void conditionAlwaysTrueOrFalse(const Token *tok, const std::map<nonneg i
     if (!tok)
         return;
 
-    if (tok->hasKnownIntValue()) {
-        if (tok->getKnownIntValue() == 0)
+    if (const ValueFlow::Value* v = tok->getKnownValue(ValueFlow::Value::ValueType::INT)) {
+        if (v->intvalue == 0)
             *alwaysFalse = true;
         else
             *alwaysTrue = true;
@@ -796,6 +797,9 @@ bool CheckUninitVar::checkScopeForVariable(const Token *tok, const Variable& var
 
 
             if (!membervar.empty()) {
+                if (mTokenizer->isCPP() && Token::simpleMatch(tok->astParent(), ">>"))
+                    return true;
+
                 if (isMemberVariableAssignment(tok, membervar)) {
                     checkRhs(tok, var, *alloc, number_of_if, membervar);
                     return true;
@@ -956,7 +960,7 @@ const Token* CheckUninitVar::checkLoopBodyRecursive(const Token *start, const Va
 
         if (tok->str() == "{") {
             // switch => bailout
-            if (tok->scope() && tok->scope()->type == Scope::ScopeType::eSwitch) {
+            if (tok->scope() && tok->scope()->type == ScopeType::eSwitch) {
                 bailout = true;
                 return nullptr;
             }
@@ -1560,7 +1564,7 @@ void CheckUninitVar::uninitvarError(const Token *tok, const std::string &varname
     if (diag(tok))
         return;
     errorPath.emplace_back(tok, "");
-    reportError(errorPath,
+    reportError(std::move(errorPath),
                 Severity::error,
                 "legacyUninitvar",
                 "$symbol:" + varname + "\nUninitialized variable: $symbol",
@@ -1583,7 +1587,7 @@ void CheckUninitVar::uninitvarError(const Token* tok, const ValueFlow::Value& v)
     auto severity = v.isKnown() ? Severity::error : Severity::warning;
     auto certainty = v.isInconclusive() ? Certainty::inconclusive : Certainty::normal;
     if (v.subexpressions.empty()) {
-        reportError(errorPath,
+        reportError(std::move(errorPath),
                     severity,
                     "uninitvar",
                     "$symbol:" + varname + "\nUninitialized variable: $symbol",
@@ -1597,7 +1601,7 @@ void CheckUninitVar::uninitvarError(const Token* tok, const ValueFlow::Value& v)
         vars += prefix + varname + "." + var;
         prefix = ", ";
     }
-    reportError(errorPath,
+    reportError(std::move(errorPath),
                 severity,
                 "uninitvar",
                 "$symbol:" + varname + "\nUninitialized " + vars,
@@ -1660,14 +1664,15 @@ void CheckUninitVar::valueFlowUninit()
                     if (isarray && tok->variable()->isMember())
                         continue; // Todo: this is a bailout
                     if (isarray && tok->variable()->isStlType() && Token::simpleMatch(tok->astParent(), ".")) {
-                        const auto yield = astContainerYield(tok);
+                        const auto yield = astContainerYield(tok, mSettings->library);
                         if (yield != Library::Container::Yield::AT_INDEX && yield != Library::Container::Yield::ITEM)
                             continue;
                     }
                     const bool deref = CheckNullPointer::isPointerDeRef(tok, unknown, *mSettings);
                     uninitderef = deref && v->indirect == 0;
                     const bool isleaf = isLeafDot(tok) || uninitderef;
-                    if (!isleaf && Token::Match(tok->astParent(), ". %name%") && (tok->astParent()->next()->varId() || tok->astParent()->next()->isEnumerator()))
+                    if (!isleaf && Token::Match(tok->astParent(), ". %name%") &&
+                        (tok->astParent()->next()->variable() || tok->astParent()->next()->isEnumerator()))
                         continue;
                 }
                 const ExprUsage usage = getExprUsage(tok, v->indirect, *mSettings);
@@ -1726,7 +1731,7 @@ static bool isVariableUsage(const Settings &settings, const Token *argtok, CTU::
     return isVariableUsage(settings, argtok, &value->value);
 }
 
-Check::FileInfo *CheckUninitVar::getFileInfo(const Tokenizer &tokenizer, const Settings &settings) const
+Check::FileInfo *CheckUninitVar::getFileInfo(const Tokenizer &tokenizer, const Settings &settings, const std::string& /*currentConfig*/) const
 {
     const std::list<CTU::FileInfo::UnsafeUsage> &unsafeUsage = CTU::getUnsafeUsage(tokenizer, settings, ::isVariableUsage);
     if (unsafeUsage.empty())
@@ -1770,7 +1775,7 @@ bool CheckUninitVar::analyseWholeProgram(const CTU::FileInfo &ctu, const std::li
         for (const CTU::FileInfo::UnsafeUsage &unsafeUsage : fi->unsafeUsage) {
             const CTU::FileInfo::FunctionCall *functionCall = nullptr;
 
-            const std::list<ErrorMessage::FileLocation> &locationList =
+            std::list<ErrorMessage::FileLocation> locationList =
                 CTU::FileInfo::getErrorPath(CTU::FileInfo::InvalidValueType::uninit,
                                             unsafeUsage,
                                             callsMap,
@@ -1781,7 +1786,7 @@ bool CheckUninitVar::analyseWholeProgram(const CTU::FileInfo &ctu, const std::li
             if (locationList.empty())
                 continue;
 
-            const ErrorMessage errmsg(locationList,
+            const ErrorMessage errmsg(std::move(locationList),
                                       fi->file0,
                                       Severity::error,
                                       "Using argument " + unsafeUsage.myArgumentName + " that points at uninitialized variable " + functionCall->callArgumentExpression,
