@@ -139,11 +139,11 @@ static std::vector<std::string> splitString(const std::string &line)
             pos2 = line.find('\"', pos1+1);
         else if (line[pos1] == '\'') {
             pos2 = line.find('\'', pos1+1);
-            if (pos2 < (int)line.size() - 3 && line.compare(pos2, 3, "\':\'", 0, 3) == 0)
+            if (pos2 < static_cast<int>(line.size()) - 3 && line.compare(pos2, 3, "\':\'", 0, 3) == 0)
                 pos2 = line.find('\'', pos2 + 3);
         } else {
             pos2 = pos1;
-            while (pos2 < line.size() && (line[pos2] == '_' || line[pos2] == ':' || std::isalnum((unsigned char)line[pos2])))
+            while (pos2 < line.size() && (line[pos2] == '_' || line[pos2] == ':' || std::isalnum(static_cast<unsigned char>(line[pos2]))))
                 ++pos2;
             if (pos2 > pos1 && pos2 < line.size() && line[pos2] == '<' && std::isalpha(line[pos1])) {
                 int tlevel = 1;
@@ -227,8 +227,13 @@ namespace clangimport {
             Variable* var{};
         };
 
-        const Settings *mSettings = nullptr;
-        SymbolDatabase *mSymbolDatabase = nullptr;
+        Data(const Settings& settings, SymbolDatabase& symbolDatabase)
+            : mSettings(settings)
+            , mSymbolDatabase(symbolDatabase)
+        {}
+
+        const Settings &mSettings;
+        SymbolDatabase &mSymbolDatabase;
 
         int enumValue = 0;
 
@@ -360,8 +365,8 @@ namespace clangimport {
         Token *addtoken(TokenList &tokenList, const std::string &str, bool valueType=true);
         const ::Type *addTypeTokens(TokenList &tokenList, const std::string &str, const Scope *scope = nullptr);
         void addFullScopeNameTokens(TokenList &tokenList, const Scope *recordScope);
-        Scope *createScope(TokenList &tokenList, Scope::ScopeType scopeType, AstNodePtr astNode, const Token *def);
-        Scope *createScope(TokenList &tokenList, Scope::ScopeType scopeType, const std::vector<AstNodePtr> &children2, const Token *def);
+        Scope *createScope(TokenList &tokenList, ScopeType scopeType, AstNodePtr astNode, const Token *def);
+        Scope *createScope(TokenList &tokenList, ScopeType scopeType, const std::vector<AstNodePtr> &children2, const Token *def);
         RET_NONNULL Token *createTokensCall(TokenList &tokenList);
         void createTokensFunctionDecl(TokenList &tokenList);
         void createTokensForCXXRecord(TokenList &tokenList);
@@ -628,7 +633,7 @@ const ::Type * clangimport::AstNode::addTypeTokens(TokenList &tokenList, const s
     for (const Token *typeToken = tokenList.back(); Token::Match(typeToken, "&|*|%name%"); typeToken = typeToken->previous()) {
         if (!typeToken->isName())
             continue;
-        const ::Type *recordType = scope->check->findVariableType(scope, typeToken);
+        const ::Type *recordType = scope->symdb.findVariableType(scope, typeToken);
         if (recordType) {
             const_cast<Token*>(typeToken)->type(recordType);
             return recordType;
@@ -657,7 +662,7 @@ void clangimport::AstNode::addFullScopeNameTokens(TokenList &tokenList, const Sc
 const Scope *clangimport::AstNode::getNestedInScope(TokenList &tokenList)
 {
     if (!tokenList.back())
-        return &mData->mSymbolDatabase->scopeList.front();
+        return &mData->mSymbolDatabase.scopeList.front();
     if (tokenList.back()->str() == "}" && mData->mNotScope.find(tokenList.back()) == mData->mNotScope.end())
         return tokenList.back()->scope()->nestedIn;
     return tokenList.back()->scope();
@@ -672,40 +677,38 @@ void clangimport::AstNode::setValueType(Token *tok)
             // TODO
             continue;
 
-        TokenList decl(nullptr);
-        decl.setLang(tok->isCpp() ? Standards::Language::CPP : Standards::Language::C);
+        TokenList decl(mData->mSettings, tok->isCpp() ? Standards::Language::CPP : Standards::Language::C);
         addTypeTokens(decl, type, tok->scope());
         if (!decl.front())
             break;
 
-        const ValueType valueType = ValueType::parseDecl(decl.front(), *mData->mSettings);
+        ValueType valueType = ValueType::parseDecl(decl.front(), mData->mSettings);
         if (valueType.type != ValueType::Type::UNKNOWN_TYPE) {
-            tok->setValueType(new ValueType(valueType));
+            tok->setValueType(new ValueType(std::move(valueType)));
             break;
         }
     }
 }
 
-Scope *clangimport::AstNode::createScope(TokenList &tokenList, Scope::ScopeType scopeType, AstNodePtr astNode, const Token *def)
+Scope *clangimport::AstNode::createScope(TokenList &tokenList, ScopeType scopeType, AstNodePtr astNode, const Token *def)
 {
     std::vector<AstNodePtr> children2{std::move(astNode)};
     return createScope(tokenList, scopeType, children2, def);
 }
 
-Scope *clangimport::AstNode::createScope(TokenList &tokenList, Scope::ScopeType scopeType, const std::vector<AstNodePtr> & children2, const Token *def)
+Scope *clangimport::AstNode::createScope(TokenList &tokenList, ScopeType scopeType, const std::vector<AstNodePtr> & children2, const Token *def)
 {
-    SymbolDatabase *symbolDatabase = mData->mSymbolDatabase;
+    SymbolDatabase &symbolDatabase = mData->mSymbolDatabase;
 
     auto *nestedIn = const_cast<Scope *>(getNestedInScope(tokenList));
 
-    symbolDatabase->scopeList.emplace_back(nullptr, nullptr, nestedIn);
-    Scope *scope = &symbolDatabase->scopeList.back();
-    if (scopeType == Scope::ScopeType::eEnum)
+    symbolDatabase.scopeList.emplace_back(nestedIn->symdb, nullptr, nestedIn);
+    Scope *scope = &symbolDatabase.scopeList.back();
+    if (scopeType == ScopeType::eEnum)
         scope->enumeratorList.reserve(children2.size());
     nestedIn->nestedList.push_back(scope);
     scope->type = scopeType;
-    scope->classDef = def;
-    scope->check = nestedIn->check;
+    scope->classDef = def; // TODO: pass into ctor
     if (Token::Match(def, "if|for|while (")) {
         std::map<const Variable *, const Variable *> replaceVar;
         for (const Token *vartok = def->tokAt(2); vartok; vartok = vartok->next()) {
@@ -746,7 +749,7 @@ Scope *clangimport::AstNode::createScope(TokenList &tokenList, Scope::ScopeType
                 continue;
             }
             astNode->createTokens(tokenList);
-            if (scopeType == Scope::ScopeType::eEnum)
+            if (scopeType == ScopeType::eEnum)
                 astNode->addtoken(tokenList, ",");
             else if (!Token::Match(tokenList.back(), "[;{}]"))
                 astNode->addtoken(tokenList, ";");
@@ -906,15 +909,14 @@ Token *clangimport::AstNode::createTokens(TokenList &tokenList)
         varDecl->children.clear();
         Token *expr1 = varDecl->createTokens(tokenList);
         Token *colon = addtoken(tokenList, ":");
-        AstNodePtr range;
-        for (std::size_t i = 0; i < 2; i++) {
-            if (children[i] && children[i]->nodeType == DeclStmt && children[i]->getChild(0)->nodeType == VarDecl) {
-                range = children[i]->getChild(0)->getChild(0);
-                break;
-            }
-        }
-        if (!range)
+
+        auto it = std::find_if(children.cbegin(), children.cbegin() + 2, [&](const AstNodePtr& c) {
+            return c && c->nodeType == DeclStmt && c->getChild(0)->nodeType == VarDecl;
+        });
+        if (it == children.cbegin() + 2)
             throw InternalError(tokenList.back(), "Failed to import CXXForRangeStmt. Range?");
+        AstNodePtr range = (*it)->getChild(0)->getChild(0);
+
         Token *expr2 = range->createTokens(tokenList);
         Token *par2 = addtoken(tokenList, ")");
 
@@ -926,7 +928,7 @@ Token *clangimport::AstNode::createTokens(TokenList &tokenList)
         par1->astOperand1(forToken);
         par1->astOperand2(colon);
 
-        createScope(tokenList, Scope::ScopeType::eFor, children.back(), forToken);
+        createScope(tokenList, ScopeType::eFor, children.back(), forToken);
         return nullptr;
     }
     if (nodeType == CXXMethodDecl) {
@@ -1009,7 +1011,7 @@ Token *clangimport::AstNode::createTokens(TokenList &tokenList)
     }
     if (nodeType == DoStmt) {
         addtoken(tokenList, "do");
-        createScope(tokenList, Scope::ScopeType::eDo, getChild(0), tokenList.back());
+        createScope(tokenList, ScopeType::eDo, getChild(0), tokenList.back());
         Token *tok1 = addtoken(tokenList, "while");
         Token *par1 = addtoken(tokenList, "(");
         Token *expr = children[1]->createTokens(tokenList);
@@ -1052,15 +1054,15 @@ Token *clangimport::AstNode::createTokens(TokenList &tokenList)
                 addTypeTokens(tokenList, mExtTokens.back());
             }
         }
-        Scope *enumscope = createScope(tokenList, Scope::ScopeType::eEnum, children, enumtok);
+        Scope *enumscope = createScope(tokenList, ScopeType::eEnum, children, enumtok);
         if (nametok)
             enumscope->className = nametok->str();
         if (enumscope->bodyEnd && Token::simpleMatch(enumscope->bodyEnd->previous(), ", }"))
             const_cast<Token *>(enumscope->bodyEnd)->deletePrevious();
 
         // Create enum type
-        mData->mSymbolDatabase->typeList.emplace_back(enumtok, enumscope, enumtok->scope());
-        enumscope->definedType = &mData->mSymbolDatabase->typeList.back();
+        mData->mSymbolDatabase.typeList.emplace_back(enumtok, enumscope, enumtok->scope());
+        enumscope->definedType = &mData->mSymbolDatabase.typeList.back();
         if (nametok)
             const_cast<Scope *>(enumtok->scope())->definedTypesMap[nametok->str()] = enumscope->definedType;
 
@@ -1089,7 +1091,7 @@ Token *clangimport::AstNode::createTokens(TokenList &tokenList)
         sep1->astOperand2(sep2);
         sep2->astOperand1(expr2);
         sep2->astOperand2(expr3);
-        createScope(tokenList, Scope::ScopeType::eFor, children[4], forToken);
+        createScope(tokenList, ScopeType::eFor, children[4], forToken);
         return nullptr;
     }
     if (nodeType == FunctionDecl) {
@@ -1133,10 +1135,10 @@ Token *clangimport::AstNode::createTokens(TokenList &tokenList)
         Token *par2 = addtoken(tokenList, ")");
         par1->link(par2);
         par2->link(par1);
-        createScope(tokenList, Scope::ScopeType::eIf, std::move(thenCode), iftok);
+        createScope(tokenList, ScopeType::eIf, std::move(thenCode), iftok);
         if (elseCode) {
             elseCode->addtoken(tokenList, "else");
-            createScope(tokenList, Scope::ScopeType::eElse, std::move(elseCode), tokenList.back());
+            createScope(tokenList, ScopeType::eElse, std::move(elseCode), tokenList.back());
         }
         return nullptr;
     }
@@ -1200,7 +1202,7 @@ Token *clangimport::AstNode::createTokens(TokenList &tokenList)
         const std::string &s = mExtTokens[mExtTokens.size() - 2];
         const Token* nameToken = (startsWith(s, "col:") || startsWith(s, "line:")) ?
                                  addtoken(tokenList, mExtTokens.back()) : nullptr;
-        Scope *scope = createScope(tokenList, Scope::ScopeType::eNamespace, children, defToken);
+        Scope *scope = createScope(tokenList, ScopeType::eNamespace, children, defToken);
         if (nameToken)
             scope->className = nameToken->str();
         return nullptr;
@@ -1225,9 +1227,9 @@ Token *clangimport::AstNode::createTokens(TokenList &tokenList)
             return nullptr;
         }
 
-        Scope *recordScope = createScope(tokenList, Scope::ScopeType::eStruct, children, classDef);
-        mData->mSymbolDatabase->typeList.emplace_back(classDef, recordScope, classDef->scope());
-        recordScope->definedType = &mData->mSymbolDatabase->typeList.back();
+        Scope *recordScope = createScope(tokenList, ScopeType::eStruct, children, classDef);
+        mData->mSymbolDatabase.typeList.emplace_back(classDef, recordScope, classDef->scope());
+        recordScope->definedType = &mData->mSymbolDatabase.typeList.back();
         if (!recordName.empty()) {
             recordScope->className = recordName;
             const_cast<Scope *>(classDef->scope())->definedTypesMap[recordName] = recordScope->definedType;
@@ -1254,7 +1256,7 @@ Token *clangimport::AstNode::createTokens(TokenList &tokenList)
         par2->link(par1);
         par1->astOperand1(tok1);
         par1->astOperand2(expr);
-        createScope(tokenList, Scope::ScopeType::eSwitch, children.back(), tok1);
+        createScope(tokenList, ScopeType::eSwitch, children.back(), tok1);
         return nullptr;
     }
     if (nodeType == TypedefDecl) {
@@ -1263,7 +1265,7 @@ Token *clangimport::AstNode::createTokens(TokenList &tokenList)
         return addtoken(tokenList, getSpelling());
     }
     if (nodeType == UnaryOperator) {
-        int index = (int)mExtTokens.size() - 1;
+        int index = static_cast<int>(mExtTokens.size()) - 1;
         while (index > 0 && mExtTokens[index][0] != '\'')
             --index;
         Token *unop = addtoken(tokenList, unquote(mExtTokens[index]));
@@ -1303,7 +1305,7 @@ Token *clangimport::AstNode::createTokens(TokenList &tokenList)
         Token *par2 = addtoken(tokenList, ")");
         par1->link(par2);
         par2->link(par1);
-        createScope(tokenList, Scope::ScopeType::eWhile, std::move(body), whiletok);
+        createScope(tokenList, ScopeType::eWhile, std::move(body), whiletok);
         return nullptr;
     }
     return addtoken(tokenList, "?" + nodeType + "?");
@@ -1359,7 +1361,7 @@ void clangimport::AstNode::createTokensFunctionDecl(TokenList &tokenList)
 
     const Token *startToken = nullptr;
 
-    SymbolDatabase *symbolDatabase = mData->mSymbolDatabase;
+    SymbolDatabase &symbolDatabase = mData->mSymbolDatabase;
     if (nodeType != CXXConstructorDecl && nodeType != CXXDestructorDecl) {
         if (isStatic)
             addtoken(tokenList, "static");
@@ -1384,9 +1386,9 @@ void clangimport::AstNode::createTokensFunctionDecl(TokenList &tokenList)
         nestedIn->functionList.emplace_back(nameToken, unquote(getFullType()));
         mData->funcDecl(mExtTokens.front(), nameToken, &nestedIn->functionList.back());
         if (nodeType == CXXConstructorDecl)
-            nestedIn->functionList.back().type = Function::Type::eConstructor;
+            nestedIn->functionList.back().type = FunctionType::eConstructor;
         else if (nodeType == CXXDestructorDecl)
-            nestedIn->functionList.back().type = Function::Type::eDestructor;
+            nestedIn->functionList.back().type = FunctionType::eDestructor;
         else
             nestedIn->functionList.back().retDef = startToken;
     }
@@ -1401,12 +1403,11 @@ void clangimport::AstNode::createTokensFunctionDecl(TokenList &tokenList)
 
     Scope *scope = nullptr;
     if (hasBody) {
-        symbolDatabase->scopeList.emplace_back(nullptr, nullptr, nestedIn);
-        scope = &symbolDatabase->scopeList.back();
-        scope->check = symbolDatabase;
+        symbolDatabase.scopeList.emplace_back(symbolDatabase, nullptr, nestedIn);
+        scope = &symbolDatabase.scopeList.back();
         scope->function = function;
-        scope->classDef = nameToken;
-        scope->type = Scope::ScopeType::eFunction;
+        scope->classDef = nameToken; // TODO: pass into ctor
+        scope->type = ScopeType::eFunction;
         scope->className = nameToken->str();
         nestedIn->nestedList.push_back(scope);
         function->hasBody(true);
@@ -1453,7 +1454,7 @@ void clangimport::AstNode::createTokensFunctionDecl(TokenList &tokenList)
 
     // Function body
     if (hasBody) {
-        symbolDatabase->functionScopes.push_back(scope);
+        symbolDatabase.functionScopes.push_back(scope);
         Token *bodyStart = addtoken(tokenList, "{");
         bodyStart->scope(scope);
         children.back()->createTokens(tokenList);
@@ -1498,19 +1499,19 @@ void clangimport::AstNode::createTokensForCXXRecord(TokenList &tokenList)
         std::vector<AstNodePtr> children2;
         std::copy_if(children.cbegin(), children.cend(), std::back_inserter(children2), [](const AstNodePtr& child) {
             return child->nodeType == CXXConstructorDecl ||
-            child->nodeType == CXXDestructorDecl ||
-            child->nodeType == CXXMethodDecl ||
-            child->nodeType == FieldDecl ||
-            child->nodeType == VarDecl ||
-            child->nodeType == AccessSpecDecl ||
-            child->nodeType == TypedefDecl;
+                   child->nodeType == CXXDestructorDecl ||
+                   child->nodeType == CXXMethodDecl ||
+                   child->nodeType == FieldDecl ||
+                   child->nodeType == VarDecl ||
+                   child->nodeType == AccessSpecDecl ||
+                   child->nodeType == TypedefDecl;
         });
-        Scope *scope = createScope(tokenList, isStruct ? Scope::ScopeType::eStruct : Scope::ScopeType::eClass, children2, classToken);
+        Scope *scope = createScope(tokenList, isStruct ? ScopeType::eStruct : ScopeType::eClass, children2, classToken);
         const std::string addr = mExtTokens[0];
         mData->scopeDecl(addr, scope);
         scope->className = className;
-        mData->mSymbolDatabase->typeList.emplace_back(classToken, scope, classToken->scope());
-        scope->definedType = &mData->mSymbolDatabase->typeList.back();
+        mData->mSymbolDatabase.typeList.emplace_back(classToken, scope, classToken->scope());
+        scope->definedType = &mData->mSymbolDatabase.typeList.back();
         const_cast<Scope *>(classToken->scope())->definedTypesMap[className] = scope->definedType;
     }
     addtoken(tokenList, ";");
@@ -1617,13 +1618,10 @@ void clangimport::parseClangAstDump(Tokenizer &tokenizer, std::istream &f)
 
     tokenizer.createSymbolDatabase();
     auto *symbolDatabase = const_cast<SymbolDatabase *>(tokenizer.getSymbolDatabase());
-    symbolDatabase->scopeList.emplace_back(nullptr, nullptr, nullptr);
-    symbolDatabase->scopeList.back().type = Scope::ScopeType::eGlobal;
-    symbolDatabase->scopeList.back().check = symbolDatabase;
+    symbolDatabase->scopeList.emplace_back(*symbolDatabase, nullptr, nullptr);
+    symbolDatabase->scopeList.back().type = ScopeType::eGlobal;
 
-    clangimport::Data data;
-    data.mSettings = &tokenizer.getSettings();
-    data.mSymbolDatabase = symbolDatabase;
+    clangimport::Data data(tokenizer.getSettings(), *symbolDatabase);
     std::string line;
     std::vector<AstNodePtr> tree;
     while (std::getline(f,line)) {
