@@ -1,6 +1,6 @@
-/*
+/* -*- C++ -*-
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,10 +21,11 @@
 
 #include "config.h"
 
+#include <cstdint>
 #include <ostream>
 #include <string>
 
-enum class Color {
+enum class Color : std::uint8_t {
     Reset      = 0,
     Bold       = 1,
     Dim        = 2,
