@@ -23,19 +23,19 @@
 
 #include "config.h"
 #include "errortypes.h"
-#include "color.h"
 
 #include <cstddef>
+#include <cstdint>
 #include <list>
 #include <set>
 #include <string>
-#include <utility>
 #include <vector>
 #include <map>
 
 class Token;
 class TokenList;
 enum class ReportType : std::uint8_t;
+enum class Color : std::uint8_t;
 
 namespace tinyxml2 {
     class XMLElement;
@@ -56,12 +56,8 @@ public:
      */
     class CPPCHECKLIB WARN_UNUSED FileLocation {
     public:
-        FileLocation(const std::string &file, int line, unsigned int column)
-            : fileIndex(0), line(line), column(column), mOrigFileName(file), mFileName(file) {}
-
-        FileLocation(const std::string &file, std::string info, int line, unsigned int column)
-            : fileIndex(0), line(line), column(column), mOrigFileName(file), mFileName(file), mInfo(std::move(info)) {}
-
+        FileLocation(const std::string &file, int line, unsigned int column);
+        FileLocation(const std::string &file, std::string info, int line, unsigned int column);
         FileLocation(const Token* tok, const TokenList* tokenList);
         FileLocation(const Token* tok, std::string info, const TokenList* tokenList);
 
@@ -88,7 +84,7 @@ public:
         /**
          * @return the location as a string. Format: [file:line]
          */
-        std::string stringify() const;
+        std::string stringify(bool addcolumn = false) const;
 
         unsigned int fileIndex;
         int line; // negative value means "no line"
@@ -129,7 +125,7 @@ public:
                  const std::string& msg,
                  const CWE &cwe,
                  Certainty certainty);
-    ErrorMessage(const ErrorPath &errorPath,
+    ErrorMessage(ErrorPath errorPath,
                  const TokenList *tokenList,
                  Severity severity,
                  const char id[],
@@ -157,8 +153,8 @@ public:
      * @return formatted string
      */
     std::string toString(bool verbose,
-                         const std::string &templateFormat = emptyString,
-                         const std::string &templateLocation = emptyString) const;
+                         const std::string &templateFormat,
+                         const std::string &templateLocation) const;
 
     std::string serialize() const;
     void deserialize(const std::string &data);
@@ -234,7 +230,7 @@ public:
      *
      * @param outmsg Message to show e.g. "Checking main.cpp..."
      */
-    virtual void reportOut(const std::string &outmsg, Color c = Color::Reset) = 0;
+    virtual void reportOut(const std::string &outmsg, Color c) = 0;
 
     /**
      * Information about found errors and warnings is directed
@@ -244,6 +240,13 @@ public:
      */
     virtual void reportErr(const ErrorMessage &msg) = 0;
 
+    /**
+     * Information about file metrics reported by addons.
+     *
+     * @param metric The file metric to report, as an XML object.
+     */
+    virtual void reportMetric(const std::string &metric) = 0;
+
     /**
      * Report progress to client
      * @param filename main file that is checked
@@ -256,7 +259,7 @@ public:
         (void)value;
     }
 
-    static std::string callStackToString(const std::list<ErrorMessage::FileLocation> &callStack);
+    static std::string callStackToString(const std::list<ErrorMessage::FileLocation> &callStack, bool addcolumn = false);
 
     /**
      * Convert XML-sensitive characters into XML entities
