@@ -157,6 +157,9 @@ Library::Library(const Library& other)
 
 Library& Library::operator=(const Library& other) &
 {
+    if (this == &other)
+        return *this;
+
     mData.reset(new LibraryData(*other.mData));
     return *this;
 }
@@ -172,10 +175,10 @@ static std::vector<std::string> getnames(const char *names)
     return ret;
 }
 
-static void gettokenlistfromvalid(const std::string& valid, bool cpp, TokenList& tokenList)
+static void gettokenlistfromvalid(const std::string& valid, TokenList& tokenList)
 {
     std::istringstream istr(valid + ',');
-    tokenList.createTokens(istr, cpp ? Standards::Language::CPP : Standards::Language::C); // TODO: check result?
+    tokenList.createTokens(istr); // TODO: check result?
     for (Token *tok = tokenList.front(); tok; tok = tok->next()) {
         if (Token::Match(tok,"- %num%")) {
             tok->str("-" + tok->strAt(1));
@@ -192,24 +195,20 @@ Library::Error Library::load(const char exename[], const char path[], bool debug
 
     const bool is_abs_path = Path::isAbsolute(path);
 
+    std::string fullfilename(path);
+
+    // TODO: what if the extension is not .cfg?
+    // only append extension when we provide the library name and not a path - TODO: handle relative paths?
+    if (!is_abs_path && Path::getFilenameExtension(fullfilename).empty())
+        fullfilename += ".cfg";
+
     std::string absolute_path;
     // open file..
     tinyxml2::XMLDocument doc;
     if (debug)
-        std::cout << "looking for library '" + std::string(path) + "'" << std::endl;
-    tinyxml2::XMLError error = xml_LoadFile(doc, path);
+        std::cout << "looking for library '" + fullfilename + "'" << std::endl;
+    tinyxml2::XMLError error = xml_LoadFile(doc, fullfilename.c_str());
     if (error == tinyxml2::XML_ERROR_FILE_NOT_FOUND) {
-        // failed to open file.. is there no extension?
-        std::string fullfilename(path);
-        if (Path::getFilenameExtension(fullfilename).empty()) {
-            fullfilename += ".cfg";
-            if (debug)
-                std::cout << "looking for library '" + fullfilename + "'" << std::endl;
-            error = xml_LoadFile(doc, fullfilename.c_str());
-            if (error != tinyxml2::XML_ERROR_FILE_NOT_FOUND)
-                absolute_path = Path::getAbsoluteFilePath(fullfilename);
-        }
-
         // only perform further lookups when the given path was not absolute
         if (!is_abs_path && error == tinyxml2::XML_ERROR_FILE_NOT_FOUND)
         {
@@ -218,9 +217,9 @@ Library::Error Library::load(const char exename[], const char path[], bool debug
             cfgfolders.emplace_back(FILESDIR "/cfg");
     #endif
             if (exename) {
-                const std::string exepath(Path::fromNativeSeparators(Path::getPathFromFilename(Path::getCurrentExecutablePath(exename))));
+                std::string exepath(Path::fromNativeSeparators(Path::getPathFromFilename(Path::getCurrentExecutablePath(exename))));
                 cfgfolders.push_back(exepath + "cfg");
-                cfgfolders.push_back(exepath);
+                cfgfolders.push_back(std::move(exepath));
             }
 
             while (error == tinyxml2::XML_ERROR_FILE_NOT_FOUND && !cfgfolders.empty()) {
@@ -236,7 +235,7 @@ Library::Error Library::load(const char exename[], const char path[], bool debug
             }
         }
     } else
-        absolute_path = Path::getAbsoluteFilePath(path);
+        absolute_path = Path::getAbsoluteFilePath(fullfilename);
 
     if (error == tinyxml2::XML_SUCCESS) {
         if (mData->mFiles.find(absolute_path) == mData->mFiles.end()) {
@@ -310,6 +309,66 @@ Library::Container::Action Library::Container::actionFrom(const std::string& act
     return Container::Action::NO_ACTION;
 }
 
+std::string Library::Container::toString(Library::Container::Yield yield)
+{
+    switch (yield) {
+    case Library::Container::Yield::AT_INDEX:
+        return "at_index";
+    case Library::Container::Yield::ITEM:
+        return "item";
+    case Library::Container::Yield::BUFFER:
+        return "buffer";
+    case Library::Container::Yield::BUFFER_NT:
+        return "buffer-nt";
+    case Library::Container::Yield::START_ITERATOR:
+        return "start-iterator";
+    case Library::Container::Yield::END_ITERATOR:
+        return "end-iterator";
+    case Library::Container::Yield::ITERATOR:
+        return "iterator";
+    case Library::Container::Yield::SIZE:
+        return "size";
+    case Library::Container::Yield::EMPTY:
+        return "empty";
+    case Library::Container::Yield::NO_YIELD:
+        break;
+    }
+    return "";
+}
+
+std::string Library::Container::toString(Library::Container::Action action)
+{
+    switch (action) {
+    case Library::Container::Action::RESIZE:
+        return "resize";
+    case Library::Container::Action::CLEAR:
+        return "clear";
+    case Library::Container::Action::PUSH:
+        return "push";
+    case Library::Container::Action::POP:
+        return "pop";
+    case Library::Container::Action::FIND:
+        return "find";
+    case Library::Container::Action::FIND_CONST:
+        return "find-const";
+    case Library::Container::Action::INSERT:
+        return "insert";
+    case Library::Container::Action::ERASE:
+        return "erase";
+    case Library::Container::Action::APPEND:
+        return "append";
+    case Library::Container::Action::CHANGE_CONTENT:
+        return "change-content";
+    case Library::Container::Action::CHANGE:
+        return "change";
+    case Library::Container::Action::CHANGE_INTERNAL:
+        return "change-internal";
+    case Library::Container::Action::NO_ACTION:
+        break;
+    }
+    return "";
+}
+
 Library::Error Library::load(const tinyxml2::XMLDocument &doc)
 {
     const tinyxml2::XMLElement * const rootnode = doc.FirstChildElement();
@@ -366,6 +425,7 @@ Library::Error Library::load(const tinyxml2::XMLDocument &doc)
                     AllocFunc temp;
                     temp.groupId = allocationId;
 
+                    temp.noFail = memorynode->BoolAttribute("no-fail", false);
                     temp.initData = memorynode->BoolAttribute("init", true);
                     temp.arg = memorynode->IntAttribute("arg", -1);
 
@@ -936,7 +996,7 @@ Library::Error Library::loadFunction(const tinyxml2::XMLElement * const node, co
                         const char *argattr = argnode->Attribute("arg");
                         if (!argattr)
                             return Error(ErrorCode::MISSING_ATTRIBUTE, "arg");
-                        if (strlen(argattr) != 1 || argattr[0]<'0' || argattr[0]>'9')
+                        if (strlen(argattr) != 1 || argattr[0]<'0' || argattr[0]> '9')
                             return Error(ErrorCode::BAD_ATTRIBUTE_VALUE, argattr);
 
                         ac.minsizes.reserve(type == ArgumentChecks::MinSize::Type::MUL ? 2 : 1);
@@ -945,7 +1005,7 @@ Library::Error Library::loadFunction(const tinyxml2::XMLElement * const node, co
                             const char *arg2attr = argnode->Attribute("arg2");
                             if (!arg2attr)
                                 return Error(ErrorCode::MISSING_ATTRIBUTE, "arg2");
-                            if (strlen(arg2attr) != 1 || arg2attr[0]<'0' || arg2attr[0]>'9')
+                            if (strlen(arg2attr) != 1 || arg2attr[0]<'0' || arg2attr[0]> '9')
                                 return Error(ErrorCode::BAD_ATTRIBUTE_VALUE, arg2attr);
                             ac.minsizes.back().arg2 = arg2attr[0] - '0';
                         }
@@ -1051,15 +1111,15 @@ Library::Error Library::loadFunction(const tinyxml2::XMLElement * const node, co
     return Error(ErrorCode::OK);
 }
 
-bool Library::isIntArgValid(const Token *ftok, int argnr, const MathLib::bigint argvalue) const
+bool Library::isIntArgValid(const Token *ftok, int argnr, const MathLib::bigint argvalue, const Settings& settings) const
 {
     const ArgumentChecks *ac = getarg(ftok, argnr);
     if (!ac || ac->valid.empty())
         return true;
     if (ac->valid.find('.') != std::string::npos)
-        return isFloatArgValid(ftok, argnr, static_cast<double>(argvalue));
-    TokenList tokenList(nullptr);
-    gettokenlistfromvalid(ac->valid, ftok->isCpp(), tokenList);
+        return isFloatArgValid(ftok, argnr, static_cast<double>(argvalue), settings);
+    TokenList tokenList(settings, ftok->isCpp() ? Standards::Language::CPP : Standards::Language::C);
+    gettokenlistfromvalid(ac->valid, tokenList);
     for (const Token *tok = tokenList.front(); tok; tok = tok->next()) {
         if (tok->isNumber() && argvalue == MathLib::toBigNumber(tok))
             return true;
@@ -1073,13 +1133,13 @@ bool Library::isIntArgValid(const Token *ftok, int argnr, const MathLib::bigint
     return false;
 }
 
-bool Library::isFloatArgValid(const Token *ftok, int argnr, double argvalue) const
+bool Library::isFloatArgValid(const Token *ftok, int argnr, double argvalue, const Settings& settings) const
 {
     const ArgumentChecks *ac = getarg(ftok, argnr);
     if (!ac || ac->valid.empty())
         return true;
-    TokenList tokenList(nullptr);
-    gettokenlistfromvalid(ac->valid, ftok->isCpp(), tokenList);
+    TokenList tokenList(settings, ftok->isCpp() ? Standards::Language::CPP : Standards::Language::C);
+    gettokenlistfromvalid(ac->valid, tokenList);
     for (const Token *tok = tokenList.front(); tok; tok = tok->next()) {
         if (Token::Match(tok, "%num% : %num%") && argvalue >= MathLib::toDoubleNumber(tok) && argvalue <= MathLib::toDoubleNumber(tok->tokAt(2)))
             return true;
@@ -1431,7 +1491,7 @@ bool Library::isNotLibraryFunction(const Token *ftok, const Function **func) con
     if (ftok->isKeyword() || ftok->isStandardType())
         return true;
 
-    if (ftok->function() && ftok->function()->nestedIn && ftok->function()->nestedIn->type != Scope::eGlobal)
+    if (ftok->function() && ftok->function()->nestedIn && ftok->function()->nestedIn->type != ScopeType::eGlobal)
         return true;
 
     // variables are not library functions.
@@ -1573,10 +1633,10 @@ Library::UseRetValType Library::getUseRetValType(const Token *ftok) const
         if (Token::simpleMatch(ftok->astParent(), ".")) {
             const Token* contTok = ftok->astParent()->astOperand1();
             using Yield = Library::Container::Yield;
-            const Yield yield = astContainerYield(contTok);
+            const Yield yield = astContainerYield(contTok, *this);
             if (yield == Yield::START_ITERATOR || yield == Yield::END_ITERATOR || yield == Yield::AT_INDEX ||
                 yield == Yield::SIZE || yield == Yield::EMPTY || yield == Yield::BUFFER || yield == Yield::BUFFER_NT ||
-                ((yield == Yield::ITEM || yield == Yield::ITERATOR) && astContainerAction(contTok) == Library::Container::Action::NO_ACTION))
+                ((yield == Yield::ITEM || yield == Yield::ITERATOR) && astContainerAction(contTok, *this) == Library::Container::Action::NO_ACTION))
                 return Library::UseRetValType::DEFAULT;
         }
         return Library::UseRetValType::NONE;
@@ -1597,6 +1657,10 @@ const std::string& Library::returnValue(const Token *ftok) const
 
 const std::string& Library::returnValueType(const Token *ftok) const
 {
+    while (Token::simpleMatch(ftok, "::"))
+        ftok = ftok->astOperand2() ? ftok->astOperand2() : ftok->astOperand1();
+    if (!ftok)
+        return mEmptyString;
     if (isNotLibraryFunction(ftok)) {
         if (Token::simpleMatch(ftok->astParent(), ".") && ftok->astParent()->astOperand1()) {
             const Token* contTok = ftok->astParent()->astOperand1();
@@ -1706,7 +1770,7 @@ bool Library::isFunctionConst(const Token *ftok) const
     if (isNotLibraryFunction(ftok)) {
         if (Token::simpleMatch(ftok->astParent(), ".")) {
             using Yield = Library::Container::Yield;
-            const Yield yield = astContainerYield(ftok->astParent()->astOperand1());
+            const Yield yield = astContainerYield(ftok->astParent()->astOperand1(), *this);
             if (yield == Yield::EMPTY || yield == Yield::SIZE || yield == Yield::BUFFER_NT)
                 return true;
         }
@@ -1725,8 +1789,8 @@ bool Library::isnoreturn(const Token *ftok) const
     if (isNotLibraryFunction(ftok)) {
         if (Token::simpleMatch(ftok->astParent(), ".")) {
             const Token* contTok = ftok->astParent()->astOperand1();
-            if (astContainerAction(contTok) != Library::Container::Action::NO_ACTION ||
-                astContainerYield(contTok) != Library::Container::Yield::NO_YIELD)
+            if (astContainerAction(contTok, *this) != Library::Container::Action::NO_ACTION ||
+                astContainerYield(contTok, *this) != Library::Container::Yield::NO_YIELD)
                 return false;
         }
         return false;
@@ -1885,10 +1949,18 @@ bool Library::isSmartPointer(const Token* tok) const
 
 const Library::SmartPointer* Library::detectSmartPointer(const Token* tok, bool withoutStd) const
 {
+    if (!tok)
+        return nullptr;
     std::string typestr = withoutStd ? "std::" : "";
-    while (Token::Match(tok, "%name%|::")) {
-        typestr += tok->str();
+    if (tok->str() == "::")
         tok = tok->next();
+    while (Token::Match(tok, "%name% ::")) {
+        typestr += tok->str();
+        typestr += "::";
+        tok = tok->tokAt(2);
+    }
+    if (tok && tok->isName()) {
+        typestr += tok->str();
     }
     auto it = mData->mSmartPointers.find(typestr);
     if (it == mData->mSmartPointers.end())
