@@ -31,7 +31,7 @@ const Scope* PathAnalysis::findOuterScope(const Scope * scope)
 {
     if (!scope)
         return nullptr;
-    if (scope->isLocal() && scope->type != Scope::eSwitch)
+    if (scope->isLocal() && scope->type != ScopeType::eSwitch)
         return findOuterScope(scope->nestedIn);
     return scope;
 }
@@ -48,9 +48,9 @@ static const Token* assignExpr(const Token* tok)
 
 std::pair<bool, bool> PathAnalysis::checkCond(const Token * tok, bool& known)
 {
-    if (tok->hasKnownIntValue()) {
+    if (const ValueFlow::Value* v = tok->getKnownValue(ValueFlow::Value::ValueType::INT)) {
         known = true;
-        return std::make_pair(!!tok->values().front().intvalue, !tok->values().front().intvalue);
+        return std::make_pair(!!v->intvalue, !v->intvalue);
     }
     auto it = std::find_if(tok->values().cbegin(), tok->values().cend(), [](const ValueFlow::Value& v) {
         return v.isIntValue();
@@ -166,7 +166,7 @@ PathAnalysis::Progress PathAnalysis::forwardRange(const Token* startToken, const
                 return Progress::Break;
         }
         // Prevent infinite recursion
-        if (tok->next() == start)
+        if (tok->next() == mStart)
             break;
     }
     return Progress::Continue;
@@ -174,17 +174,17 @@ PathAnalysis::Progress PathAnalysis::forwardRange(const Token* startToken, const
 
 void PathAnalysis::forward(const std::function<Progress(const Info&)>& f) const
 {
-    const Scope * endScope = findOuterScope(start->scope());
+    const Scope * endScope = findOuterScope(mStart->scope());
     if (!endScope)
         return;
     const Token * endToken = endScope->bodyEnd;
-    Info info{start, ErrorPath{}, true};
-    forwardRange(start, endToken, std::move(info), f);
+    Info info{mStart, ErrorPath{}, true};
+    forwardRange(mStart, endToken, std::move(info), f);
 }
 
-bool reaches(const Token * start, const Token * dest, const Library& library, ErrorPath* errorPath)
+bool reaches(const Token * start, const Token * dest, ErrorPath* errorPath)
 {
-    PathAnalysis::Info info = PathAnalysis{start, library}.forwardFind([&](const PathAnalysis::Info& i) {
+    PathAnalysis::Info info = PathAnalysis{start}.forwardFind([&](const PathAnalysis::Info& i) {
         return (i.tok == dest);
     });
     if (!info.tok)
