@@ -1,6 +1,6 @@
 /* -*- C++ -*-
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2024 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +22,10 @@
 //---------------------------------------------------------------------------
 
 #include "config.h"
+#include "mathlib.h"
 #include "standards.h"
 
+#include <cassert>
 #include <climits>
 #include <cstddef>
 #include <cstdint>
@@ -43,51 +45,60 @@ namespace tinyxml2 {
  */
 class CPPCHECKLIB Platform {
 private:
-    static long long min_value(int bit) {
+    static long long min_value(std::uint8_t bit) {
+        assert(bit > 0);
         if (bit >= 64)
             return LLONG_MIN;
         return -(1LL << (bit-1));
     }
 
-    static long long max_value(int bit) {
+    static long long max_value(std::uint8_t bit) {
+        assert(bit > 0);
         if (bit >= 64)
             return (~0ULL) >> 1;
         return (1LL << (bit-1)) - 1LL;
     }
 
+    static unsigned long long max_value_unsigned(std::uint8_t bit) {
+        assert(bit > 0);
+        if (bit >= 64)
+            return ~0ULL;
+        return (1ULL << bit) - 1ULL;
+    }
+
     /** provides list of defines specified by the limit.h/climits includes */
     std::string getLimitsDefines(bool c99) const;
 public:
     Platform();
 
-    bool isIntValue(long long value) const {
+    bool isIntValue(MathLib::bigint value) const {
         return value >= min_value(int_bit) && value <= max_value(int_bit);
     }
 
-    bool isIntValue(unsigned long long value) const {
+    bool isIntValue(MathLib::biguint value) const {
         const unsigned long long intMax = max_value(int_bit);
         return value <= intMax;
     }
 
-    bool isLongValue(long long value) const {
+    bool isLongValue(MathLib::bigint value) const {
         return value >= min_value(long_bit) && value <= max_value(long_bit);
     }
 
-    bool isLongValue(unsigned long long value) const {
-        const unsigned long long longMax = max_value(long_bit);
+    bool isLongValue(MathLib::biguint value) const {
+        const MathLib::biguint longMax = max_value(long_bit);
         return value <= longMax;
     }
 
-    bool isLongLongValue(unsigned long long value) const {
-        const unsigned long long longLongMax = max_value(long_long_bit);
+    bool isLongLongValue(MathLib::biguint value) const {
+        const MathLib::biguint longLongMax = max_value(long_long_bit);
         return value <= longLongMax;
     }
 
-    nonneg int char_bit;       /// bits in char
-    nonneg int short_bit;      /// bits in short
-    nonneg int int_bit;        /// bits in int
-    nonneg int long_bit;       /// bits in long
-    nonneg int long_long_bit;  /// bits in long long
+    std::uint8_t char_bit;       /// bits in char
+    std::uint8_t short_bit;      /// bits in short
+    std::uint8_t int_bit;        /// bits in int
+    std::uint8_t long_bit;       /// bits in long
+    std::uint8_t long_long_bit;  /// bits in long long
 
     /** size of standard types */
     std::size_t sizeof_bool;
