@@ -64,8 +64,8 @@ void ProgramMemory::setValue(const Token* expr, const ValueFlow::Value& value) {
     const Token* subexpr = solveExprValue(
         expr,
         [&](const Token* tok) -> std::vector<MathLib::bigint> {
-        if (tok->hasKnownIntValue())
-            return {tok->values().front().intvalue};
+        if (const ValueFlow::Value* v = tok->getKnownValue(ValueFlow::Value::ValueType::INT))
+            return {v->intvalue};
         MathLib::bigint result = 0;
         if (getIntValue(tok->exprId(), result))
             return {result};
@@ -305,8 +305,8 @@ static void programMemoryParseCondition(ProgramMemory& pm, const Token* tok, con
     auto eval = [&](const Token* t) -> std::vector<MathLib::bigint> {
         if (!t)
             return std::vector<MathLib::bigint>{};
-        if (t->hasKnownIntValue())
-            return {t->values().front().intvalue};
+        if (const ValueFlow::Value* v = t->getKnownValue(ValueFlow::Value::ValueType::INT))
+            return {v->intvalue};
         MathLib::bigint result = 0;
         bool error = false;
         execute(t, pm, &result, &error, settings);
@@ -369,7 +369,7 @@ static void fillProgramMemoryFromConditions(ProgramMemory& pm, const Scope* scop
         return;
     assert(scope != scope->nestedIn);
     fillProgramMemoryFromConditions(pm, scope->nestedIn, endTok, settings);
-    if (scope->type == Scope::eIf || scope->type == Scope::eWhile || scope->type == Scope::eElse || scope->type == Scope::eFor) {
+    if (scope->type == ScopeType::eIf || scope->type == ScopeType::eWhile || scope->type == ScopeType::eElse || scope->type == ScopeType::eFor) {
         const Token* condTok = getCondTokFromEnd(scope->bodyEnd);
         if (!condTok)
             return;
@@ -377,7 +377,7 @@ static void fillProgramMemoryFromConditions(ProgramMemory& pm, const Scope* scop
         bool error = false;
         execute(condTok, pm, &result, &error, settings);
         if (error)
-            programMemoryParseCondition(pm, condTok, endTok, settings, scope->type != Scope::eElse);
+            programMemoryParseCondition(pm, condTok, endTok, settings, scope->type != ScopeType::eElse);
     }
 }
 
@@ -669,16 +669,17 @@ static ValueFlow::Value evaluate(const std::string& op, const ValueFlow::Value&
     return result;
 }
 
-using BuiltinLibraryFunction = std::function<ValueFlow::Value(const std::vector<ValueFlow::Value>&)>;
+using BuiltinLibraryFunction = std::function<ValueFlow::Value (const std::vector<ValueFlow::Value>&)>;
 static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibraryFunctions()
 {
     std::unordered_map<std::string, BuiltinLibraryFunction> functions;
     functions["strlen"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!(v.isTokValue() && v.tokvalue->tokType() == Token::eString))
+        const ValueFlow::Value& v_ref = args[0];
+        if (!(v_ref.isTokValue() && v_ref.tokvalue->tokType() == Token::eString))
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.valueType = ValueFlow::Value::ValueType::INT;
         v.intvalue = Token::getStrLength(v.tokvalue);
         v.tokvalue = nullptr;
@@ -717,9 +718,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["sin"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::sin(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -727,9 +729,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["lgamma"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::lgamma(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -737,9 +740,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["cos"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::cos(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -747,9 +751,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["tan"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::tan(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -757,9 +762,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["asin"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::asin(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -767,9 +773,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["acos"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::acos(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -777,9 +784,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["atan"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::atan(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -919,9 +927,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["ilogb"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.intvalue = std::ilogb(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::INT;
         return v;
@@ -929,9 +938,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["erf"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::erf(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -939,9 +949,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["erfc"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::erfc(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -949,9 +960,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["floor"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::floor(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -959,9 +971,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["sqrt"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::sqrt(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -969,9 +982,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["cbrt"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::cbrt(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -979,9 +993,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["ceil"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::ceil(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -989,9 +1004,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["exp"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::exp(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -999,9 +1015,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["exp2"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::exp2(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1009,9 +1026,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["expm1"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::expm1(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1019,9 +1037,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["fabs"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::fabs(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1029,9 +1048,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["log"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::log(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1039,9 +1059,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["log10"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::log10(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1049,9 +1070,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["log1p"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::log1p(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1059,9 +1081,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["log2"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::log2(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1069,9 +1092,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["logb"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::logb(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1079,9 +1103,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["nearbyint"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::nearbyint(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1089,9 +1114,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["sinh"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::sinh(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1099,9 +1125,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["cosh"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::cosh(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1109,9 +1136,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["tanh"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::tanh(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1119,9 +1147,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["asinh"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::asinh(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1129,9 +1158,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["acosh"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::acosh(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1139,9 +1169,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["atanh"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::atanh(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1149,9 +1180,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["round"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::round(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1159,9 +1191,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["tgamma"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::tgamma(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1169,9 +1202,10 @@ static std::unordered_map<std::string, BuiltinLibraryFunction> createBuiltinLibr
     functions["trunc"] = [](const std::vector<ValueFlow::Value>& args) {
         if (args.size() != 1)
             return ValueFlow::Value::unknown();
-        ValueFlow::Value v = args[0];
-        if (!v.isFloatValue() && !v.isIntValue())
+        const ValueFlow::Value& v_ref = args[0];
+        if (!v_ref.isFloatValue() && !v_ref.isIntValue())
             return ValueFlow::Value::unknown();
+        ValueFlow::Value v = v_ref;
         v.floatValue = std::trunc(asFloat(args[0]));
         v.valueType = ValueFlow::Value::ValueType::FLOAT;
         return v;
@@ -1372,7 +1406,7 @@ namespace {
             if (!expr)
                 return unknown();
             if (expr->hasKnownIntValue() && !expr->isAssignmentOp() && expr->str() != ",")
-                return expr->values().front();
+                return *expr->getKnownValue(ValueFlow::Value::ValueType::INT);
             if ((value = expr->getKnownValue(ValueFlow::Value::ValueType::FLOAT)) ||
                 (value = expr->getKnownValue(ValueFlow::Value::ValueType::TOK)) ||
                 (value = expr->getKnownValue(ValueFlow::Value::ValueType::ITERATOR_START)) ||
@@ -1477,10 +1511,12 @@ namespace {
                     return ValueFlow::Value{};
             } else if (Token::Match(expr, "%cop%") && expr->astOperand1() && expr->astOperand2()) {
                 ValueFlow::Value lhs = execute(expr->astOperand1());
+                if (lhs.isUninitValue())
+                    return unknown();
                 ValueFlow::Value rhs = execute(expr->astOperand2());
-                ValueFlow::Value r = unknown();
-                if (!lhs.isUninitValue() && !rhs.isUninitValue())
-                    r = evaluate(expr->str(), lhs, rhs);
+                if (rhs.isUninitValue())
+                    return unknown();
+                ValueFlow::Value r = evaluate(expr->str(), lhs, rhs);
                 if (expr->isComparisonOp() && (r.isUninitValue() || r.isImpossible())) {
                     if (rhs.isIntValue() && !expr->astOperand1()->values().empty()) {
                         std::vector<ValueFlow::Value> result = infer(makeIntegralInferModel(),
@@ -1750,11 +1786,11 @@ static std::shared_ptr<Token> createTokenFromExpression(const std::string& retur
                                                         bool cpp,
                                                         std::unordered_map<nonneg int, const Token*>& lookupVarId)
 {
-    std::shared_ptr<TokenList> tokenList = std::make_shared<TokenList>(&settings);
+    std::shared_ptr<TokenList> tokenList = std::make_shared<TokenList>(settings, cpp ? Standards::Language::CPP : Standards::Language::C);
     {
         const std::string code = "return " + returnValue + ";";
         std::istringstream istr(code);
-        if (!tokenList->createTokens(istr, cpp ? Standards::Language::CPP : Standards::Language::C))
+        if (!tokenList->createTokens(istr))
             return nullptr;
     }
 
