@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2024 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -203,8 +203,8 @@ namespace {
                 if (tok->index() >= i)
                     throw InternalError(tok, "Cyclic reverse analysis.");
                 i = tok->index();
-                if (tok == start || (tok->str() == "{" && (tok->scope()->type == Scope::ScopeType::eFunction ||
-                                                           tok->scope()->type == Scope::ScopeType::eLambda))) {
+                if (tok == start || (tok->str() == "{" && (tok->scope()->type == ScopeType::eFunction ||
+                                                           tok->scope()->type == ScopeType::eLambda))) {
                     const Function* f = tok->scope()->function;
                     if (f && f->isConstructor()) {
                         if (const Token* initList = f->constructorMemberInitialization())
@@ -367,9 +367,9 @@ namespace {
                 }
                 if (tok->str() == "case") {
                     const Scope* scope = tok->scope();
-                    while (scope && scope->type != Scope::eSwitch)
+                    while (scope && scope->type != ScopeType::eSwitch)
                         scope = scope->nestedIn;
-                    if (!scope || scope->type != Scope::eSwitch)
+                    if (!scope || scope->type != ScopeType::eSwitch)
                         break;
                     tok = tok->tokAt(scope->bodyStart->index() - tok->index() - 1);
                     continue;
