@@ -22,6 +22,7 @@
 #include "errortypes.h"
 #include "filesettings.h"
 #include "path.h"
+#include "pathmatch.h"
 #include "utils.h"
 #include "token.h"
 #include "tokenize.h"
@@ -48,6 +49,7 @@ SuppressionList::ErrorMessage SuppressionList::ErrorMessage::fromErrorMessage(co
         ret.setFileName(msg.callStack.back().getfile(false));
         ret.lineNumber = msg.callStack.back().line;
     } else {
+        ret.setFileName(msg.file0);
         ret.lineNumber = SuppressionList::Suppression::NO_LINE;
     }
     ret.certainty = msg.certainty;
@@ -97,7 +99,7 @@ std::string SuppressionList::parseFile(std::istream &istr)
         if (pos < line.size() - 1 && line[pos] == '/' && line[pos + 1] == '/')
             continue;
 
-        const std::string errmsg(addSuppressionLine(line));
+        std::string errmsg(addSuppressionLine(line));
         if (!errmsg.empty())
             return errmsg;
     }
@@ -139,7 +141,7 @@ std::string SuppressionList::parseXmlFile(const char *filename)
                 return std::string("unknown element '") + name + "' in suppressions XML '" + filename + "', expected id/fileName/lineNumber/symbolName/hash.";
         }
 
-        const std::string err = addSuppression(std::move(s));
+        std::string err = addSuppression(std::move(s));
         if (!err.empty())
             return err;
     }
@@ -204,7 +206,7 @@ std::vector<SuppressionList::Suppression> SuppressionList::parseMultiSuppressCom
     return suppressions;
 }
 
-std::string SuppressionList::addSuppressionLine(const std::string &line)
+SuppressionList::Suppression SuppressionList::parseLine(const std::string &line)
 {
     std::istringstream lineStream;
     SuppressionList::Suppression suppression;
@@ -249,7 +251,12 @@ std::string SuppressionList::addSuppressionLine(const std::string &line)
 
     suppression.fileName = Path::simplifyPath(suppression.fileName);
 
-    return addSuppression(std::move(suppression));
+    return suppression;
+}
+
+std::string SuppressionList::addSuppressionLine(const std::string &line)
+{
+    return addSuppression(parseLine(line));
 }
 
 std::string SuppressionList::addSuppression(SuppressionList::Suppression suppression)
@@ -305,9 +312,13 @@ bool SuppressionList::updateSuppressionState(const SuppressionList::Suppression&
     auto foundSuppression = std::find_if(mSuppressions.begin(), mSuppressions.end(),
                                          std::bind(&Suppression::isSameParameters, &suppression, std::placeholders::_1));
     if (foundSuppression != mSuppressions.end()) {
-        // Update matched state of existing global suppression
-        if (!suppression.isLocal() && suppression.matched)
-            foundSuppression->matched = suppression.matched;
+        // Update state of existing global suppression
+        if (!suppression.isLocal()) {
+            if (suppression.checked)
+                foundSuppression->checked = true;
+            if (suppression.matched)
+                foundSuppression->matched = true;
+        }
         return true;
     }
 
@@ -324,15 +335,24 @@ bool SuppressionList::Suppression::parseComment(std::string comment, std::string
     if (comment.size() < 2)
         return false;
 
-    if (comment.find(';') != std::string::npos)
-        comment.erase(comment.find(';'));
-
-    if (comment.find("//", 2) != std::string::npos)
-        comment.erase(comment.find("//",2));
-
     if (comment.compare(comment.size() - 2, 2, "*/") == 0)
         comment.erase(comment.size() - 2, 2);
 
+    std::string::size_type extraPos = comment.find(';');
+    std::string::size_type extraDelimiterSize = 1;
+
+    if (extraPos == std::string::npos) {
+        extraPos = comment.find("//", 2);
+        extraDelimiterSize = 2;
+    }
+
+    if (extraPos != std::string::npos) {
+        extraComment = trim(comment.substr(extraPos + extraDelimiterSize));
+        for (auto it = extraComment.begin(); it != extraComment.end();)
+            it = *it & 0x80 ? extraComment.erase(it) : it + 1;
+        comment.erase(extraPos);
+    }
+
     const std::set<std::string> cppchecksuppress{
         "cppcheck-suppress",
         "cppcheck-suppress-begin",
@@ -367,26 +387,32 @@ bool SuppressionList::Suppression::parseComment(std::string comment, std::string
     return true;
 }
 
-bool SuppressionList::Suppression::isSuppressed(const SuppressionList::ErrorMessage &errmsg) const
+SuppressionList::Suppression::Result SuppressionList::Suppression::isSuppressed(const SuppressionList::ErrorMessage &errmsg) const
 {
-    if (hash > 0 && hash != errmsg.hash)
-        return false;
-    if (!errorId.empty() && !matchglob(errorId, errmsg.errorId))
-        return false;
     if (type == SuppressionList::Type::macro) {
         if (errmsg.macroNames.count(macroName) == 0)
-            return false;
+            return Result::None;
+        if (hash > 0 && hash != errmsg.hash)
+            return Result::Checked;
+        if (!errorId.empty() && !matchglob(errorId, errmsg.errorId))
+            return Result::Checked;
     } else {
-        if (!fileName.empty() && !matchglob(fileName, errmsg.getFileName()))
-            return false;
         if ((SuppressionList::Type::unique == type) && (lineNumber != NO_LINE) && (lineNumber != errmsg.lineNumber)) {
             if (!thisAndNextLine || lineNumber + 1 != errmsg.lineNumber)
-                return false;
+                return Result::None;
         }
+        if (!fileName.empty() && fileName != errmsg.getFileName() && !PathMatch::match(fileName, errmsg.getFileName()))
+            return Result::None;
+        if (hash > 0 && hash != errmsg.hash)
+            return Result::Checked;
+        // the empty check is a hack to allow wildcard suppressions on IDs to be marked as checked
+        if (!errorId.empty() && (errmsg.errorId.empty() || !matchglob(errorId, errmsg.errorId)))
+            return Result::Checked;
         if ((SuppressionList::Type::block == type) && ((errmsg.lineNumber < lineBegin) || (errmsg.lineNumber > lineEnd)))
-            return false;
+            return Result::Checked;
     }
     if (!symbolName.empty()) {
+        bool matchedSymbol = false;
         for (std::string::size_type pos = 0; pos < errmsg.symbolNames.size();) {
             const std::string::size_type pos2 = errmsg.symbolNames.find('\n',pos);
             std::string symname;
@@ -397,21 +423,31 @@ bool SuppressionList::Suppression::isSuppressed(const SuppressionList::ErrorMess
                 symname = errmsg.symbolNames.substr(pos,pos2-pos);
                 pos = pos2+1;
             }
-            if (matchglob(symbolName, symname))
-                return true;
+            if (matchglob(symbolName, symname)) {
+                matchedSymbol = true;
+                break;
+            }
         }
-        return false;
+        if (!matchedSymbol)
+            return Result::Checked;
     }
-    return true;
+    return Result::Matched;
 }
 
 bool SuppressionList::Suppression::isMatch(const SuppressionList::ErrorMessage &errmsg)
 {
-    if (!isSuppressed(errmsg))
+    switch (isSuppressed(errmsg)) {
+    case Result::None:
         return false;
-    matched = true;
-    checked = true;
-    return true;
+    case Result::Checked:
+        checked = true;
+        return false;
+    case Result::Matched:
+        checked = true;
+        matched = true;
+        return true;
+    }
+    cppcheck::unreachable();
 }
 
 // cppcheck-suppress unusedFunction - used by GUI only
@@ -506,18 +542,28 @@ void SuppressionList::dump(std::ostream & out) const
             out << " type=\"blockEnd\"";
         else if (suppression.type == SuppressionList::Type::macro)
             out << " type=\"macro\"";
+        if (suppression.isInline)
+            out << " inline=\"true\"";
+        else
+            out << " inline=\"false\"";
+        if (!suppression.extraComment.empty())
+            out << " comment=\"" << ErrorLogger::toxml(suppression.extraComment) << "\"";
         out << " />" << std::endl;
     }
     out << "  </suppressions>" << std::endl;
 }
 
-std::list<SuppressionList::Suppression> SuppressionList::getUnmatchedLocalSuppressions(const FileWithDetails &file, const bool unusedFunctionChecking) const
+std::list<SuppressionList::Suppression> SuppressionList::getUnmatchedLocalSuppressions(const FileWithDetails &file, const bool includeUnusedFunction) const
 {
     std::lock_guard<std::mutex> lg(mSuppressionsSync);
 
     std::list<Suppression> result;
     for (const Suppression &s : mSuppressions) {
-        if (s.matched || ((s.lineNumber != Suppression::NO_LINE) && !s.checked))
+        if (s.isInline)
+            continue;
+        if (s.matched)
+            continue;
+        if ((s.lineNumber != Suppression::NO_LINE) && !s.checked)
             continue;
         if (s.type == SuppressionList::Type::macro)
             continue;
@@ -525,7 +571,7 @@ std::list<SuppressionList::Suppression> SuppressionList::getUnmatchedLocalSuppre
             continue;
         if (s.errorId == ID_CHECKERSREPORT)
             continue;
-        if (!unusedFunctionChecking && s.errorId == ID_UNUSEDFUNCTION)
+        if (!includeUnusedFunction && s.errorId == ID_UNUSEDFUNCTION)
             continue;
         if (!s.isLocal() || s.fileName != file.spath())
             continue;
@@ -534,17 +580,21 @@ std::list<SuppressionList::Suppression> SuppressionList::getUnmatchedLocalSuppre
     return result;
 }
 
-std::list<SuppressionList::Suppression> SuppressionList::getUnmatchedGlobalSuppressions(const bool unusedFunctionChecking) const
+std::list<SuppressionList::Suppression> SuppressionList::getUnmatchedGlobalSuppressions(const bool includeUnusedFunction) const
 {
     std::lock_guard<std::mutex> lg(mSuppressionsSync);
 
     std::list<Suppression> result;
     for (const Suppression &s : mSuppressions) {
-        if (s.matched || ((s.lineNumber != Suppression::NO_LINE) && !s.checked))
+        if (s.isInline)
+            continue;
+        if (s.matched)
+            continue;
+        if (!s.checked && s.isWildcard())
             continue;
         if (s.hash > 0)
             continue;
-        if (!unusedFunctionChecking && s.errorId == ID_UNUSEDFUNCTION)
+        if (!includeUnusedFunction && s.errorId == ID_UNUSEDFUNCTION)
             continue;
         if (s.errorId == ID_CHECKERSREPORT)
             continue;
@@ -555,6 +605,26 @@ std::list<SuppressionList::Suppression> SuppressionList::getUnmatchedGlobalSuppr
     return result;
 }
 
+std::list<SuppressionList::Suppression> SuppressionList::getUnmatchedInlineSuppressions(const bool includeUnusedFunction) const
+{
+    std::list<SuppressionList::Suppression> result;
+    for (const SuppressionList::Suppression &s : SuppressionList::mSuppressions) {
+        if (!s.isInline)
+            continue;
+        // TODO: remove this and markUnmatchedInlineSuppressionsAsChecked()?
+        if (!s.checked)
+            continue;
+        if (s.matched)
+            continue;
+        if (s.hash > 0)
+            continue;
+        if (!includeUnusedFunction && s.errorId == ID_UNUSEDFUNCTION)
+            continue;
+        result.push_back(s);
+    }
+    return result;
+}
+
 std::list<SuppressionList::Suppression> SuppressionList::getSuppressions() const
 {
     std::lock_guard<std::mutex> lg(mSuppressionsSync);
