@@ -41,13 +41,13 @@
 #include <vector>
 
 class Platform;
-class ErrorLogger;
 class Function;
 class Scope;
 class Settings;
 class SymbolDatabase;
 class Tokenizer;
 class ValueType;
+class ErrorLogger;
 
 enum class Reference : std::uint8_t {
     None,
@@ -704,6 +704,8 @@ private:
     void evaluate(const Settings& settings);
 };
 
+enum class FunctionType : std::uint8_t { eConstructor, eCopyConstructor, eMoveConstructor, eOperatorEqual, eDestructor, eFunction, eLambda };
+
 class CPPCHECKLIB Function {
     // only symbol database can change this
     friend class SymbolDatabase;
@@ -756,8 +758,6 @@ class CPPCHECKLIB Function {
     }
 
 public:
-    enum Type : std::uint8_t { eConstructor, eCopyConstructor, eMoveConstructor, eOperatorEqual, eDestructor, eFunction, eLambda };
-
     Function(const Token *tok, const Scope *scope, const Token *tokDef, const Token *tokArgDef);
     Function(const Token *tokenDef, const std::string &clangType);
 
@@ -777,7 +777,7 @@ public:
     nonneg int initializedArgCount() const {
         return initArgCount;
     }
-    void addArguments(const SymbolDatabase *symbolDatabase, const Scope *scope);
+    void addArguments(const Scope *scope);
 
     /** @brief check if this function is virtual in the base classes */
     bool isImplicitlyVirtual(bool defaultVal = false, bool* pFoundAllBaseClasses = nullptr) const;
@@ -788,17 +788,17 @@ public:
     const Function *getOverriddenFunction(bool *foundAllBaseClasses = nullptr) const;
 
     bool isLambda() const {
-        return type==eLambda;
+        return type==FunctionType::eLambda;
     }
 
     bool isConstructor() const {
-        return type==eConstructor ||
-               type==eCopyConstructor ||
-               type==eMoveConstructor;
+        return type==FunctionType::eConstructor ||
+               type==FunctionType::eCopyConstructor ||
+               type==FunctionType::eMoveConstructor;
     }
 
     bool isDestructor() const {
-        return type==eDestructor;
+        return type==FunctionType::eDestructor;
     }
     bool isAttributeConstructor() const {
         return tokenDef->isAttributeConstructor();
@@ -926,7 +926,7 @@ public:
     const Scope* nestedIn{};          ///< Scope the function is declared in
     std::list<Variable> argumentList; ///< argument list, must remain list due to clangimport usage!
     nonneg int initArgCount{};        ///< number of args with default values
-    Type type = eFunction;            ///< constructor, destructor, ...
+    FunctionType type = FunctionType::eFunction; ///< constructor, destructor, ...
     const Token* noexceptArg{};       ///< noexcept token
     const Token* throwArg{};          ///< throw token
     const Token* templateDef{};       ///< points to 'template <' before function
@@ -1026,6 +1026,8 @@ private:
     RET_NONNULL const Token *setFlags(const Token *tok1, const Scope *scope);
 };
 
+enum class ScopeType : std::uint8_t { eGlobal, eClass, eStruct, eUnion, eNamespace, eFunction, eIf, eElse, eFor, eWhile, eDo, eSwitch, eUnconditional, eTry, eCatch, eLambda, eEnum };
+
 class CPPCHECKLIB Scope {
     // let tests access private function for testing
     friend class TestSymbolDatabase;
@@ -1036,12 +1038,10 @@ public:
         const Scope *scope;
     };
 
-    enum ScopeType : std::uint8_t { eGlobal, eClass, eStruct, eUnion, eNamespace, eFunction, eIf, eElse, eFor, eWhile, eDo, eSwitch, eUnconditional, eTry, eCatch, eLambda, eEnum };
+    Scope(const SymbolDatabase &symdb_, const Token *classDef_, const Scope *nestedIn_);
+    Scope(const SymbolDatabase &symdb_, const Token *classDef_, const Scope *nestedIn_, ScopeType type_, const Token *start_);
 
-    Scope(const SymbolDatabase *check_, const Token *classDef_, const Scope *nestedIn_);
-    Scope(const SymbolDatabase *check_, const Token *classDef_, const Scope *nestedIn_, ScopeType type_, const Token *start_);
-
-    const SymbolDatabase* check{};
+    const SymbolDatabase& symdb;
     std::string className;
     const Token* classDef{};   ///< class/struct/union/namespace token
     const Token* bodyStart{};  ///< '{' token
@@ -1101,7 +1101,7 @@ public:
 
     static Function* nestedInFunction(const Scope* scope) {
         while (scope) {
-            if (scope->type == Scope::eFunction)
+            if (scope->type == ScopeType::eFunction)
                 break;
             scope = scope->nestedIn;
         }
@@ -1111,26 +1111,26 @@ public:
     }
 
     bool isClassOrStruct() const {
-        return (type == eClass || type == eStruct);
+        return (type == ScopeType::eClass || type == ScopeType::eStruct);
     }
 
     bool isClassOrStructOrUnion() const {
-        return (type == eClass || type == eStruct || type == eUnion);
+        return (type == ScopeType::eClass || type == ScopeType::eStruct || type == ScopeType::eUnion);
     }
 
     bool isExecutable() const {
-        return type != eClass && type != eStruct && type != eUnion && type != eGlobal && type != eNamespace && type != eEnum;
+        return type != ScopeType::eClass && type != ScopeType::eStruct && type != ScopeType::eUnion && type != ScopeType::eGlobal && type != ScopeType::eNamespace && type != ScopeType::eEnum;
     }
 
     bool isLoopScope() const {
-        return type == Scope::ScopeType::eFor || type == Scope::ScopeType::eWhile || type == Scope::ScopeType::eDo;
+        return type == ScopeType::eFor || type == ScopeType::eWhile || type == ScopeType::eDo;
     }
 
     bool isLocal() const {
-        return (type == eIf || type == eElse ||
-                type == eFor || type == eWhile || type == eDo ||
-                type == eSwitch || type == eUnconditional ||
-                type == eTry || type == eCatch);
+        return (type == ScopeType::eIf || type == ScopeType::eElse ||
+                type == ScopeType::eFor || type == ScopeType::eWhile || type == ScopeType::eDo ||
+                type == ScopeType::eSwitch || type == ScopeType::eUnconditional ||
+                type == ScopeType::eTry || type == ScopeType::eCatch);
     }
 
     // Is there lambda/inline function(s) in this scope?
@@ -1158,10 +1158,10 @@ public:
 
     void addVariable(const Token *token_, const Token *start_,
                      const Token *end_, AccessControl access_, const Type *type_,
-                     const Scope *scope_, const Settings& settings);
+                     const Scope *scope_);
 
     /** @brief initialize varlist */
-    void getVariableList(const Settings& settings);
+    void getVariableList();
 
     const Function *getDestructor() const;
 
@@ -1179,10 +1179,9 @@ public:
      * @brief check if statement is variable declaration and add it if it is
      * @param tok pointer to start of statement
      * @param varaccess access control of statement
-     * @param settings Settings
      * @return pointer to last token
      */
-    const Token *checkVariable(const Token *tok, AccessControl varaccess, const Settings& settings);
+    const Token *checkVariable(const Token *tok, AccessControl varaccess);
 
     /**
      * @brief get variable from name
@@ -1207,10 +1206,10 @@ private:
      */
     bool isVariableDeclaration(const Token* tok, const Token*& vartok, const Token*& typetok) const;
 
-    void findFunctionInBase(const std::string & name, nonneg int args, std::vector<const Function *> & matches) const;
+    void findFunctionInBase(const Token* tok, nonneg int args, std::vector<const Function *> & matches) const;
 
     /** @brief initialize varlist */
-    void getVariableList(const Settings& settings, const Token *start, const Token *end);
+    void getVariableList(const Token *start, const Token *end);
 };
 
 /** Value type */
@@ -1238,7 +1237,7 @@ public:
         DOUBLE,
         LONGDOUBLE
     } type = UNKNOWN_TYPE;
-    nonneg int bits{};                         ///< bitfield bitcount
+    int bits{};                                ///< bitfield bitcount
     nonneg int pointer{};                      ///< 0=>not pointer, 1=>*, 2=>**, 3=>***, etc
     nonneg int constness{};                    ///< bit 0=data, bit 1=*, bit 2=**
     nonneg int volatileness{};                 ///< bit 0=data, bit 1=*, bit 2=**
@@ -1306,7 +1305,7 @@ public:
     bool fromLibraryType(const std::string &typestr, const Settings &settings);
 
     bool isEnum() const {
-        return typeScope && typeScope->type == Scope::eEnum;
+        return typeScope && typeScope->type == ScopeType::eEnum;
     }
 
     bool isConst(nonneg int indirect = 0) const;
@@ -1328,7 +1327,7 @@ public:
 class CPPCHECKLIB SymbolDatabase {
     friend class TestSymbolDatabase;
 public:
-    SymbolDatabase(Tokenizer& tokenizer, const Settings& settings, ErrorLogger& errorLogger);
+    explicit SymbolDatabase(Tokenizer& tokenizer);
     ~SymbolDatabase();
 
     /** @brief Information about all namespaces/classes/structures */
@@ -1412,7 +1411,7 @@ public:
     nonneg int sizeOfType(const Token *type) const;
 
     /** Set array dimensions when valueflow analysis is completed */
-    void setArrayDimensionsUsingValueFlow(); // cppcheck-suppress functionConst // has side effects
+    void setArrayDimensionsUsingValueFlow();
 
     void clangSetVariables(const std::vector<const Variable *> &variableList);
     void createSymbolDatabaseExprIds();
@@ -1435,14 +1434,12 @@ private:
     void createSymbolDatabaseNeedInitialization();
     void createSymbolDatabaseVariableSymbolTable();
     void createSymbolDatabaseSetScopePointers();
-    void createSymbolDatabaseSetFunctionPointers(bool firstPass); // cppcheck-suppress functionConst // has side effects
+    void createSymbolDatabaseSetFunctionPointers(bool firstPass);
     void createSymbolDatabaseSetVariablePointers();
-    // cppcheck-suppress functionConst
     void createSymbolDatabaseSetTypePointers();
     void createSymbolDatabaseSetSmartPointerType();
-    void createSymbolDatabaseEnums(); // cppcheck-suppress functionConst // has side effects
-    void createSymbolDatabaseEscapeFunctions(); // cppcheck-suppress functionConst // has side effects
-    // cppcheck-suppress functionConst
+    void createSymbolDatabaseEnums();
+    void createSymbolDatabaseEscapeFunctions();
     void createSymbolDatabaseIncompleteVars();
 
     void debugSymbolDatabase() const;
