@@ -23,7 +23,6 @@
 #include "library.h"
 #include "mathlib.h"
 #include "settings.h"
-#include "simplecpp.h"
 #include "symboldatabase.h"
 #include "tokenlist.h"
 #include "utils.h"
@@ -48,6 +47,8 @@
 #include <unordered_set>
 #include <utility>
 
+#include <simplecpp.h>
+
 namespace {
     struct less {
         template<class T, class U>
@@ -60,16 +61,17 @@ namespace {
 const std::list<ValueFlow::Value> TokenImpl::mEmptyValueList;
 const std::string Token::mEmptyString;
 
-Token::Token(TokensFrontBack &tokensFrontBack)
-    : mTokensFrontBack(tokensFrontBack)
-    , mIsC(mTokensFrontBack.list.isC())
-    , mIsCpp(mTokensFrontBack.list.isCPP())
+Token::Token(const TokenList& tokenlist, std::shared_ptr<TokensFrontBack> tokensFrontBack)
+    : mList(tokenlist)
+    , mTokensFrontBack(std::move(tokensFrontBack))
+    , mIsC(mList.isC())
+    , mIsCpp(mList.isCPP())
 {
     mImpl = new TokenImpl();
 }
 
 Token::Token(const Token* tok)
-    : Token(const_cast<Token*>(tok)->mTokensFrontBack)
+    : Token(tok->mList, const_cast<Token*>(tok)->mTokensFrontBack)
 {
     fileIndex(tok->fileIndex());
     linenr(tok->linenr());
@@ -107,12 +109,22 @@ static const std::unordered_set<std::string> controlFlowKeywords = {
 
 void Token::update_property_info()
 {
-    setFlag(fIsControlFlowKeyword, controlFlowKeywords.find(mStr) != controlFlowKeywords.end());
+    assert(mImpl);
+
+    setFlag(fIsControlFlowKeyword, false);
+    // TODO: clear fIsLong
     isStandardType(false);
 
     if (!mStr.empty()) {
-        if (mStr == "true" || mStr == "false")
-            tokType(eBoolean);
+        if (mStr == "true" || mStr == "false") {
+            if (mImpl->mVarId) {
+                if (mIsCpp)
+                    throw InternalError(this, "Internal error. VarId set for bool literal.");
+                tokType(eVariable);
+            }
+            else
+                tokType(eBoolean);
+        }
         else if (isStringLiteral(mStr)) {
             tokType(eString);
             isLong(isPrefixStringCharLiteral(mStr, '"', "L"));
@@ -121,13 +133,23 @@ void Token::update_property_info()
             tokType(eChar);
             isLong(isPrefixStringCharLiteral(mStr, '\'', "L"));
         }
-        else if (std::isalpha((unsigned char)mStr[0]) || mStr[0] == '_' || mStr[0] == '$') { // Name
+        else if (std::isalpha(static_cast<unsigned char>(mStr[0])) || mStr[0] == '_' || mStr[0] == '$') { // Name
             if (mImpl->mVarId)
                 tokType(eVariable);
-            else if (mTokensFrontBack.list.isKeyword(mStr) || mStr == "asm") // TODO: not a keyword
+            else if (mList.isKeyword(mStr)) {
                 tokType(eKeyword);
-            else if (mTokType != eVariable && mTokType != eFunction && mTokType != eType && mTokType != eKeyword)
+                update_property_isStandardType();
+                if (mTokType != eType) // cannot be a control-flow keyword when it is a type
+                    setFlag(fIsControlFlowKeyword, controlFlowKeywords.find(mStr) != controlFlowKeywords.end());
+            }
+            else if (mStr == "asm") { // TODO: not a keyword
+                tokType(eKeyword);
+            }
+            else {
                 tokType(eName);
+                // some types are not being treated as keywords
+                update_property_isStandardType();
+            }
         } else if (simplecpp::Token::isNumberLike(mStr)) {
             if ((MathLib::isInt(mStr) || MathLib::isFloat(mStr)) && mStr.find('_') == std::string::npos)
                 tokType(eNumber);
@@ -147,6 +169,7 @@ void Token::update_property_info()
                   mStr == "||" ||
                   mStr == "!"))
             tokType(eLogicalOp);
+        // TODO: should link check only apply to < and >? Token::link() suggests so
         else if (mStr.size() <= 2 && !mLink &&
                  (mStr == "==" ||
                   mStr == "!=" ||
@@ -167,11 +190,11 @@ void Token::update_property_info()
             tokType(eEllipsis);
         else
             tokType(eOther);
-
-        update_property_isStandardType();
     } else {
         tokType(eNone);
     }
+    assert(!mImpl->mVarId || mTokType == eVariable);
+    // TODO: validate type for linked token?
 }
 
 static const std::unordered_set<std::string> stdTypes = { "bool"
@@ -264,7 +287,7 @@ void Token::deleteNext(nonneg int count)
     if (mNext)
         mNext->previous(this);
     else
-        mTokensFrontBack.back = this;
+        mTokensFrontBack->back = this;
 }
 
 void Token::deletePrevious(nonneg int count)
@@ -284,7 +307,7 @@ void Token::deletePrevious(nonneg int count)
     if (mPrevious)
         mPrevious->next(this);
     else
-        mTokensFrontBack.front = this;
+        mTokensFrontBack->front = this;
 }
 
 void Token::swapWithNext()
@@ -367,10 +390,10 @@ void Token::replace(Token *replaceThis, Token *start, Token *end)
     start->previous(replaceThis->previous());
     end->next(replaceThis->next());
 
-    if (end->mTokensFrontBack.back == end) {
+    if (end->mTokensFrontBack->back == end) {
         while (end->next())
             end = end->next();
-        end->mTokensFrontBack.back = end;
+        end->mTokensFrontBack->back = end;
     }
 
     // Update mProgressValue, fileIndex and linenr
@@ -747,7 +770,7 @@ nonneg int Token::getStrArraySize(const Token *tok)
     // cppcheck-suppress shadowFunction - TODO: fix this
     const std::string str(getStringLiteral(tok->str()));
     int sizeofstring = 1;
-    for (int i = 0; i < (int)str.size(); i++) {
+    for (int i = 0; i < static_cast<int>(str.size()); i++) {
         if (str[i] == '\\')
             ++i;
         ++sizeofstring;
@@ -762,7 +785,7 @@ nonneg int Token::getStrSize(const Token *tok, const Settings &settings)
     if (tok->valueType()) {
         ValueType vt(*tok->valueType());
         vt.pointer = 0;
-        sizeofType = ValueFlow::getSizeOf(vt, settings);
+        sizeofType = ValueFlow::getSizeOf(vt, settings, ValueFlow::Accuracy::ExactOrZero);
     }
     return getStrArraySize(tok) * sizeofType;
 }
@@ -1044,10 +1067,12 @@ Token* Token::insertToken(const std::string& tokenStr, const std::string& origin
     if (mStr.empty())
         newToken = this;
     else
-        newToken = new Token(mTokensFrontBack);
+        newToken = new Token(mList, mTokensFrontBack);
     newToken->str(tokenStr);
-    newToken->originalName(originalNameStr);
-    newToken->setMacroName(macroNameStr);
+    if (!originalNameStr.empty())
+        newToken->originalName(originalNameStr);
+    if (!macroNameStr.empty())
+        newToken->setMacroName(macroNameStr);
 
     if (newToken != this) {
         newToken->mImpl->mLineNumber = mImpl->mLineNumber;
@@ -1059,7 +1084,7 @@ Token* Token::insertToken(const std::string& tokenStr, const std::string& origin
                 newToken->previous(this->previous());
                 newToken->previous()->next(newToken);
             } else {
-                mTokensFrontBack.front = newToken;
+                mTokensFrontBack->front = newToken;
             }
             this->previous(newToken);
             newToken->next(this);
@@ -1068,7 +1093,7 @@ Token* Token::insertToken(const std::string& tokenStr, const std::string& origin
                 newToken->next(this->next());
                 newToken->next()->previous(newToken);
             } else {
-                mTokensFrontBack.back = newToken;
+                mTokensFrontBack->back = newToken;
             }
             this->next(newToken);
             newToken->previous(this);
@@ -1164,7 +1189,7 @@ Token* Token::insertToken(const std::string& tokenStr, const std::string& origin
                             nameSpace += tok1->str();
                             tok1 = tok1->next();
                         }
-                        mImpl->mScopeInfo->usingNamespaces.insert(nameSpace);
+                        mImpl->mScopeInfo->usingNamespaces.insert(std::move(nameSpace));
                     }
                 }
             }
@@ -1631,7 +1656,7 @@ static void astStringXml(const Token *tok, nonneg int indent, std::ostream &out)
     }
 }
 
-void Token::printAst(bool verbose, bool xml, const std::vector<std::string> &fileNames, std::ostream &out) const
+void Token::printAst(bool xml, const std::vector<std::string> &fileNames, std::ostream &out) const
 {
     if (!xml)
         out << "\n\n##AST" << std::endl;
@@ -1648,10 +1673,8 @@ void Token::printAst(bool verbose, bool xml, const std::vector<std::string> &fil
                     << "\" column=\"" << tok->column() << "\">" << std::endl;
                 astStringXml(tok, 2U, out);
                 out << "</ast>" << std::endl;
-            } else if (verbose)
+            } else
                 out << "[" << fileNames[tok->fileIndex()] << ":" << tok->linenr() << "]" << std::endl << tok->astStringVerbose() << std::endl;
-            else
-                out << tok->astString(" ") << std::endl;
             if (tok->str() == "(")
                 tok = tok->link();
         }
@@ -1715,7 +1738,7 @@ std::string Token::astStringZ3() const
     return "(" + str() + " " + astOperand1()->astStringZ3() + " " + astOperand2()->astStringZ3() + ")";
 }
 
-void Token::printValueFlow(bool xml, std::ostream &out) const
+void Token::printValueFlow(const std::vector<std::string>& files, bool xml, std::ostream &out) const
 {
     std::string outs;
 
@@ -1742,7 +1765,7 @@ void Token::printValueFlow(bool xml, std::ostream &out) const
         else {
             if (fileIndex != tok->fileIndex()) {
                 outs += "File ";
-                outs += tok->mTokensFrontBack.list.getFiles()[tok->fileIndex()];
+                outs += files[tok->fileIndex()];
                 outs += '\n';
                 line = 0;
             }
@@ -1931,8 +1954,8 @@ const ValueFlow::Value * Token::getInvalidValue(const Token *ftok, nonneg int ar
     for (auto it = mImpl->mValues->begin(); it != mImpl->mValues->end(); ++it) {
         if (it->isImpossible())
             continue;
-        if ((it->isIntValue() && !settings.library.isIntArgValid(ftok, argnr, it->intvalue)) ||
-            (it->isFloatValue() && !settings.library.isFloatArgValid(ftok, argnr, it->floatValue))) {
+        if ((it->isIntValue() && !settings.library.isIntArgValid(ftok, argnr, it->intvalue, settings)) ||
+            (it->isFloatValue() && !settings.library.isFloatArgValid(ftok, argnr, it->floatValue, settings))) {
             if (!ret || ret->isInconclusive() || (ret->condition && !it->isInconclusive()))
                 ret = &(*it);
             if (!ret->isInconclusive() && !ret->condition)
@@ -2487,13 +2510,15 @@ std::shared_ptr<ScopeInfo2> Token::scopeInfo() const
     return mImpl->mScopeInfo;
 }
 
+// if there is a known INT value it will always be the first entry
 bool Token::hasKnownIntValue() const
 {
     if (!mImpl->mValues)
         return false;
-    return std::any_of(mImpl->mValues->begin(), mImpl->mValues->end(), [](const ValueFlow::Value& value) {
-        return value.isKnown() && value.isIntValue();
-    });
+    if (mImpl->mValues->empty())
+        return false;
+    const ValueFlow::Value& value = mImpl->mValues->front();
+    return value.isIntValue() && value.isKnown();
 }
 
 bool Token::hasKnownValue() const
@@ -2516,7 +2541,7 @@ bool Token::hasKnownSymbolicValue(const Token* tok) const
     return mImpl->mValues &&
            std::any_of(mImpl->mValues->begin(), mImpl->mValues->end(), [&](const ValueFlow::Value& value) {
         return value.isKnown() && value.isSymbolicValue() && value.tokvalue &&
-        value.tokvalue->exprId() == tok->exprId();
+               value.tokvalue->exprId() == tok->exprId();
     });
 }
 
@@ -2524,6 +2549,15 @@ const ValueFlow::Value* Token::getKnownValue(ValueFlow::Value::ValueType t) cons
 {
     if (!mImpl->mValues)
         return nullptr;
+    if (mImpl->mValues->empty())
+        return nullptr;
+    // known INT values are always the first entry
+    if (t == ValueFlow::Value::ValueType::INT) {
+        const auto& v = mImpl->mValues->front();
+        if (!v.isKnown() || !v.isIntValue())
+            return nullptr;
+        return &v;
+    }
     auto it = std::find_if(mImpl->mValues->begin(), mImpl->mValues->end(), [&](const ValueFlow::Value& value) {
         return value.isKnown() && value.valueType == t;
     });
@@ -2580,7 +2614,7 @@ const ValueFlow::Value* Token::getMovedValue() const
         return nullptr;
     const auto it = std::find_if(mImpl->mValues->begin(), mImpl->mValues->end(), [](const ValueFlow::Value& value) {
         return value.isMovedValue() && !value.isImpossible() &&
-        value.moveKind != ValueFlow::Value::MoveKind::NonMovedVariable;
+               value.moveKind != ValueFlow::Value::MoveKind::NonMovedVariable;
     });
     return it == mImpl->mValues->end() ? nullptr : &*it;
 }
@@ -2598,6 +2632,7 @@ const ValueFlow::Value* Token::getContainerSizeValue(const MathLib::bigint val)
 
 TokenImpl::~TokenImpl()
 {
+    delete mMacroName;
     delete mOriginalName;
     delete mValueType;
     delete mValues;
@@ -2685,7 +2720,3 @@ Token* findLambdaEndScope(Token* tok)
 const Token* findLambdaEndScope(const Token* tok) {
     return findLambdaEndScope(const_cast<Token*>(tok));
 }
-
-const std::string& Token::fileName() const {
-    return mTokensFrontBack.list.getFiles()[mImpl->mFileIndex];
-}
