@@ -52,6 +52,7 @@ class Variable;
 class ConstTokenRange;
 class Token;
 struct TokensFrontBack;
+class TokenList;
 
 struct ScopeInfo2 {
     ScopeInfo2(std::string name_, const Token *bodyEnd_, std::set<std::string> usingNamespaces_ = std::set<std::string>()) : name(std::move(name_)), bodyEnd(bodyEnd_), usingNamespaces(std::move(usingNamespaces_)) {}
@@ -81,7 +82,7 @@ struct TokenImpl {
     nonneg int mIndex{};
 
     /** Bitfield bit count. */
-    unsigned char mBits{};
+    short mBits = -1;
 
     // AST..
     Token* mAstOperand1{};
@@ -101,7 +102,7 @@ struct TokenImpl {
     std::string* mOriginalName{};
 
     // If this token came from a macro replacement list, this is the name of that macro
-    std::string mMacroName;
+    std::string* mMacroName{};
 
     // ValueType
     ValueType* mValueType{};
@@ -165,7 +166,8 @@ class CPPCHECKLIB Token {
     friend class TestToken;
 
 private:
-    TokensFrontBack& mTokensFrontBack;
+    const TokenList& mList;
+    std::shared_ptr<TokensFrontBack> mTokensFrontBack;
 
     static const std::string mEmptyString;
 
@@ -184,7 +186,7 @@ public:
         eNone
     };
 
-    explicit Token(TokensFrontBack &tokensFrontBack);
+    Token(const TokenList& tokenlist, std::shared_ptr<TokensFrontBack> tokensFrontBack);
     // for usage in CheckIO::ArgumentInfo only
     explicit Token(const Token *tok);
     ~Token();
@@ -480,7 +482,7 @@ public:
         setFlag(fIsStandardType, b);
     }
     bool isExpandedMacro() const {
-        return !mImpl->mMacroName.empty();
+        return !!mImpl->mMacroName;
     }
     bool isCast() const {
         return getFlag(fIsCast);
@@ -560,6 +562,12 @@ public:
     void isAttributeMaybeUnused(const bool value) {
         setFlag(fIsAttributeMaybeUnused, value);
     }
+    bool isAttributeFallthrough() const {
+        return getFlag(fIsAttributeFallthrough);
+    }
+    void isAttributeFallthrough(const bool value) {
+        setFlag(fIsAttributeFallthrough, value);
+    }
     std::vector<std::string> getAttributeAlignas() const {
         return mImpl->mAttributeAlignas ? *mImpl->mAttributeAlignas : std::vector<std::string>();
     }
@@ -734,11 +742,18 @@ public:
         setFlag(fIsInitBracket, b);
     }
 
+    bool isAnonymous() const {
+        return getFlag(fIsAnonymous);
+    }
+    void isAnonymous(bool b) {
+        setFlag(fIsAnonymous, b);
+    }
+
     // cppcheck-suppress unusedFunction
     bool isBitfield() const {
-        return mImpl->mBits > 0;
+        return mImpl->mBits >= 0;
     }
-    unsigned char bits() const {
+    short bits() const {
         return mImpl->mBits;
     }
     const std::set<TemplateSimplifier::TokenAndName*>* templateSimplifierPointers() const {
@@ -752,8 +767,14 @@ public:
             mImpl->mTemplateSimplifierPointers = new std::set<TemplateSimplifier::TokenAndName*>;
         mImpl->mTemplateSimplifierPointers->insert(tokenAndName);
     }
-    void setBits(const unsigned char b) {
-        mImpl->mBits = b;
+    bool setBits(const MathLib::bigint b) {
+        const MathLib::bigint max = std::numeric_limits<short>::max();
+        if (b > max) {
+            mImpl->mBits = max;
+            return false;
+        }
+        mImpl->mBits = b < 0 ? -1 : b;
+        return true;
     }
 
     bool isUtf8() const {
@@ -805,10 +826,13 @@ public:
     }
 
     const std::string& getMacroName() const {
-        return mImpl->mMacroName;
+        return mImpl->mMacroName ? *mImpl->mMacroName : mEmptyString;
     }
     void setMacroName(std::string name) {
-        mImpl->mMacroName = std::move(name);
+        if (!mImpl->mMacroName)
+            mImpl->mMacroName = new std::string(std::move(name));
+        else
+            *mImpl->mMacroName = std::move(name);
     }
 
     template<size_t count>
@@ -882,8 +906,6 @@ private:
     static int multiCompare(const Token *tok, const char *haystack, nonneg int varid);
 
 public:
-    const std::string& fileName() const;
-
     nonneg int fileIndex() const {
         return mImpl->mFileIndex;
     }
@@ -949,13 +971,11 @@ public:
         return mImpl->mVarId;
     }
     void varId(nonneg int id) {
+        if (mImpl->mVarId == id)
+            return;
+
         mImpl->mVarId = id;
-        if (id != 0) {
-            tokType(eVariable);
-            isStandardType(false);
-        } else {
-            update_property_info();
-        }
+        update_property_info();
     }
 
     nonneg int exprId() const {
@@ -1095,6 +1115,9 @@ public:
      * to.
      */
     void link(Token *linkToToken) {
+        if (mLink == linkToToken)
+            return;
+
         mLink = linkToToken;
         if (mStr == "<" || mStr == ">")
             update_property_info();
@@ -1300,6 +1323,9 @@ public:
 
     const ValueFlow::Value* getKnownValue(ValueFlow::Value::ValueType t) const;
     MathLib::bigint getKnownIntValue() const {
+        assert(!mImpl->mValues->empty());
+        assert(mImpl->mValues->front().isKnown());
+        assert(mImpl->mValues->front().valueType == ValueFlow::Value::ValueType::INT);
         return mImpl->mValues->front().intvalue;
     }
 
@@ -1387,34 +1413,36 @@ private:
         fIsAttributeExport      = (1ULL << 16), // __attribute__((__visibility__("default"))), __declspec(dllexport)
         fIsAttributeMaybeUnused = (1ULL << 17), // [[maybe_unused]]
         fIsAttributeNodiscard   = (1ULL << 18), // __attribute__ ((warn_unused_result)), [[nodiscard]]
-        fIsControlFlowKeyword   = (1ULL << 19), // if/switch/while/...
-        fIsOperatorKeyword      = (1ULL << 20), // operator=, etc
-        fIsComplex              = (1ULL << 21), // complex/_Complex type
-        fIsEnumType             = (1ULL << 22), // enumeration type
-        fIsName                 = (1ULL << 23),
-        fIsLiteral              = (1ULL << 24),
-        fIsTemplateArg          = (1ULL << 25),
-        fAtAddress              = (1ULL << 26), // @ 0x4000
-        fIncompleteVar          = (1ULL << 27),
-        fConstexpr              = (1ULL << 28),
-        fExternC                = (1ULL << 29),
-        fIsSplitVarDeclComma    = (1ULL << 30), // set to true when variable declarations are split up ('int a,b;' => 'int a; int b;')
-        fIsSplitVarDeclEq       = (1ULL << 31), // set to true when variable declaration with initialization is split up ('int a=5;' => 'int a; a=5;')
-        fIsImplicitInt          = (1ULL << 32), // Is "int" token implicitly added?
-        fIsInline               = (1ULL << 33), // Is this a inline type
-        fIsTemplate             = (1ULL << 34),
-        fIsSimplifedScope       = (1ULL << 35), // scope added when simplifying e.g. if (int i = ...; ...)
-        fIsRemovedVoidParameter = (1ULL << 36), // A void function parameter has been removed
-        fIsIncompleteConstant   = (1ULL << 37),
-        fIsRestrict             = (1ULL << 38), // Is this a restrict pointer type
-        fIsAtomic               = (1ULL << 39), // Is this a _Atomic declaration
-        fIsSimplifiedTypedef    = (1ULL << 40),
-        fIsFinalType            = (1ULL << 41), // Is this a type with final specifier
-        fIsInitComma            = (1ULL << 42), // Is this comma located inside some {..}. i.e: {1,2,3,4}
-        fIsInitBracket          = (1ULL << 43), // Is this bracket used as a part of variable initialization i.e: int a{5}, b(2);
+        fIsAttributeFallthrough = (1ULL << 19), // [[__fallthrough__]], [[fallthrough]]
+        fIsControlFlowKeyword   = (1ULL << 20), // if/switch/while/...
+        fIsOperatorKeyword      = (1ULL << 21), // operator=, etc
+        fIsComplex              = (1ULL << 22), // complex/_Complex type
+        fIsEnumType             = (1ULL << 23), // enumeration type
+        fIsName                 = (1ULL << 24),
+        fIsLiteral              = (1ULL << 25),
+        fIsTemplateArg          = (1ULL << 26),
+        fAtAddress              = (1ULL << 27), // @ 0x4000
+        fIncompleteVar          = (1ULL << 28),
+        fConstexpr              = (1ULL << 29),
+        fExternC                = (1ULL << 30),
+        fIsSplitVarDeclComma    = (1ULL << 31), // set to true when variable declarations are split up ('int a,b;' => 'int a; int b;')
+        fIsSplitVarDeclEq       = (1ULL << 32), // set to true when variable declaration with initialization is split up ('int a=5;' => 'int a; a=5;')
+        fIsImplicitInt          = (1ULL << 33), // Is "int" token implicitly added?
+        fIsInline               = (1ULL << 34), // Is this a inline type
+        fIsTemplate             = (1ULL << 35),
+        fIsSimplifedScope       = (1ULL << 36), // scope added when simplifying e.g. if (int i = ...; ...)
+        fIsRemovedVoidParameter = (1ULL << 37), // A void function parameter has been removed
+        fIsIncompleteConstant   = (1ULL << 38),
+        fIsRestrict             = (1ULL << 39), // Is this a restrict pointer type
+        fIsAtomic               = (1ULL << 40), // Is this a _Atomic declaration
+        fIsSimplifiedTypedef    = (1ULL << 41),
+        fIsFinalType            = (1ULL << 42), // Is this a type with final specifier
+        fIsInitComma            = (1ULL << 43), // Is this comma located inside some {..}. i.e: {1,2,3,4}
+        fIsInitBracket          = (1ULL << 44), // Is this bracket used as a part of variable initialization i.e: int a{5}, b(2);
+        fIsAnonymous            = (1ULL << 45), // Is this a token added for an unnamed member
     };
 
-    enum : std::uint8_t  {
+    enum : std::uint8_t {
         efMaxSize = sizeof(nonneg int) * 8,
         efIsUnique = efMaxSize - 2,
     };
@@ -1530,6 +1558,7 @@ public:
         mImpl->mValues = nullptr;
     }
 
+    // cppcheck-suppress unusedFunction - used in tests only
     std::string astString(const char *sep = "") const {
         std::string ret;
         if (mImpl->mAstOperand1)
@@ -1545,9 +1574,9 @@ public:
 
     std::string expressionString() const;
 
-    void printAst(bool verbose, bool xml, const std::vector<std::string> &fileNames, std::ostream &out) const;
+    void printAst(bool xml, const std::vector<std::string> &fileNames, std::ostream &out) const;
 
-    void printValueFlow(bool xml, std::ostream &out) const;
+    void printValueFlow(const std::vector<std::string>& files, bool xml, std::ostream &out) const;
 
     void scopeInfo(std::shared_ptr<ScopeInfo2> newScopeInfo);
     std::shared_ptr<ScopeInfo2> scopeInfo() const;
