@@ -31,11 +31,14 @@
 #include "standards.h"
 #include "token.h"
 
+#include <algorithm>
+#include <cassert>
 #include <cctype>
 #include <cstdint>
 #include <exception>
 #include <functional>
 #include <iostream>
+#include <iterator>
 #include <utility>
 #include <set>
 #include <stack>
@@ -43,28 +46,18 @@
 
 #include <simplecpp.h>
 
-//#define N_ASSERT_LANG
-
-#ifndef N_ASSERT_LANG
-#include <cassert>
-#define ASSERT_LANG(x) assert(x)
-#else
-#define ASSERT_LANG(x)
-#endif
-
 // How many compileExpression recursions are allowed?
 // For practical code this could be endless. But in some special torture test
 // there needs to be a limit.
 static constexpr int AST_MAX_DEPTH = 150;
 
 
-TokenList::TokenList(const Settings* settings)
-    : mTokensFrontBack(*this)
+TokenList::TokenList(const Settings& settings, Standards::Language lang)
+    : mTokensFrontBack(new TokensFrontBack)
     , mSettings(settings)
 {
-    if (mSettings && (mSettings->enforcedLang != Standards::Language::None)) {
-        mLang = mSettings->enforcedLang;
-    }
+    assert(lang != Standards::Language::None);
+    mLang = lang;
 }
 
 TokenList::~TokenList()
@@ -88,42 +81,32 @@ const std::string& TokenList::getSourceFilePath() const
 // Deallocate lists..
 void TokenList::deallocateTokens()
 {
-    deleteTokens(mTokensFrontBack.front);
-    mTokensFrontBack.front = nullptr;
-    mTokensFrontBack.back = nullptr;
+    if (mTokensFrontBack) {
+        deleteTokens(mTokensFrontBack->front);
+        mTokensFrontBack->front = nullptr;
+        mTokensFrontBack->back = nullptr;
+    }
+    // TODO: clear mOrigFiles?
     mFiles.clear();
 }
 
-void TokenList::determineCppC()
-{
-    // only try to determine if it wasn't enforced
-    if (mLang == Standards::Language::None) {
-        ASSERT_LANG(!getSourceFilePath().empty());
-        mLang = Path::identify(getSourceFilePath(), mSettings ? mSettings->cppHeaderProbe : false);
-        // TODO: cannot enable assert as this might occur for unknown extensions
-        //ASSERT_LANG(mLang != Standards::Language::None);
-        if (mLang == Standards::Language::None) {
-            // TODO: should default to C instead like we do for headers
-            // default to C++
-            mLang = Standards::Language::CPP;
-        }
-    }
-}
-
+// TODO: also update mOrigFiles?
 int TokenList::appendFileIfNew(std::string fileName)
 {
+    assert(!fileName.empty());
+
     // Has this file been tokenized already?
-    for (int i = 0; i < mFiles.size(); ++i)
-        if (Path::sameFileName(mFiles[i], fileName))
-            return i;
+    auto it = std::find_if(mFiles.cbegin(), mFiles.cend(), [&](const std::string& f) {
+        return Path::sameFileName(f, fileName);
+    });
+    if (it != mFiles.cend())
+        return static_cast<int>(std::distance(mFiles.cbegin(), it));
+
+    assert(mTokensFrontBack->front == nullptr); // has no effect if tokens have already been created
 
     // The "mFiles" vector remembers what files have been tokenized..
     mFiles.push_back(std::move(fileName));
 
-    // Update mIsC and mIsCpp properties
-    if (mFiles.size() == 1) { // Update only useful if first file added to _files
-        determineCppC();
-    }
     return mFiles.size() - 1;
 }
 
@@ -165,17 +148,17 @@ void TokenList::addtoken(const std::string& str, const nonneg int lineno, const
         }
     }
 
-    if (mTokensFrontBack.back) {
-        mTokensFrontBack.back->insertToken(str);
+    if (mTokensFrontBack->back) {
+        mTokensFrontBack->back->insertToken(str);
     } else {
-        mTokensFrontBack.front = new Token(mTokensFrontBack);
-        mTokensFrontBack.back = mTokensFrontBack.front;
-        mTokensFrontBack.back->str(str);
+        mTokensFrontBack->front = new Token(*this, mTokensFrontBack);
+        mTokensFrontBack->back = mTokensFrontBack->front;
+        mTokensFrontBack->back->str(str);
     }
 
-    mTokensFrontBack.back->linenr(lineno);
-    mTokensFrontBack.back->column(column);
-    mTokensFrontBack.back->fileIndex(fileno);
+    mTokensFrontBack->back->linenr(lineno);
+    mTokensFrontBack->back->column(column);
+    mTokensFrontBack->back->fileIndex(fileno);
 }
 
 void TokenList::addtoken(const std::string& str, const Token *locationTok)
@@ -183,17 +166,17 @@ void TokenList::addtoken(const std::string& str, const Token *locationTok)
     if (str.empty())
         return;
 
-    if (mTokensFrontBack.back) {
-        mTokensFrontBack.back->insertToken(str);
+    if (mTokensFrontBack->back) {
+        mTokensFrontBack->back->insertToken(str);
     } else {
-        mTokensFrontBack.front = new Token(mTokensFrontBack);
-        mTokensFrontBack.back = mTokensFrontBack.front;
-        mTokensFrontBack.back->str(str);
+        mTokensFrontBack->front = new Token(*this, mTokensFrontBack);
+        mTokensFrontBack->back = mTokensFrontBack->front;
+        mTokensFrontBack->back->str(str);
     }
 
-    mTokensFrontBack.back->linenr(locationTok->linenr());
-    mTokensFrontBack.back->column(locationTok->column());
-    mTokensFrontBack.back->fileIndex(locationTok->fileIndex());
+    mTokensFrontBack->back->linenr(locationTok->linenr());
+    mTokensFrontBack->back->column(locationTok->column());
+    mTokensFrontBack->back->fileIndex(locationTok->fileIndex());
 }
 
 void TokenList::addtoken(const Token * tok, const nonneg int lineno, const nonneg int column, const nonneg int fileno)
@@ -201,20 +184,20 @@ void TokenList::addtoken(const Token * tok, const nonneg int lineno, const nonne
     if (tok == nullptr)
         return;
 
-    if (mTokensFrontBack.back) {
-        mTokensFrontBack.back->insertToken(tok->str(), tok->originalName());
+    if (mTokensFrontBack->back) {
+        mTokensFrontBack->back->insertToken(tok->str(), tok->originalName());
     } else {
-        mTokensFrontBack.front = new Token(mTokensFrontBack);
-        mTokensFrontBack.back = mTokensFrontBack.front;
-        mTokensFrontBack.back->str(tok->str());
+        mTokensFrontBack->front = new Token(*this, mTokensFrontBack);
+        mTokensFrontBack->back = mTokensFrontBack->front;
+        mTokensFrontBack->back->str(tok->str());
         if (!tok->originalName().empty())
-            mTokensFrontBack.back->originalName(tok->originalName());
+            mTokensFrontBack->back->originalName(tok->originalName());
     }
 
-    mTokensFrontBack.back->linenr(lineno);
-    mTokensFrontBack.back->column(column);
-    mTokensFrontBack.back->fileIndex(fileno);
-    mTokensFrontBack.back->flags(tok->flags());
+    mTokensFrontBack->back->linenr(lineno);
+    mTokensFrontBack->back->column(column);
+    mTokensFrontBack->back->fileIndex(fileno);
+    mTokensFrontBack->back->flags(tok->flags());
 }
 
 void TokenList::addtoken(const Token *tok, const Token *locationTok)
@@ -222,20 +205,20 @@ void TokenList::addtoken(const Token *tok, const Token *locationTok)
     if (tok == nullptr || locationTok == nullptr)
         return;
 
-    if (mTokensFrontBack.back) {
-        mTokensFrontBack.back->insertToken(tok->str(), tok->originalName());
+    if (mTokensFrontBack->back) {
+        mTokensFrontBack->back->insertToken(tok->str(), tok->originalName());
     } else {
-        mTokensFrontBack.front = new Token(mTokensFrontBack);
-        mTokensFrontBack.back = mTokensFrontBack.front;
-        mTokensFrontBack.back->str(tok->str());
+        mTokensFrontBack->front = new Token(*this, mTokensFrontBack);
+        mTokensFrontBack->back = mTokensFrontBack->front;
+        mTokensFrontBack->back->str(tok->str());
         if (!tok->originalName().empty())
-            mTokensFrontBack.back->originalName(tok->originalName());
+            mTokensFrontBack->back->originalName(tok->originalName());
     }
 
-    mTokensFrontBack.back->flags(tok->flags());
-    mTokensFrontBack.back->linenr(locationTok->linenr());
-    mTokensFrontBack.back->column(locationTok->column());
-    mTokensFrontBack.back->fileIndex(locationTok->fileIndex());
+    mTokensFrontBack->back->flags(tok->flags());
+    mTokensFrontBack->back->linenr(locationTok->linenr());
+    mTokensFrontBack->back->column(locationTok->column());
+    mTokensFrontBack->back->fileIndex(locationTok->fileIndex());
 }
 
 void TokenList::addtoken(const Token *tok)
@@ -243,20 +226,22 @@ void TokenList::addtoken(const Token *tok)
     if (tok == nullptr)
         return;
 
-    if (mTokensFrontBack.back) {
-        mTokensFrontBack.back->insertToken(tok->str(), tok->originalName(), tok->getMacroName());
+    if (mTokensFrontBack->back) {
+        mTokensFrontBack->back->insertToken(tok->str(), tok->originalName(), tok->getMacroName());
     } else {
-        mTokensFrontBack.front = new Token(mTokensFrontBack);
-        mTokensFrontBack.back = mTokensFrontBack.front;
-        mTokensFrontBack.back->str(tok->str());
-        mTokensFrontBack.back->originalName(tok->originalName());
-        mTokensFrontBack.back->setMacroName(tok->getMacroName());
+        mTokensFrontBack->front = new Token(*this, mTokensFrontBack);
+        mTokensFrontBack->back = mTokensFrontBack->front;
+        mTokensFrontBack->back->str(tok->str());
+        if (!tok->originalName().empty())
+            mTokensFrontBack->back->originalName(tok->originalName());
+        if (!tok->getMacroName().empty())
+            mTokensFrontBack->back->setMacroName(tok->getMacroName());
     }
 
-    mTokensFrontBack.back->flags(tok->flags());
-    mTokensFrontBack.back->linenr(tok->linenr());
-    mTokensFrontBack.back->column(tok->column());
-    mTokensFrontBack.back->fileIndex(tok->fileIndex());
+    mTokensFrontBack->back->flags(tok->flags());
+    mTokensFrontBack->back->linenr(tok->linenr());
+    mTokensFrontBack->back->column(tok->column());
+    mTokensFrontBack->back->fileIndex(tok->fileIndex());
 }
 
 
@@ -327,37 +312,18 @@ void TokenList::insertTokens(Token *dest, const Token *src, nonneg int n)
         dest->varId(src->varId());
         dest->tokType(src->tokType());
         dest->flags(src->flags());
-        dest->setMacroName(src->getMacroName());
+        if (!src->getMacroName().empty())
+            dest->setMacroName(src->getMacroName());
         src  = src->next();
         --n;
     }
 }
 
-//---------------------------------------------------------------------------
-// Tokenize - tokenizes a given file.
 //---------------------------------------------------------------------------
 
-bool TokenList::createTokens(std::istream &code, const std::string& file0)
+bool TokenList::createTokens(std::istream &code)
 {
-    ASSERT_LANG(!file0.empty());
-
-    appendFileIfNew(file0);
-
-    return createTokensInternal(code, file0);
-}
-
-//---------------------------------------------------------------------------
-
-bool TokenList::createTokens(std::istream &code, Standards::Language lang)
-{
-    ASSERT_LANG(lang != Standards::Language::None);
-    if (mLang == Standards::Language::None) {
-        mLang = lang;
-    } else {
-        ASSERT_LANG(lang == mLang);
-    }
-
-    return createTokensInternal(code, "");
+    return createTokensInternal(code, mFiles.empty() ? "" : *mFiles.cbegin());
 }
 
 //---------------------------------------------------------------------------
@@ -385,10 +351,10 @@ void TokenList::createTokens(simplecpp::TokenList&& tokenList)
         // TODO: this points to mFiles when called from createTokens(std::istream &, const std::string&)
         mOrigFiles = mFiles = tokenList.getFiles();
     }
-    else
+    else {
+        // TODO: clear mOrigFiles?
         mFiles.clear();
-
-    determineCppC();
+    }
 
     for (const simplecpp::Token *tok = tokenList.cfront(); tok;) {
 
@@ -399,30 +365,31 @@ void TokenList::createTokens(simplecpp::TokenList&& tokenList)
         if (str.size() > 1 && str[0] == '.' && std::isdigit(str[1]))
             str = '0' + str;
 
-        if (mTokensFrontBack.back) {
-            mTokensFrontBack.back->insertToken(str);
+        if (mTokensFrontBack->back) {
+            mTokensFrontBack->back->insertToken(str);
         } else {
-            mTokensFrontBack.front = new Token(mTokensFrontBack);
-            mTokensFrontBack.back = mTokensFrontBack.front;
-            mTokensFrontBack.back->str(str);
+            mTokensFrontBack->front = new Token(*this, mTokensFrontBack);
+            mTokensFrontBack->back = mTokensFrontBack->front;
+            mTokensFrontBack->back->str(str);
         }
 
-        mTokensFrontBack.back->fileIndex(tok->location.fileIndex);
-        mTokensFrontBack.back->linenr(tok->location.line);
-        mTokensFrontBack.back->column(tok->location.col);
-        mTokensFrontBack.back->setMacroName(tok->macro);
+        mTokensFrontBack->back->fileIndex(tok->location.fileIndex);
+        mTokensFrontBack->back->linenr(tok->location.line);
+        mTokensFrontBack->back->column(tok->location.col);
+        if (!tok->macro.empty())
+            mTokensFrontBack->back->setMacroName(tok->macro);
 
         tok = tok->next;
         if (tok)
             tokenList.deleteToken(tok->previous);
     }
 
-    if (mSettings && mSettings->relativePaths) {
+    if (mSettings.relativePaths) {
         for (std::string & mFile : mFiles)
-            mFile = Path::getRelativePath(mFile, mSettings->basePaths);
+            mFile = Path::getRelativePath(mFile, mSettings.basePaths);
     }
 
-    Token::assignProgressValues(mTokensFrontBack.front);
+    Token::assignProgressValues(mTokensFrontBack->front);
 }
 
 //---------------------------------------------------------------------------
@@ -503,7 +470,7 @@ static bool iscast(const Token *tok, bool cpp)
     if (Token::Match(tok->link(), ") %assign%|,|..."))
         return false;
 
-    if (tok->previous() && tok->previous()->isName() && tok->strAt(-1) != "return" &&
+    if (tok->previous() && tok->previous()->isName() && !Token::Match(tok->previous(), "return|case") &&
         (!cpp || !Token::Match(tok->previous(), "delete|throw")))
         return false;
 
@@ -633,6 +600,10 @@ static bool iscpp11init_impl(const Token * const tok)
             if (Token::simpleMatch(castTok->astParent(), "case"))
                 return true;
         }
+        if (findParent(colonTok->previous(), [](const Token *parent){
+            return parent->str() == "case";
+        }))
+            return true;
         const Token* caseTok = colonTok->tokAt(-2);
         while (caseTok && Token::Match(caseTok->tokAt(-1), "::|%name%"))
             caseTok = caseTok->tokAt(-1);
@@ -860,7 +831,7 @@ static void compileTerm(Token *&tok, AST_state& state)
         } else if ((state.cpp && iscpp11init(tok)) || Token::simpleMatch(tok->previous(), "] {")) {
             Token *const end = tok->link();
             if (state.op.empty() || Token::Match(tok->previous(), "[{,]") || Token::Match(tok->tokAt(-2), "%name% (")) {
-                if (Token::Match(tok->tokAt(-1), "!!, { . %name% =|{")) {
+                if (Token::Match(tok->tokAt(-1), "!!, { . %name% =|{") && !Token::simpleMatch(tok->tokAt(-1), "(")) {
                     const int inArrayAssignment = state.inArrayAssignment;
                     state.inArrayAssignment = 1;
                     compileBinOp(tok, state, compileExpression);
@@ -873,6 +844,10 @@ static void compileTerm(Token *&tok, AST_state& state)
                     if (precedes(tok,end)) // typically for something like `MACRO(x, { if (c) { ... } })`, where end is the last curly, and tok is the open curly for the if
                         tok = end;
                 }
+            } else if (tok->next() == end) {
+                tok->astOperand1(state.op.top());
+                state.op.pop();
+                tok = tok->next();
             } else
                 compileBinOp(tok, state, compileExpression);
             if (tok != end)
@@ -1069,6 +1044,8 @@ static void compilePrecedence2(Token *&tok, AST_state& state)
                 compileUnaryOp(tok, state, compileExpression);
             tok = tok2->link()->next();
         } else if (Token::simpleMatch(tok->previous(), "requires {")) {
+            tok->astOperand1(state.op.top());
+            state.op.pop();
             state.op.push(tok);
             tok = tok->link()->next();
             continue;
@@ -1103,7 +1080,7 @@ static void compilePrecedence2(Token *&tok, AST_state& state)
             state.inGeneric = inGenericSaved;
             tok = tok->link()->next();
             if (Token::simpleMatch(tok, "::"))
-                compileBinOp(tok, state, compileTerm);
+                compileBinOp(tok, state, compileScope);
         } else if (iscast(tok, state.cpp) && Token::simpleMatch(tok->link(), ") {") &&
                    Token::simpleMatch(tok->link()->linkAt(1), "} [")) {
             Token *cast = tok;
@@ -1852,7 +1829,7 @@ static Token * createAstAtToken(Token *tok)
 
 void TokenList::createAst() const
 {
-    for (Token *tok = mTokensFrontBack.front; tok; tok = tok ? tok->next() : nullptr) {
+    for (Token *tok = mTokensFrontBack->front; tok; tok = tok ? tok->next() : nullptr) {
         Token* const nextTok = createAstAtToken(tok);
         if (precedes(nextTok, tok))
             throw InternalError(tok, "Syntax Error: Infinite loop when creating AST.", InternalError::AST);
@@ -1877,11 +1854,11 @@ void TokenList::validateAst(bool print) const
 {
     OnException oe{[&] {
             if (print)
-                mTokensFrontBack.front->printOut(std::cout);
+                mTokensFrontBack->front->printOut(std::cout);
         }};
     // Check for some known issues in AST to avoid crash/hang later on
     std::set<const Token*> safeAstTokens;    // list of "safe" AST tokens without endless recursion
-    for (const Token *tok = mTokensFrontBack.front; tok; tok = tok->next()) {
+    for (const Token *tok = mTokensFrontBack->front; tok; tok = tok->next()) {
         // Syntax error if binary operator only has 1 operand
         if ((tok->isAssignmentOp() || tok->isComparisonOp() || Token::Match(tok,"[|^/%]")) && tok->astOperand1() && !tok->astOperand2())
             throw InternalError(tok, "Syntax Error: AST broken, binary operator has only one operand.", InternalError::AST);
@@ -2006,7 +1983,7 @@ bool TokenList::validateToken(const Token* tok) const
 {
     if (!tok)
         return true;
-    for (const Token *t = mTokensFrontBack.front; t; t = t->next()) {
+    for (const Token *t = mTokensFrontBack->front; t; t = t->next()) {
         if (tok==t)
             return true;
     }
@@ -2015,20 +1992,17 @@ bool TokenList::validateToken(const Token* tok) const
 
 void TokenList::simplifyPlatformTypes()
 {
-    if (!mSettings)
-        return;
-
-    const bool isCPP11 = isCPP() && (mSettings->standards.cpp >= Standards::CPP11);
+    const bool isCPP11 = isCPP() && (mSettings.standards.cpp >= Standards::CPP11);
 
     enum : std::uint8_t { isLongLong, isLong, isInt } type;
 
     /** @todo This assumes a flat address space. Not true for segmented address space (FAR *). */
 
-    if (mSettings->platform.sizeof_size_t == mSettings->platform.sizeof_long)
+    if (mSettings.platform.sizeof_size_t == mSettings.platform.sizeof_long)
         type = isLong;
-    else if (mSettings->platform.sizeof_size_t == mSettings->platform.sizeof_long_long)
+    else if (mSettings.platform.sizeof_size_t == mSettings.platform.sizeof_long_long)
         type = isLongLong;
-    else if (mSettings->platform.sizeof_size_t == mSettings->platform.sizeof_int)
+    else if (mSettings.platform.sizeof_size_t == mSettings.platform.sizeof_int)
         type = isInt;
     else
         return;
@@ -2081,13 +2055,13 @@ void TokenList::simplifyPlatformTypes()
         }
     }
 
-    const std::string platform_type(mSettings->platform.toString());
+    const std::string platform_type(mSettings.platform.toString());
 
     for (Token *tok = front(); tok; tok = tok->next()) {
         if (tok->tokType() != Token::eType && tok->tokType() != Token::eName)
             continue;
 
-        const Library::PlatformType * const platformtype = mSettings->library.platform_type(tok->str(), platform_type);
+        const Library::PlatformType * const platformtype = mSettings.library.platform_type(tok->str(), platform_type);
 
         if (platformtype) {
             // check for namespace
@@ -2175,7 +2149,7 @@ void TokenList::simplifyStdType()
             continue;
         }
 
-        if (Token::Match(tok, "char|short|int|long|unsigned|signed|double|float") || (isC() && (!mSettings || (mSettings->standards.c >= Standards::C99)) && Token::Match(tok, "complex|_Complex"))) {
+        if (Token::Match(tok, "char|short|int|long|unsigned|signed|double|float") || (isC() && (mSettings.standards.c >= Standards::C99) && Token::Match(tok, "complex|_Complex"))) {
             bool isFloat= false;
             bool isSigned = false;
             bool isUnsigned = false;
@@ -2198,7 +2172,7 @@ void TokenList::simplifyStdType()
                 else if (Token::Match(tok2, "float|double")) {
                     isFloat = true;
                     typeSpec = tok2;
-                } else if (isC() && (!mSettings || (mSettings->standards.c >= Standards::C99)) && Token::Match(tok2, "complex|_Complex"))
+                } else if (isC() && (mSettings.standards.c >= Standards::C99) && Token::Match(tok2, "complex|_Complex"))
                     isComplex = !isFloat || tok2->str() == "_Complex" || Token::Match(tok2->next(), "*|&|%name%"); // Ensure that "complex" is not the variables name
                 else if (Token::Match(tok2, "char|int")) {
                     if (!typeSpec)
@@ -2237,69 +2211,40 @@ void TokenList::simplifyStdType()
 bool TokenList::isKeyword(const std::string &str) const
 {
     if (isCPP()) {
-        // TODO: integrate into keywords?
-        // types and literals are not handled as keywords
-        static const std::unordered_set<std::string> cpp_types = {"bool", "false", "true"};
-        if (cpp_types.find(str) != cpp_types.end())
-            return false;
-
-        if (mSettings) {
-            const auto &cpp_keywords = Keywords::getAll(mSettings->standards.cpp);
-            return cpp_keywords.find(str) != cpp_keywords.end();
+        const auto &cpp_keywords = Keywords::getAll(mSettings.standards.cpp);
+        const bool b = cpp_keywords.find(str) != cpp_keywords.end();
+        if (b) {
+            // TODO: integrate into keywords?
+            // types and literals are not handled as keywords
+            static const std::unordered_set<std::string> cpp_types = {"bool", "false", "true"};
+            if (cpp_types.find(str) != cpp_types.end())
+                return false;
         }
-
-        static const auto& latest_cpp_keywords = Keywords::getAll(Standards::cppstd_t::CPPLatest);
-        return latest_cpp_keywords.find(str) != latest_cpp_keywords.end();
+        return b;
     }
 
-    // TODO: integrate into Keywords?
-    // types are not handled as keywords
-    static const std::unordered_set<std::string> c_types = {"char", "double", "float", "int", "long", "short"};
-    if (c_types.find(str) != c_types.end())
-        return false;
-
-    if (mSettings) {
-        const auto &c_keywords = Keywords::getAll(mSettings->standards.c);
-        return c_keywords.find(str) != c_keywords.end();
+    const auto &c_keywords = Keywords::getAll(mSettings.standards.c);
+    const bool b = c_keywords.find(str) != c_keywords.end();
+    if (b) {
+        // TODO: integrate into Keywords?
+        // types are not handled as keywords
+        static const std::unordered_set<std::string> c_types = {"char", "double", "float", "int", "long", "short"};
+        if (c_types.find(str) != c_types.end())
+            return false;
     }
-
-    static const auto& latest_c_keywords = Keywords::getAll(Standards::cstd_t::CLatest);
-    return latest_c_keywords.find(str) != latest_c_keywords.end();
+    return b;
 }
 
 bool TokenList::isC() const
 {
-    ASSERT_LANG(mLang != Standards::Language::None);
-
-    // TODO: remove the fallback
-    if (mLang == Standards::Language::None)
-        return false; // treat as C++ by default
-
     return mLang == Standards::Language::C;
 }
 
 bool TokenList::isCPP() const
 {
-    ASSERT_LANG(mLang != Standards::Language::None);
-
-    // TODO: remove the fallback
-    if (mLang == Standards::Language::None)
-        return true; // treat as C++ by default
-
     return mLang == Standards::Language::CPP;
 }
 
-void TokenList::setLang(Standards::Language lang, bool force)
-{
-    ASSERT_LANG(lang != Standards::Language::None);
-    if (!force)
-    {
-        ASSERT_LANG(mLang == Standards::Language::None);
-    }
-
-    mLang = lang;
-}
-
 const Token * TokenList::isFunctionHead(const Token *tok, const std::string &endsWith)
 {
     if (!tok)
