@@ -26,11 +26,11 @@
 
 #include <cstddef>
 #include <iosfwd>
+#include <memory>
 #include <string>
 #include <vector>
 
 class Token;
-class TokenList;
 class Settings;
 
 namespace simplecpp {
@@ -44,21 +44,20 @@ namespace simplecpp {
  * @brief This struct stores pointers to the front and back tokens of the list this token is in.
  */
 struct TokensFrontBack {
-    explicit TokensFrontBack(const TokenList& list) : list(list) {}
     Token *front{};
     Token* back{};
-    const TokenList& list;
 };
 
 class CPPCHECKLIB TokenList {
 public:
-    // TODO: pass settings as reference
-    explicit TokenList(const Settings* settings);
+    explicit TokenList(const Settings& settings, Standards::Language lang);
     ~TokenList();
 
     TokenList(const TokenList &) = delete;
     TokenList &operator=(const TokenList &) = delete;
 
+    TokenList(TokenList&& other) NOEXCEPT = default;
+
     /** @return the source file path. e.g. "file.cpp" */
     const std::string& getSourceFilePath() const;
 
@@ -68,9 +67,6 @@ public:
     /** @return true if the code is C++ */
     bool isCPP() const;
 
-    // TODO: get rid of this
-    void setLang(Standards::Language lang, bool force = false);
-
     /**
      * Delete all tokens in given token list
      * @param tok token list to delete
@@ -103,10 +99,8 @@ public:
      * - UTF in the code are not handled.
      * - comments are not handled.
      * @param code input stream for code
-     * @param file0 source file name
      */
-    bool createTokens(std::istream &code, const std::string& file0);
-    bool createTokens(std::istream &code, Standards::Language lang);
+    bool createTokens(std::istream &code);
 
     void createTokens(simplecpp::TokenList&& tokenList);
 
@@ -118,20 +112,20 @@ public:
 
     /** get first token of list */
     const Token *front() const {
-        return mTokensFrontBack.front;
+        return mTokensFrontBack->front;
     }
     // NOLINTNEXTLINE(readability-make-member-function-const) - do not allow usage of mutable pointer from const object
     Token *front() {
-        return mTokensFrontBack.front;
+        return mTokensFrontBack->front;
     }
 
     /** get last token of list */
     const Token *back() const {
-        return mTokensFrontBack.back;
+        return mTokensFrontBack->back;
     }
     // NOLINTNEXTLINE(readability-make-member-function-const) - do not allow usage of mutable pointer from const object
     Token *back() {
-        return mTokensFrontBack.back;
+        return mTokensFrontBack->back;
     }
 
     /**
@@ -209,13 +203,15 @@ public:
      */
     static const Token * isFunctionHead(const Token *tok, const std::string &endsWith);
 
-private:
-    void determineCppC();
+    const Settings& getSettings() const {
+        return mSettings;
+    }
 
+private:
     bool createTokensInternal(std::istream &code, const std::string& file0);
 
     /** Token list */
-    TokensFrontBack mTokensFrontBack;
+    std::shared_ptr<TokensFrontBack> mTokensFrontBack;
 
     /** filenames for the tokenized source code (source + included) */
     std::vector<std::string> mFiles;
@@ -224,7 +220,7 @@ private:
     std::vector<std::string> mOrigFiles;
 
     /** settings */
-    const Settings* const mSettings{};
+    const Settings& mSettings;
 
     /** File is known to be C/C++ code */
     Standards::Language mLang{Standards::Language::None};
