@@ -40,18 +40,25 @@ int caseInsensitiveStringCompare(const std::string &lhs, const std::string &rhs)
 
 bool isValidGlobPattern(const std::string& pattern)
 {
+    int consecutiveAsterisks = 0;
     for (auto i = pattern.cbegin(); i != pattern.cend(); ++i) {
-        if (*i == '*' || *i == '?') {
-            const auto j = i + 1;
-            if (j != pattern.cend() && (*j == '*' || *j == '?')) {
+        if (*i == '*') {
+            ++consecutiveAsterisks;
+            if (consecutiveAsterisks > 2) {
                 return false;
             }
+        } else if (*i == '?') {
+            if (consecutiveAsterisks > 0) {
+                return false;
+            }
+        } else {
+            consecutiveAsterisks = 0;
         }
     }
     return true;
 }
 
-bool matchglob(const std::string& pattern, const std::string& name)
+bool matchglob(const std::string& pattern, const std::string& name, bool caseInsensitive)
 {
     const char* p = pattern.c_str();
     const char* n = name.c_str();
@@ -83,9 +90,7 @@ bool matchglob(const std::string& pattern, const std::string& name)
                 // Non-wildcard characters match literally
                 if (*n == *p) {
                     n++;
-                } else if (*n == '\\' && *p == '/') {
-                    n++;
-                } else if (*n == '/' && *p == '\\') {
+                } else if (caseInsensitive && tolower(*n) == tolower(*p)) {
                     n++;
                 } else {
                     matching = false;
@@ -115,12 +120,6 @@ bool matchglob(const std::string& pattern, const std::string& name)
     }
 }
 
-bool matchglobs(const std::vector<std::string> &patterns, const std::string &name) {
-    return std::any_of(begin(patterns), end(patterns), [&name](const std::string &pattern) {
-        return matchglob(pattern, name);
-    });
-}
-
 void strTolower(std::string& str)
 {
     // This wrapper exists because Sun's CC does not allow a static_cast
