@@ -1,4 +1,4 @@
-void foo(int **a)
+static void foo(int **a)
 {
     int b = 1;
     **a = b;
