@@ -16,8 +16,6 @@
 #include <stdint.h>
 #include <stdio.h>
 #include <stdarg.h>
-#include <netdb.h>
-#include <sys/time.h>
 #include <sys/types.h>
 #include <pwd.h>
 #include <sys/mman.h>
@@ -36,7 +34,11 @@
 #include <netdb.h>
 #if !defined(__APPLE__)
 #include <byteswap.h>
+#include <features.h>
 #endif
+#include <sys/socket.h>
+#include <time.h>
+#include <stddef.h>
 
 #ifdef __gnu_linux__
 void unreachableCode_error(void) // #11197
@@ -58,6 +60,7 @@ int deallocuse_backtrace(int size) {
     return numEntries;
 }
 
+#if !defined(__APPLE__)
 void leakReturnValNotUsed_get_current_dir_name(void)
 {
     // cppcheck-suppress leakReturnValNotUsed
@@ -114,7 +117,6 @@ int nullPointer_gethostbyname_r(const char* name, struct hostent* ret, const cha
     return gethostbyname_r(name, ret, buf, buflen, result, h_errnop);
 }
 
-
 int nullPointer_gethostbyaddr_r(const void* addr, socklen_t len, int type, struct hostent* ret, const char* buf, size_t buflen, struct hostent** result, const int* h_errnop)
 {
     // cppcheck-suppress nullPointer
@@ -129,6 +131,7 @@ int nullPointer_gethostbyaddr_r(const void* addr, socklen_t len, int type, struc
     (void) gethostbyaddr_r(addr, len, type, ret, buf, buflen, result, NULL);
     return gethostbyaddr_r(addr, len, type, ret, buf, buflen, result, h_errnop);
 }
+#endif
 
 int nullPointer_getopt_long(int argc, char **argv, const char *optstring,
                             const struct option *longopts, int *longindex)
@@ -154,6 +157,7 @@ int nullPointer_getopt_long_only(int argc, char* const* argv, const char* optstr
     return getopt_long_only(argc, argv, optstring, longopts, longindex);
 }
 
+#if !defined(__APPLE__)
 int nullPointer_getservent_r(struct servent *restrict result_buf, const char *restrict buf, size_t buflen, struct servent **restrict result)
 {
     // cppcheck-suppress nullPointer
@@ -173,6 +177,7 @@ void *bufferAccessOutOfBounds_memrchr(const void *s, int c, size_t n)
     (void)memrchr(buf,c,43);
     return memrchr(s,c,n);
 }
+#endif
 
 void knownConditionTrueFalse_ffsl(long i)
 {
@@ -192,6 +197,7 @@ void knownConditionTrueFalse_ffsll(long long i)
     if (ffsll(i) == 0) {}
 }
 
+#if !defined(__APPLE__)
 int nullPointer_semtimedop(int semid, struct sembuf *sops, size_t nsops, const struct timespec *timeout)
 {
     (void) semtimedop(semid, sops, nsops, NULL); // If the timeout argument is NULL, then semtimedop() behaves exactly like semop().
@@ -227,8 +233,10 @@ int uninitvar_getpw(uid_t uid, char *buf)
     // cppcheck-suppress uninitvar
     return getpw(someUid, buf);
 }
+#endif
 
 // Declaration necessary because there is no specific / portable header.
+// https://www.eyrie.org/~eagle/software/rra-c-util/xmalloc.html
 extern void *xcalloc(size_t nmemb, size_t size);
 extern void *xmalloc(size_t size);
 extern void *xrealloc(void *block, size_t newsize);
@@ -294,8 +302,10 @@ void valid_code(int argInt1, va_list valist_arg, const int * parg)
 
     if (__builtin_expect(argInt1, 0)) {}
     if (__builtin_expect_with_probability(argInt1 + 1, 2, 0.5)) {}
+#ifdef __GLIBC__
     if (__glibc_unlikely(argInt1 != 0)) {}
     if (__glibc_likely(parg != NULL)) {}
+#endif
     const void *ax1 = __builtin_assume_aligned(parg, 16);
     printf("%p", ax1);
     const void *ax2 = __builtin_assume_aligned(parg, 32, 8);
@@ -489,6 +499,7 @@ void bufferAccessOutOfBounds()
     free(pAlloc2);
 }
 
+#if !defined(__APPLE__)
 void leakReturnValNotUsed()
 {
     // cppcheck-suppress [unreadVariable, constVariablePointer]
@@ -508,6 +519,7 @@ void leakReturnValNotUsed()
     if (42 == __builtin_expect(42, 0))
         return;
 }
+#endif
 
 #if !defined(__CYGWIN__) && !defined(__APPLE__)
 int nullPointer_epoll_ctl(int epfd, int op, int fd, struct epoll_event *event)
