@@ -30,6 +30,16 @@ namespace ExampleNamespace {
     {
         return (arg == TOLERANCE);
     }
+
+    // syntaxError when TYPED_TEST is not known
+    TYPED_TEST (ExampleTypedTest, cppcheck_test)
+    {
+    }
+
+    // syntaxError when TYPED_TEST_P is not known
+    TYPED_TEST_P (ExampleTypedTestP, cppcheck)
+    {
+    }
 }
 
 TEST(ASSERT, ASSERT)
