@@ -49,11 +49,19 @@ def test_json_entry_file_not_found(tmpdir):
          "output": "bug1.o"}
     ]
 
-    expected = "'{}' from compilation database does not exist".format(os.path.join(tmpdir, "bug1.cpp"))
-    if sys.platform == "win32":
-        expected = expected.replace('\\', '/')
+    project_file = os.path.join(tmpdir, "file.json")
+    missing_file = os.path.join(tmpdir, "bug1.cpp")
+    missing_file_posix = missing_file
 
-    __test_project_error(tmpdir, "json", json.dumps(compilation_db), expected)
+    if sys.platform == "win32":
+        missing_file_posix = missing_file_posix.replace('\\', '/')
+
+    with open(project_file, 'w') as f:
+        f.write(json.dumps(compilation_db))
+
+    ret, _, stderr = cppcheck(["--project=" + str(project_file)])
+    assert 0 == ret
+    assert f"{missing_file}:1:0: error: File is missing: {missing_file_posix} [syntaxError]\n\n^\n" == stderr
 
 
 def test_json_no_arguments(tmpdir):
