@@ -1,5 +1,5 @@
 // Cppcheck - A tool for static C/C++ code analysis
-// Copyright (C) 2007-2024 Cppcheck team.
+// Copyright (C) 2007-2025 Cppcheck team.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -15,17 +15,20 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "clangimport.h"
+#include "fixture.h"
 #include "platform.h"
 #include "settings.h"
+#include "standards.h"
 #include "symboldatabase.h"
 #include "token.h"
 #include "tokenize.h"
-#include "fixture.h"
+#include "tokenlist.h"
 
 #include <cstdint>
 #include <list>
 #include <sstream>
 #include <string>
+#include <utility>
 #include <vector>
 
 
@@ -139,7 +142,8 @@ private:
 
     std::string parse(const char clang[]) {
         const Settings settings = settingsBuilder().clang().build();
-        Tokenizer tokenizer(settings, *this);
+        TokenList tokenlist{settings, Standards::Language::CPP};
+        Tokenizer tokenizer(std::move(tokenlist), *this);
         std::istringstream istr(clang);
         clangimport::parseClangAstDump(tokenizer, istr);
         if (!tokenizer.tokens()) {
@@ -1059,7 +1063,8 @@ private:
 
 #define GET_SYMBOL_DB(AST) \
     const Settings settings = settingsBuilder().clang().platform(Platform::Type::Unix64).build(); \
-    Tokenizer tokenizer(settings, *this); \
+    TokenList tokenlist{settings, Standards::Language::CPP}; \
+    Tokenizer tokenizer(std::move(tokenlist), *this); \
     { \
         std::istringstream istr(AST); \
         clangimport::parseClangAstDump(tokenizer, istr); \
@@ -1093,7 +1098,7 @@ private:
         // Enum scope and type
         ASSERT_EQUALS(3, db->scopeList.size());
         const Scope &enumScope = db->scopeList.back();
-        ASSERT_EQUALS(Scope::ScopeType::eEnum, enumScope.type);
+        ASSERT_EQUALS_ENUM(ScopeType::eEnum, enumScope.type);
         ASSERT_EQUALS("abc", enumScope.className);
         const Type *enumType = enumScope.definedType;
         ASSERT_EQUALS("abc", enumType->name());
@@ -1138,8 +1143,8 @@ private:
         const Scope *scope = db->functionScopes[0];
         const Function *func = scope->function;
         ASSERT_EQUALS(2, func->argCount());
-        ASSERT_EQUALS(0, (long long)func->getArgumentVar(0)->nameToken());
-        ASSERT_EQUALS(0, (long long)func->getArgumentVar(1)->nameToken());
+        ASSERT(!func->getArgumentVar(0)->nameToken());
+        ASSERT(!func->getArgumentVar(1)->nameToken());
     }
 
     void symbolDatabaseFunction3() { // #9640
@@ -1257,7 +1262,7 @@ private:
         const Token *tok = Token::findsimplematch(tokenizer.tokens(), "i");
         ASSERT(!!tok);
         ASSERT(!!tok->variable());
-        ASSERT_EQUALS(Scope::ScopeType::eFor, tok->variable()->scope()->type);
+        ASSERT_EQUALS_ENUM(ScopeType::eFor, tok->variable()->scope()->type);
     }
 
     void valueFlow1() {
