@@ -16,28 +16,34 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "addoninfo.h"
 #include "color.h"
 #include "cppcheck.h"
 #include "errorlogger.h"
 #include "filesettings.h"
 #include "fixture.h"
 #include "helpers.h"
+#include "path.h"
+#include "preprocessor.h"
 #include "settings.h"
 #include "standards.h"
 #include "suppressions.h"
 
-#include "simplecpp.h"
-
 #include <algorithm>
+#include <cstddef>
 #include <list>
+#include <sstream>
 #include <string>
 #include <vector>
 
+#include <simplecpp.h>
+
 class TestCppcheck : public TestFixture {
 public:
     TestCppcheck() : TestFixture("TestCppcheck") {}
 
 private:
+    const std::string templateFormat{"{file}:{line}:{column}: {severity}:{inconclusive:inconclusive:} {message} [{id}]"};
 
     class ErrorLogger2 : public ErrorLogger {
     public:
@@ -51,6 +57,10 @@ private:
             ids.push_back(msg.id);
             errmsgs.push_back(msg);
         }
+
+        void reportMetric(const std::string &metric) override {
+            (void) metric;
+        }
     };
 
     void run() override {
@@ -59,10 +69,11 @@ private:
         TEST_CASE(checkWithFS);
         TEST_CASE(suppress_error_library);
         TEST_CASE(unique_errors);
+        TEST_CASE(unique_errors_2);
         TEST_CASE(isPremiumCodingStandardId);
         TEST_CASE(getDumpFileContentsRawTokens);
         TEST_CASE(getDumpFileContentsLibrary);
-        TEST_CASE(getClangFlagsIncludeFile);
+        TEST_CASE(premiumResultsCache);
     }
 
     void getErrorMessages() const {
@@ -112,11 +123,11 @@ private:
                         "  return 0;\n"
                         "}");
 
-        const Settings s;
+        const auto s = dinit(Settings, $.templateFormat = templateFormat);
         Suppressions supprs;
         ErrorLogger2 errorLogger;
         CppCheck cppcheck(s, supprs, errorLogger, false, {});
-        ASSERT_EQUALS(1, cppcheck.check(FileWithDetails(file.path())));
+        ASSERT_EQUALS(1, cppcheck.check(FileWithDetails(file.path(), Path::identify(file.path(), false), 0)));
         // TODO: how to properly disable these warnings?
         errorLogger.ids.erase(std::remove_if(errorLogger.ids.begin(), errorLogger.ids.end(), [](const std::string& id) {
             return id == "logChecker";
@@ -134,11 +145,11 @@ private:
                         "  return 0;\n"
                         "}");
 
-        const Settings s;
+        const auto s = dinit(Settings, $.templateFormat = templateFormat);
         Suppressions supprs;
         ErrorLogger2 errorLogger;
         CppCheck cppcheck(s, supprs, errorLogger, false, {});
-        FileSettings fs{file.path()};
+        FileSettings fs{file.path(), Path::identify(file.path(), false), 0};
         ASSERT_EQUALS(1, cppcheck.check(fs));
         // TODO: how to properly disable these warnings?
         errorLogger.ids.erase(std::remove_if(errorLogger.ids.begin(), errorLogger.ids.end(), [](const std::string& id) {
@@ -162,7 +173,7 @@ private:
         Suppressions supprs;
         ErrorLogger2 errorLogger;
         CppCheck cppcheck(s, supprs, errorLogger, false, {});
-        ASSERT_EQUALS(0, cppcheck.check(FileWithDetails(file.path())));
+        ASSERT_EQUALS(0, cppcheck.check(FileWithDetails(file.path(), Path::identify(file.path(), false), 0)));
         // TODO: how to properly disable these warnings?
         errorLogger.ids.erase(std::remove_if(errorLogger.ids.begin(), errorLogger.ids.end(), [](const std::string& id) {
             return id == "logChecker";
@@ -170,7 +181,7 @@ private:
         ASSERT_EQUALS(0, errorLogger.ids.size());
     }
 
-    // TODO: hwo to actually get duplicated findings
+    // TODO: how to actually get duplicated findings
     void unique_errors() const
     {
         ScopedFile file("inc.h",
@@ -183,12 +194,13 @@ private:
         ScopedFile test_file_b("b.cpp",
                                "#include \"inc.h\"");
 
-        const Settings s;
+        // this is the "simple" format
+        const auto s = dinit(Settings, $.templateFormat = templateFormat); // TODO: remove when we only longer rely on toString() in unique message handling
         Suppressions supprs;
         ErrorLogger2 errorLogger;
         CppCheck cppcheck(s, supprs, errorLogger, false, {});
-        ASSERT_EQUALS(1, cppcheck.check(FileWithDetails(test_file_a.path())));
-        ASSERT_EQUALS(1, cppcheck.check(FileWithDetails(test_file_b.path())));
+        ASSERT_EQUALS(1, cppcheck.check(FileWithDetails(test_file_a.path(), Path::identify(test_file_a.path(), false), 0)));
+        ASSERT_EQUALS(1, cppcheck.check(FileWithDetails(test_file_b.path(), Path::identify(test_file_b.path(), false), 0)));
         // TODO: how to properly disable these warnings?
         errorLogger.errmsgs.erase(std::remove_if(errorLogger.errmsgs.begin(), errorLogger.errmsgs.end(), [](const ErrorMessage& msg) {
             return msg.id == "logChecker";
@@ -196,49 +208,95 @@ private:
         // the internal errorlist is cleared after each check() call
         ASSERT_EQUALS(2, errorLogger.errmsgs.size());
         auto it = errorLogger.errmsgs.cbegin();
+        ASSERT_EQUALS("a.cpp", it->file0);
         ASSERT_EQUALS("nullPointer", it->id);
         ++it;
+        ASSERT_EQUALS("b.cpp", it->file0);
         ASSERT_EQUALS("nullPointer", it->id);
     }
 
+    void unique_errors_2() const
+    {
+        ScopedFile test_file("c.cpp",
+                             "void f()\n"
+                             "{\n"
+                             "const long m[9] = {};\n"
+                             "long a=m[9], b=m[9];\n"
+                             "(void)a;\n"
+                             "(void)b;\n"
+                             "}");
+
+        // this is the "simple" format
+        const auto s = dinit(Settings, $.templateFormat = templateFormat); // TODO: remove when we only longer rely on toString() in unique message handling?
+        Suppressions supprs;
+        ErrorLogger2 errorLogger;
+        CppCheck cppcheck(s, supprs, errorLogger, false, {});
+        ASSERT_EQUALS(1, cppcheck.check(FileWithDetails(test_file.path(), Path::identify(test_file.path(), false), 0)));
+        // TODO: how to properly disable these warnings?
+        errorLogger.errmsgs.erase(std::remove_if(errorLogger.errmsgs.begin(), errorLogger.errmsgs.end(), [](const ErrorMessage& msg) {
+            return msg.id == "logChecker";
+        }), errorLogger.errmsgs.end());
+        // the internal errorlist is cleared after each check() call
+        ASSERT_EQUALS(2, errorLogger.errmsgs.size());
+        auto it = errorLogger.errmsgs.cbegin();
+        ASSERT_EQUALS("c.cpp", it->file0);
+        ASSERT_EQUALS(1, it->callStack.size());
+        {
+            auto stack = it->callStack.cbegin();
+            ASSERT_EQUALS(4, stack->line);
+            ASSERT_EQUALS(9, stack->column);
+        }
+        ASSERT_EQUALS("arrayIndexOutOfBounds", it->id);
+        ++it;
+        ASSERT_EQUALS("c.cpp", it->file0);
+        ASSERT_EQUALS(1, it->callStack.size());
+        {
+            auto stack = it->callStack.cbegin();
+            ASSERT_EQUALS(4, stack->line);
+            ASSERT_EQUALS(17, stack->column);
+        }
+        ASSERT_EQUALS("arrayIndexOutOfBounds", it->id);
+    }
+
     void isPremiumCodingStandardId() const {
         Suppressions supprs;
         ErrorLogger2 errorLogger;
 
         {
-            Settings s;
-            s.premiumArgs = "";
+            const auto s = dinit(Settings, $.premiumArgs = "");
             CppCheck cppcheck(s, supprs, errorLogger, false, {});
 
             ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("misra-c2012-0.0"));
             ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("misra-c2023-0.0"));
-            ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-misra-c2012-0.0"));
-            ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-misra-c2023-0.0"));
-            ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-misra-c++2008-0.0.0"));
-            ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-misra-c++2023-0.0.0"));
+            ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-misra-c-2012-0.0"));
+            ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-misra-c-2023-0.0"));
+            ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-misra-c-2025-0.0"));
+            ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-misra-c-2025-dir-0.0"));
+            ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-misra-c++-2008-0-0-0"));
+            ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-misra-c++-2023-0.0.0"));
             ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-cert-int50-cpp"));
             ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("premium-autosar-0-0-0"));
         }
 
         {
-            Settings s;
-            s.premiumArgs = "--misra-c-2012 --cert-c++-2016 --autosar";
+            const auto s = dinit(Settings, $.premiumArgs = "--misra-c-2012 --cert-c++-2016 --autosar");
 
             CppCheck cppcheck(s, supprs, errorLogger, false, {});
 
-            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("misra-c2012-0.0"));
-            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("misra-c2023-0.0"));
-            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-misra-c2012-0.0"));
-            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-misra-c2023-0.0"));
-            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-misra-c++2008-0.0.0"));
-            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-misra-c++2023-0.0.0"));
+            ASSERT_EQUALS(false, cppcheck.isPremiumCodingStandardId("misra-c2012-0.0"));
+            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-misra-c-2012-0.0"));
+            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-misra-c-2023-0.0"));
+            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-misra-c-2025-0.0"));
+            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-misra-c-2025-dir-0.0"));
+            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-misra-c++-2008-0-0-0"));
+            ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-misra-c++-2023-0.0.0"));
             ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-cert-int50-cpp"));
             ASSERT_EQUALS(true, cppcheck.isPremiumCodingStandardId("premium-autosar-0-0-0"));
         }
     }
 
     void getDumpFileContentsRawTokens() const {
-        Settings s = settingsBuilder().build();
+        Settings s;
         s.relativePaths = true;
         s.basePaths.emplace_back("/some/path");
         Suppressions supprs;
@@ -275,13 +333,38 @@ private:
         }
     }
 
-    void getClangFlagsIncludeFile() const {
-        Settings s;
-        s.userIncludes.emplace_back("1.h");
+    void premiumResultsCache() const {
+        // Trac #13889 - cached misra results are shown after removing --premium=misra-c-2012 option
+
+        Settings settings;
         Suppressions supprs;
         ErrorLogger2 errorLogger;
-        CppCheck cppcheck(s, supprs, errorLogger, false, {});
-        ASSERT_EQUALS("-x c --include 1.h ", cppcheck.getClangFlags(Standards::Language::C));
+
+        std::vector<std::string> files;
+
+        std::istringstream istr("void f();\nint x;\n");
+        const simplecpp::TokenList tokens(istr, files, "m1.c");
+
+        Preprocessor preprocessor(settings, errorLogger, Standards::Language::C);
+        ASSERT(preprocessor.loadFiles(tokens, files));
+
+        AddonInfo premiumaddon;
+        premiumaddon.name = "premiumaddon.json";
+        premiumaddon.executable = "premiumaddon";
+
+        settings.cppcheckCfgProductName = "Cppcheck Premium 0.0.0";
+        settings.addons.insert(premiumaddon.name);
+        settings.addonInfos.push_back(premiumaddon);
+
+        settings.premiumArgs = "misra-c-2012";
+        CppCheck check(settings, supprs, errorLogger, false, {});
+        const size_t hash1 = check.calculateHash(preprocessor, tokens);
+
+        settings.premiumArgs = "";
+        const size_t hash2 = check.calculateHash(preprocessor, tokens);
+
+        // cppcheck-suppress knownConditionTrueFalse
+        ASSERT(hash1 != hash2);
     }
 
     // TODO: test suppressions
