@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2024 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,8 +40,6 @@ public:
     TestLibrary() : TestFixture("TestLibrary") {}
 
 private:
-    const Settings settings;
-
     void run() override {
         TEST_CASE(isCompliantValidationExpression);
         TEST_CASE(empty);
@@ -66,9 +64,12 @@ private:
         TEST_CASE(resource);
         TEST_CASE(podtype);
         TEST_CASE(container);
+        TEST_CASE(containerActionToFromString);
+        TEST_CASE(containerYieldToFromString);
         TEST_CASE(version);
         TEST_CASE(loadLibErrors);
         TEST_CASE(loadLibCombinations);
+        TEST_CASE(smartpointer);
     }
 
     void isCompliantValidationExpression() const {
@@ -152,9 +153,9 @@ private:
                                    "  </function>\n"
                                    "</def>";
 
-        TokenList tokenList(&settings);
+        TokenList tokenList(settingsDefault, Standards::Language::CPP);
         std::istringstream istr("foo();"); // <- too few arguments, not library function
-        ASSERT(tokenList.createTokens(istr, Standards::Language::CPP));
+        ASSERT(tokenList.createTokens(istr));
         Token::createMutualLinks(tokenList.front()->next(), tokenList.back()->previous());
         tokenList.createAst();
 
@@ -176,18 +177,18 @@ private:
         ASSERT(LibraryHelper::loadxmldata(library, xmldata, sizeof(xmldata)));
 
         {
-            TokenList tokenList(&settings);
+            TokenList tokenList(settingsDefault, Standards::Language::CPP);
             std::istringstream istr("foo();"); // <- too few arguments, not library function
-            ASSERT(tokenList.createTokens(istr, Standards::Language::CPP));
+            ASSERT(tokenList.createTokens(istr));
             Token::createMutualLinks(tokenList.front()->next(), tokenList.back()->previous());
             tokenList.createAst();
 
             ASSERT(library.isNotLibraryFunction(tokenList.front()));
         }
         {
-            TokenList tokenList(&settings);
+            TokenList tokenList(settingsDefault, Standards::Language::CPP);
             std::istringstream istr("foo(a);"); // <- library function
-            ASSERT(tokenList.createTokens(istr, Standards::Language::CPP));
+            ASSERT(tokenList.createTokens(istr));
             Token::createMutualLinks(tokenList.front()->next(), tokenList.back()->previous());
             tokenList.createAst();
 
@@ -196,9 +197,9 @@ private:
             ASSERT(func);
         }
         {
-            TokenList tokenList(&settings);
+            TokenList tokenList(settingsDefault, Standards::Language::CPP);
             std::istringstream istr("foo(a, b);"); // <- library function
-            ASSERT(tokenList.createTokens(istr, Standards::Language::CPP));
+            ASSERT(tokenList.createTokens(istr));
             Token::createMutualLinks(tokenList.front()->next(), tokenList.back()->previous());
             tokenList.createAst();
 
@@ -207,9 +208,9 @@ private:
             ASSERT(func);
         }
         {
-            TokenList tokenList(&settings);
+            TokenList tokenList(settingsDefault, Standards::Language::CPP);
             std::istringstream istr("foo(a, b, c);"); // <- too much arguments, not library function
-            ASSERT(tokenList.createTokens(istr, Standards::Language::CPP));
+            ASSERT(tokenList.createTokens(istr));
             Token::createMutualLinks(tokenList.front()->next(), tokenList.back()->previous());
             tokenList.createAst();
 
@@ -345,125 +346,125 @@ private:
         tokenList.front()->next()->astOperand1(tokenList.front());
 
         // 1-
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 1, -10));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 1, -10.0));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 1, 0));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 1, 0.0));
-        ASSERT_EQUALS(true, library.isIntArgValid(tokenList.front(), 1, 1));
-        ASSERT_EQUALS(true, library.isFloatArgValid(tokenList.front(), 1, 1.0));
-        ASSERT_EQUALS(true, library.isIntArgValid(tokenList.front(), 1, 10));
-        ASSERT_EQUALS(true, library.isFloatArgValid(tokenList.front(), 1, 10.0));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 1, -10, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 1, -10.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 1, 0, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 1, 0.0, settingsDefault));
+        ASSERT_EQUALS(true, library.isIntArgValid(tokenList.front(), 1, 1, settingsDefault));
+        ASSERT_EQUALS(true, library.isFloatArgValid(tokenList.front(), 1, 1.0, settingsDefault));
+        ASSERT_EQUALS(true, library.isIntArgValid(tokenList.front(), 1, 10, settingsDefault));
+        ASSERT_EQUALS(true, library.isFloatArgValid(tokenList.front(), 1, 10.0, settingsDefault));
 
         // -7-0
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 2, -10));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 2, -10.0));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 2, -7.5));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 2, -7.1));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 2, -7));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 2, -7.0));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 2, -3));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 2, -3.0));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 2, -3.5));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 2, 0));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 2, 0.0));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 2, 0.5));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 2, 1));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 2, 1.0));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 2, -10, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 2, -10.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 2, -7.5, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 2, -7.1, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 2, -7, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 2, -7.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 2, -3, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 2, -3.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 2, -3.5, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 2, 0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 2, 0.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 2, 0.5, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 2, 1, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 2, 1.0, settingsDefault));
 
         // 1-5,8
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 3, 0));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 3, 0.0));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 3, 1));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 3, 1.0));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 3, 3));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 3, 3.0));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 3, 5));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 3, 5.0));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 3, 6));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 3, 6.0));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 3, 7));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 3, 7.0));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 3, 8));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 3, 8.0));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 3, 9));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 3, 9.0));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 3, 0, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 3, 0.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 3, 1, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 3, 1.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 3, 3, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 3, 3.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 3, 5, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 3, 5.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 3, 6, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 3, 6.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 3, 7, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 3, 7.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 3, 8, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 3, 8.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 3, 9, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 3, 9.0, settingsDefault));
 
         // -1,5
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 4, -10));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 4, -10.0));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 4, -1));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 4, -1.0));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 4, 5.000001));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 4, 5.5));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 4, -10, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 4, -10.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 4, -1, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 4, -1.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 4, 5.000001, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 4, 5.5, settingsDefault));
 
         // :1,5
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 5, -10));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 5, -10.0));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 5, 1));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 5, 1.0));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 5, 2));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 5, 2.0));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 5, -10, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 5, -10.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 5, 1, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 5, 1.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 5, 2, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 5, 2.0, settingsDefault));
 
         // 1.5:
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 6, 0));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 6, 0.0));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 6, 1));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 6, 1.499999));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 6, 1.5));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 6, 2));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 6, 10));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 6, 0, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 6, 0.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 6, 1, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 6, 1.499999, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 6, 1.5, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 6, 2, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 6, 10, settingsDefault));
 
         // -6.7:-5.5,-3.3:-2.7
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 7, -7));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -7.0));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -6.7000001));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -6.7));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 7, -6));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -6.0));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -5.5));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -5.4999999));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -3.3000001));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -3.3));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 7, -3));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -3.0));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -2.7));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -2.6999999));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 7, -2));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -2.0));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 7, 0));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, 0.0));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 7, 3));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, 3.0));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 7, 6));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, 6.0));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 7, -7, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -7.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -6.7000001, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -6.7, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 7, -6, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -6.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -5.5, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -5.4999999, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -3.3000001, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -3.3, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 7, -3, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -3.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 7, -2.7, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -2.6999999, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 7, -2, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, -2.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 7, 0, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, 0.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 7, 3, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, 3.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 7, 6, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 7, 6.0, settingsDefault));
 
         // 0.0:
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 8, -1));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 8, -1.0));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 8, -0.00000001));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 8, 0));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 8, 0.0));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 8, 0.000000001));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 8, 1));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 8, 1.0));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 8, -1, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 8, -1.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 8, -0.00000001, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 8, 0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 8, 0.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 8, 0.000000001, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 8, 1, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 8, 1.0, settingsDefault));
 
         // :2.0
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 9, -1));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 9, -1.0));
-        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 9, 2));
-        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 9, 2.0));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 9, 2.00000001));
-        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 9, 200));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 9, 200.0));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 9, -1, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 9, -1.0, settingsDefault));
+        ASSERT_EQUALS(true,  library.isIntArgValid(tokenList.front(), 9, 2, settingsDefault));
+        ASSERT_EQUALS(true,  library.isFloatArgValid(tokenList.front(), 9, 2.0, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 9, 2.00000001, settingsDefault));
+        ASSERT_EQUALS(false, library.isIntArgValid(tokenList.front(), 9, 200, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 9, 200.0, settingsDefault));
 
         // 0.0
-        ASSERT_EQUALS(true, library.isIntArgValid(tokenList.front(), 10, 0));
-        ASSERT_EQUALS(true, library.isFloatArgValid(tokenList.front(), 10, 0.0));
+        ASSERT_EQUALS(true, library.isIntArgValid(tokenList.front(), 10, 0, settingsDefault));
+        ASSERT_EQUALS(true, library.isFloatArgValid(tokenList.front(), 10, 0.0, settingsDefault));
 
         // ! 0.0
-        ASSERT_EQUALS(true, library.isFloatArgValid(tokenList.front(), 11, -0.42));
-        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 11, 0.0));
-        ASSERT_EQUALS(true, library.isFloatArgValid(tokenList.front(), 11, 0.42));
+        ASSERT_EQUALS(true, library.isFloatArgValid(tokenList.front(), 11, -0.42, settingsDefault));
+        ASSERT_EQUALS(false, library.isFloatArgValid(tokenList.front(), 11, 0.0, settingsDefault));
+        ASSERT_EQUALS(true, library.isFloatArgValid(tokenList.front(), 11, 0.42, settingsDefault));
     }
 
     void function_arg_minsize() const {
@@ -568,14 +569,14 @@ private:
         ASSERT_EQUALS(library.functions().size(), 1U);
 
         {
-            SimpleTokenizer tokenizer(settings, *this);
+            SimpleTokenizer tokenizer(settingsDefault, *this);
             const char code[] = "CString str; str.Format();";
             ASSERT(tokenizer.tokenize(code));
             ASSERT(library.isnotnoreturn(Token::findsimplematch(tokenizer.tokens(), "Format")));
         }
 
         {
-            SimpleTokenizer tokenizer(settings, *this);
+            SimpleTokenizer tokenizer(settingsDefault, *this);
             const char code[] = "HardDrive hd; hd.Format();";
             ASSERT(tokenizer.tokenize(code));
             ASSERT(!library.isnotnoreturn(Token::findsimplematch(tokenizer.tokens(), "Format")));
@@ -594,14 +595,14 @@ private:
         ASSERT(LibraryHelper::loadxmldata(library, xmldata, sizeof(xmldata)));
 
         {
-            SimpleTokenizer tokenizer(settings, *this);
+            SimpleTokenizer tokenizer(settingsDefault, *this);
             const char code[] = "struct X : public Base { void dostuff() { f(0); } };";
             ASSERT(tokenizer.tokenize(code));
             ASSERT(library.isnullargbad(Token::findsimplematch(tokenizer.tokens(), "f"),1));
         }
 
         {
-            SimpleTokenizer tokenizer(settings, *this);
+            SimpleTokenizer tokenizer(settingsDefault, *this);
             const char code[] = "struct X : public Base { void dostuff() { f(1,2); } };";
             ASSERT(tokenizer.tokenize(code));
             ASSERT(!library.isnullargbad(Token::findsimplematch(tokenizer.tokens(), "f"),1));
@@ -868,8 +869,11 @@ private:
         ASSERT_EQUALS(F.endPattern, "");
         ASSERT_EQUALS(F.itEndPattern, ":: iterator");
 
+        ASSERT(!library.detectContainerOrIterator(nullptr));
+
         {
-            const SimpleTokenizer var(*this, "std::A<int> a;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("std::A<int> a;"));
             ASSERT_EQUALS(&A, library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             bool isIterator;
@@ -878,14 +882,16 @@ private:
         }
 
         {
-            const SimpleTokenizer var(*this, "std::A<int>::size_type a_s;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("std::A<int>::size_type a_s;"));
             ASSERT(!library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             ASSERT(!library.detectContainerOrIterator(var.tokens()));
         }
 
         {
-            const SimpleTokenizer var(*this, "std::A<int>::iterator a_it;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("std::A<int>::iterator a_it;"));
             ASSERT(!library.detectContainer(var.tokens()));
             ASSERT_EQUALS(&A, library.detectIterator(var.tokens()));
             bool isIterator;
@@ -894,7 +900,8 @@ private:
         }
 
         {
-            const SimpleTokenizer var(*this, "std::B<int> b;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("std::B<int> b;"));
             ASSERT_EQUALS(&B, library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             bool isIterator;
@@ -903,14 +910,16 @@ private:
         }
 
         {
-            const SimpleTokenizer var(*this, "std::B<int>::size_type b_s;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("std::B<int>::size_type b_s;"));
             ASSERT(!library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             ASSERT(!library.detectContainerOrIterator(var.tokens()));
         }
 
         {
-            const SimpleTokenizer var(*this, "std::B<int>::iterator b_it;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("std::B<int>::iterator b_it;"));
             ASSERT(!library.detectContainer(var.tokens()));
             ASSERT_EQUALS(&B, library.detectIterator(var.tokens()));
             bool isIterator;
@@ -919,21 +928,24 @@ private:
         }
 
         {
-            const SimpleTokenizer var(*this, "C c;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("C c;"));
             ASSERT(!library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             ASSERT(!library.detectContainerOrIterator(var.tokens()));
         }
 
         {
-            const SimpleTokenizer var(*this, "D d;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("D d;"));
             ASSERT(!library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             ASSERT(!library.detectContainerOrIterator(var.tokens()));
         }
 
         {
-            const SimpleTokenizer var(*this, "std::E e;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("std::E e;"));
             ASSERT(library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             bool isIterator;
@@ -943,7 +955,8 @@ private:
         }
 
         {
-            const SimpleTokenizer var(*this, "E e;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("E e;"));
             ASSERT(!library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             ASSERT(!library.detectContainerOrIterator(var.tokens()));
@@ -951,7 +964,8 @@ private:
         }
 
         {
-            const SimpleTokenizer var(*this, "std::E::iterator I;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("std::E::iterator I;"));
             ASSERT(!library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             ASSERT(!library.detectContainerOrIterator(var.tokens()));
@@ -959,7 +973,8 @@ private:
         }
 
         {
-            const SimpleTokenizer var(*this, "std::E::size_type p;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("std::E::size_type p;"));
             ASSERT(!library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             ASSERT(!library.detectContainerOrIterator(var.tokens()));
@@ -967,7 +982,8 @@ private:
         }
 
         {
-            const SimpleTokenizer var(*this, "std::F f;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("std::F f;"));
             ASSERT(library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             bool isIterator;
@@ -976,21 +992,23 @@ private:
         }
 
         {
-            const SimpleTokenizer var(*this, "std::F::iterator I;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("std::F::iterator I;"));
             ASSERT(!library.detectContainer(var.tokens()));
             TODO_ASSERT(library.detectIterator(var.tokens()));
             bool isIterator = false;
-            TODO_ASSERT_EQUALS((intptr_t)&F, 0, (intptr_t)library.detectContainerOrIterator(var.tokens(), &isIterator));
+            TODO_ASSERT_EQUALS(reinterpret_cast<intptr_t>(&F), 0, reinterpret_cast<intptr_t>(library.detectContainerOrIterator(var.tokens(), &isIterator)));
             TODO_ASSERT(isIterator);
         }
 
         {
-            const SimpleTokenizer var(*this, "F::iterator I;");
+            SimpleTokenizer var(*this);
+            ASSERT(var.tokenize("F::iterator I;"));
             ASSERT(!library.detectContainer(var.tokens()));
             ASSERT(!library.detectIterator(var.tokens()));
             ASSERT(!library.detectContainerOrIterator(var.tokens()));
             bool isIterator = false;
-            TODO_ASSERT_EQUALS((intptr_t)&F, 0, (intptr_t)library.detectContainerOrIterator(var.tokens(), &isIterator, true));
+            TODO_ASSERT_EQUALS(reinterpret_cast<intptr_t>(&F), 0, reinterpret_cast<intptr_t>(library.detectContainerOrIterator(var.tokens(), &isIterator, true)));
             TODO_ASSERT(isIterator);
         }
     }
@@ -1020,6 +1038,22 @@ private:
         }
     }
 
+    void containerActionToFromString() const {
+        for (uint16_t i = 0; i < static_cast<uint16_t>(Library::Container::Action::NO_ACTION); ++i) {
+            const auto a = static_cast<Library::Container::Action>(i);
+            const std::string& s = Library::Container::toString(a);
+            ASSERT_EQUALS(i, static_cast<uint16_t>(Library::Container::actionFrom(s)));
+        }
+    }
+
+    void containerYieldToFromString() const {
+        for (uint16_t i = 0; i < static_cast<uint16_t>(Library::Container::Yield::NO_YIELD); ++i) {
+            const auto y = static_cast<Library::Container::Yield>(i);
+            const std::string& s = Library::Container::toString(y);
+            ASSERT_EQUALS(i, static_cast<uint16_t>(Library::Container::yieldFrom(s)));
+        }
+    }
+
     template<std::size_t size>
     void loadLibError(const char (&xmldata)[size], Library::ErrorCode errorcode, const char* file, unsigned line) const {
         Library library;
@@ -1140,6 +1174,15 @@ private:
             ASSERT_EQUALS(s.library.defines().empty(), false);
         }
     }
+
+    void smartpointer() const {
+        const Settings s = settingsBuilder().library("std.cfg").build();
+        const Library& library = s.library;
+
+        ASSERT(!library.detectSmartPointer(nullptr));
+
+        // TODO: add more tests
+    }
 };
 
 REGISTER_TEST(TestLibrary)
