@@ -21,6 +21,7 @@
 #include "helpers.h"
 #include "standards.h"
 
+#include <initializer_list>
 #include <list>
 #include <set>
 #include <string>
@@ -55,6 +56,7 @@ private:
         TEST_CASE(simplifyPath);
         TEST_CASE(getAbsolutePath);
         TEST_CASE(exists);
+        TEST_CASE(fromNativeSeparators);
     }
 
     void removeQuotationMarks() const {
@@ -577,6 +579,20 @@ private:
         ASSERT_EQUALS(false, Path::exists("testpath.txt", &b));
         ASSERT_EQUALS(false, b);
     }
+
+    void fromNativeSeparators() const {
+        ASSERT_EQUALS("lib/file.c", Path::fromNativeSeparators("lib/file.c"));
+        ASSERT_EQUALS("lib//file.c", Path::fromNativeSeparators("lib//file.c"));
+        ASSERT_EQUALS("/lib/file.c", Path::fromNativeSeparators("/lib/file.c"));
+        ASSERT_EQUALS("//lib/file.c", Path::fromNativeSeparators("//lib/file.c"));
+        ASSERT_EQUALS("./lib/file.c", Path::fromNativeSeparators("./lib/file.c"));
+
+        ASSERT_EQUALS("lib/file.c", Path::fromNativeSeparators("lib\\file.c"));
+        ASSERT_EQUALS("lib//file.c", Path::fromNativeSeparators("lib\\\\file.c"));
+        ASSERT_EQUALS("/lib/file.c", Path::fromNativeSeparators("\\lib\\file.c"));
+        ASSERT_EQUALS("//lib/file.c", Path::fromNativeSeparators("\\\\lib\\file.c"));
+        ASSERT_EQUALS("./lib/file.c", Path::fromNativeSeparators(".\\lib\\file.c"));
+    }
 };
 
 REGISTER_TEST(TestPath)
