@@ -22,14 +22,10 @@
 #include "platform.h"
 #include "settings.h"
 #include "token.h"
-#include "tokenize.h"
-#include "tokenlist.h"
 #include "utils.h"
 
 #include <cstddef>
-#include <sstream>
 #include <string>
-#include <vector>
 
 class TestSimplifyUsing : public TestFixture {
 public:
@@ -40,6 +36,7 @@ private:
     const Settings settings0 = settingsBuilder().severity(Severity::style).build();
 
     void run() override {
+        mNewTemplate = true;
         TEST_CASE(simplifyUsing1);
         TEST_CASE(simplifyUsing2);
         TEST_CASE(simplifyUsing3);
@@ -75,6 +72,7 @@ private:
         TEST_CASE(simplifyUsing33);
         TEST_CASE(simplifyUsing34);
         TEST_CASE(simplifyUsing35);
+        TEST_CASE(simplifyUsing36);
 
         TEST_CASE(simplifyUsing8970);
         TEST_CASE(simplifyUsing8971);
@@ -95,6 +93,7 @@ private:
         TEST_CASE(simplifyUsing10173);
         TEST_CASE(simplifyUsing10335);
         TEST_CASE(simplifyUsing10720);
+        TEST_CASE(simplifyUsing13873); // function declaration
 
         TEST_CASE(scopeInfo1);
         TEST_CASE(scopeInfo2);
@@ -114,11 +113,8 @@ private:
         const Settings settings = settingsBuilder(settings0).certainty(Certainty::inconclusive).debugwarnings(options.debugwarnings).platform(options.type).build();
 
         if (options.preprocess) {
-            Tokenizer tokenizer(settings, *this);
-            std::vector<std::string> files(1, "test.cpp");
-            PreprocessorHelper::preprocess(code, files, tokenizer, *this);
-            std::istringstream istr(code);
-            ASSERT_LOC(tokenizer.list.createTokens(istr, "test.cpp"), file, line); // TODO: this creates the tokens a second time
+            SimpleTokenizer2 tokenizer(settings, *this, code, "test.cpp");
+
             ASSERT_LOC(tokenizer.simplifyTokens1(""), file, line);
             return tokenizer.tokens()->stringifyList(nullptr);
         }
@@ -754,7 +750,7 @@ private:
                                     "}";
             ASSERT_EQUALS(expected, tok(code));
             ASSERT_EQUALS(
-                "[test.cpp:3]: (debug) valueFlowConditionExpressions bailout: Skipping function due to incomplete variable cout\n",
+                "[test.cpp:3:5]: (debug) valueFlowConditionExpressions bailout: Skipping function due to incomplete variable cout [valueFlowBailoutIncompleteVar]\n",
                 errout_str());
         }
         {
@@ -820,7 +816,7 @@ private:
                                  "auto S :: get ( ) . int & { return i ; }";
         ASSERT_EQUALS(expected2, tok(code2));
         TODO_ASSERT_EQUALS("",
-                           "[test.cpp:6]: (debug) auto token with no type.\n"
+                           "[test.cpp:6:1]: (debug) auto token with no type. [autoNoType]\n"
                            "", errout_str());
 
         const char code3[] = "using V = int*;\n"
@@ -828,7 +824,7 @@ private:
         const char expected3[] = "auto g ( ) . const volatile int * { return { } ; }";
         ASSERT_EQUALS(expected3, tok(code3));
         TODO_ASSERT_EQUALS("",
-                           "[test.cpp:2]: (debug) auto token with no type.\n"
+                           "[test.cpp:2:1]: (debug) auto token with no type. [autoNoType]\n"
                            "", errout_str());
     }
 
@@ -879,6 +875,14 @@ private:
         ASSERT_EQUALS("", errout_str());
     }
 
+    void simplifyUsing36() {
+        const char code[] = "using A::a;\n"
+                            "int c = B<int>::a;\n";
+        const char expected[] = "int c ; c = B < int > :: a ;";
+        ASSERT_EQUALS(expected, tok(code));
+        ASSERT_EQUALS("", errout_str());
+    }
+
     void simplifyUsing8970() {
         const char code[] = "using V = std::vector<int>;\n"
                             "struct A {\n"
@@ -1590,7 +1594,21 @@ private:
                             "STAMP(B, A);\n"
                             "STAMP(C, B);\n";
         (void)tok(code, dinit(TokOptions, $.preprocess = true));
-        ASSERT(startsWith(errout_str(), "[test.cpp:6]: (debug) Failed to parse 'using C = S < S < S < int"));
+        TODO_ASSERT(startsWith(errout_str(), "[test.cpp:6]: (debug) Failed to parse 'using C = S < S < S < int"));
+    }
+
+    void simplifyUsing13873() { // function declaration
+        const char code1[] = "using NS1::f;\n"
+                             "namespace NS1 { void f(); }\n";
+        ASSERT_EQUALS("namespace NS1 { void f ( ) ; }", tok(code1));
+
+        const char code2[] = "using NS1::f;\n"
+                             "void bar() { f(); }\n";
+        ASSERT_EQUALS("void bar ( ) { NS1 :: f ( ) ; }", tok(code2));
+
+        const char code3[] = "using NS1::f;\n"
+                             "namespace NS1 { void* f(); }\n";
+        ASSERT_EQUALS("namespace NS1 { void * f ( ) ; }", tok(code3));
     }
 
     void scopeInfo1() {
