@@ -22,10 +22,8 @@
 #include "helpers.h"
 #include "settings.h"
 #include "fixture.h"
-#include "tokenize.h"
 
 #include <string>
-#include <vector>
 
 class TestString : public TestFixture {
 public:
@@ -35,6 +33,7 @@ private:
     const Settings settings = settingsBuilder().severity(Severity::warning).severity(Severity::style).build();
 
     void run() override {
+        mNewTemplate = true;
         TEST_CASE(stringLiteralWrite);
 
         TEST_CASE(alwaysTrueFalseStringCompare);
@@ -64,14 +63,12 @@ private:
     struct CheckOptions
     {
         CheckOptions() = default;
-        const char* filename = "test.cpp";
+        bool cpp = true;
     };
 
 #define check(...) check_(__FILE__, __LINE__, __VA_ARGS__)
     void check_(const char* file, int line, const char code[], const CheckOptions& options = make_default_obj()) {
-        std::vector<std::string> files(1, options.filename);
-        Tokenizer tokenizer(settings, *this);
-        PreprocessorHelper::preprocess(code, files, tokenizer, *this);
+        SimpleTokenizer2 tokenizer(settings, *this, code, options.cpp ? "test.cpp" : "test.c");
 
         // Tokenize..
         ASSERT_LOC(tokenizer.simplifyTokens1(""), file, line);
@@ -85,19 +82,19 @@ private:
               "  char *abc = \"abc\";\n"
               "  abc[0] = 'a';\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3] -> [test.cpp:2]: (error) Modifying string literal \"abc\" directly or indirectly is undefined behaviour.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:3] -> [test.cpp:2:15]: (error) Modifying string literal \"abc\" directly or indirectly is undefined behaviour. [stringLiteralWrite]\n", errout_str());
 
         check("void f() {\n"
               "  char *abc = \"abc\";\n"
               "  *abc = 'a';\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3] -> [test.cpp:2]: (error) Modifying string literal \"abc\" directly or indirectly is undefined behaviour.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:4] -> [test.cpp:2:15]: (error) Modifying string literal \"abc\" directly or indirectly is undefined behaviour. [stringLiteralWrite]\n", errout_str());
 
         check("void f() {\n"
               "  char *abc = \"A very long string literal\";\n"
               "  abc[0] = 'a';\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3] -> [test.cpp:2]: (error) Modifying string literal \"A very long stri..\" directly or indirectly is undefined behaviour.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:3] -> [test.cpp:2:15]: (error) Modifying string literal \"A very long stri..\" directly or indirectly is undefined behaviour. [stringLiteralWrite]\n", errout_str());
 
         check("void f() {\n"
               "  QString abc = \"abc\";\n"
@@ -113,7 +110,7 @@ private:
               "  foo_FP1(s);\n"
               "}");
         ASSERT_EQUALS(
-            "[test.cpp:2] -> [test.cpp:5]: (error) Modifying string literal \"Y\" directly or indirectly is undefined behaviour.\n",
+            "[test.cpp:2:3] -> [test.cpp:5:13]: (error) Modifying string literal \"Y\" directly or indirectly is undefined behaviour. [stringLiteralWrite]\n",
             errout_str());
 
         check("void foo_FP1(char *p) {\n"
@@ -129,13 +126,13 @@ private:
               "  wchar_t *abc = L\"abc\";\n"
               "  abc[0] = u'a';\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3] -> [test.cpp:2]: (error) Modifying string literal L\"abc\" directly or indirectly is undefined behaviour.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:3] -> [test.cpp:2:18]: (error) Modifying string literal L\"abc\" directly or indirectly is undefined behaviour. [stringLiteralWrite]\n", errout_str());
 
         check("void f() {\n"
               "  char16_t *abc = u\"abc\";\n"
               "  abc[0] = 'a';\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3] -> [test.cpp:2]: (error) Modifying string literal u\"abc\" directly or indirectly is undefined behaviour.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:3] -> [test.cpp:2:19]: (error) Modifying string literal u\"abc\" directly or indirectly is undefined behaviour. [stringLiteralWrite]\n", errout_str());
 
         check("void foo() {\n" // #8332
               "    int i;\n"
@@ -145,7 +142,7 @@ private:
               "    }\n"
               "    printf(\"%s\\n\", p);\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:5] -> [test.cpp:3]: (error) Modifying string literal \"string literal\" directly or indirectly is undefined behaviour.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:5:9] -> [test.cpp:3:16]: (error) Modifying string literal \"string literal\" directly or indirectly is undefined behaviour. [stringLiteralWrite]\n", errout_str());
     }
 
     void alwaysTrueFalseStringCompare() {
@@ -163,18 +160,18 @@ private:
               "  if (wcscmp(L\"A\",L\"A\")){}\n"
               "  if (wcscasecmp(L\"A\",L\"A\")){}\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Unnecessary comparison of static strings.\n"
-                      "[test.cpp:3]: (warning) Unnecessary comparison of static strings.\n"
-                      "[test.cpp:4]: (warning) Unnecessary comparison of static strings.\n"
-                      "[test.cpp:5]: (warning) Unnecessary comparison of static strings.\n"
-                      "[test.cpp:6]: (warning) Unnecessary comparison of static strings.\n"
-                      "[test.cpp:7]: (warning) Unnecessary comparison of static strings.\n"
-                      "[test.cpp:8]: (warning) Unnecessary comparison of static strings.\n"
-                      "[test.cpp:9]: (warning) Unnecessary comparison of static strings.\n"
-                      "[test.cpp:10]: (warning) Unnecessary comparison of static strings.\n"
-                      "[test.cpp:11]: (warning) Unnecessary comparison of static strings.\n"
-                      "[test.cpp:12]: (warning) Unnecessary comparison of static strings.\n"
-                      "[test.cpp:13]: (warning) Unnecessary comparison of static strings.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n"
+                      "[test.cpp:3:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n"
+                      "[test.cpp:4:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n"
+                      "[test.cpp:5:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n"
+                      "[test.cpp:6:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n"
+                      "[test.cpp:7:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n"
+                      "[test.cpp:8:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n"
+                      "[test.cpp:9:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n"
+                      "[test.cpp:10:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n"
+                      "[test.cpp:11:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n"
+                      "[test.cpp:12:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n"
+                      "[test.cpp:13:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n", errout_str());
 
         // avoid false positives when the address is modified #6415
         check("void f(void *p, int offset)  {\n"
@@ -207,7 +204,7 @@ private:
               "    const wchar_t* str1 = L\"Hello\";\n"
               "    return wcsicmp(str1, str1);\n" // <<
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (warning) Comparison of identical string variables.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:12]: (warning) Comparison of identical string variables. [stringCompare]\n", errout_str());
 
         check("int main()\n"
               "{\n"
@@ -216,7 +213,7 @@ private:
               "    std::cout << \"Equal\";"
               "  }"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (warning) Unnecessary comparison of static strings.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n", errout_str());
 
         check("void f() {\n"
               "  if (strcmp($\"00FF00\", \"00FF00\") == 0) {}"
@@ -235,7 +232,7 @@ private:
               "    std::cout << \"Equal\";"
               "  }"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (warning) Unnecessary comparison of static strings.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n", errout_str());
 
         check("int main()\n"
               "{\n"
@@ -244,7 +241,7 @@ private:
               "    std::cout << \"Equal\";"
               "  }"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (warning) Unnecessary comparison of static strings.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n", errout_str());
 
         check("int main()\n"
               "{\n"
@@ -262,7 +259,7 @@ private:
               "    std::cout << \"Equal\";"
               "  }"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (warning) Unnecessary comparison of static strings.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:7]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n", errout_str());
 
         check("int foo(const char *buf)\n"
               "{\n"
@@ -271,7 +268,7 @@ private:
               "    std::cout << \"Equal\";"
               "  }"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (warning) Comparison of identical string variables.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:7]: (warning) Comparison of identical string variables. [stringCompare]\n", errout_str());
 
         check("int foo(const std::string& buf)\n"
               "{\n"
@@ -280,21 +277,21 @@ private:
               "    std::cout << \"Equal\";"
               "  }"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (warning) Comparison of identical string variables.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:7]: (warning) Comparison of identical string variables. [stringCompare]\n", errout_str());
 
         check("int main() {\n"
               "  if (\"str\" == \"str\") {\n"
               "    std::cout << \"Equal\";\n"
               "  }\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Unnecessary comparison of static strings.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:6]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n", errout_str());
 
         check("int main() {\n"
               "  if (\"str\" != \"str\") {\n"
               "    std::cout << \"Equal\";\n"
               "  }\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Unnecessary comparison of static strings.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:6]: (warning) Unnecessary comparison of static strings. [staticStringCompare]\n", errout_str());
 
         check("int main() {\n"
               "  if (a+\"str\" != \"str\"+b) {\n"
@@ -308,22 +305,22 @@ private:
         check("bool foo(char* c) {\n"
               "    return c == \"x\";\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) String literal compared with variable 'c'. Did you intend to use strcmp() instead?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:14]: (warning) String literal compared with variable 'c'. Did you intend to use strcmp() instead? [literalWithCharPtrCompare]\n", errout_str());
 
         check("bool foo(char** c) {\n"
               "    return c[3] == \"x\";\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) String literal compared with variable 'c[3]'. Did you intend to use strcmp() instead?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:17]: (warning) String literal compared with variable 'c[3]'. Did you intend to use strcmp() instead? [literalWithCharPtrCompare]\n", errout_str());
 
         check("bool foo(wchar_t* c) {\n"
               "    return c == L\"x\";\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) String literal compared with variable 'c'. Did you intend to use wcscmp() instead?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:14]: (warning) String literal compared with variable 'c'. Did you intend to use wcscmp() instead? [literalWithCharPtrCompare]\n", errout_str());
 
         check("bool foo(const char* c) {\n"
               "    return \"x\" == c;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) String literal compared with variable 'c'. Did you intend to use strcmp() instead?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:16]: (warning) String literal compared with variable 'c'. Did you intend to use strcmp() instead? [literalWithCharPtrCompare]\n", errout_str());
 
         check("bool foo(char* c) {\n"
               "    return foo+\"x\" == c;\n"
@@ -337,8 +334,8 @@ private:
 
         check("bool foo(char* c) {\n"
               "    return \"x\" == c+foo;\n"
-              "}", dinit(CheckOptions, $.filename = "test.c"));
-        ASSERT_EQUALS("[test.c:2]: (warning) String literal compared with variable 'c+foo'. Did you intend to use strcmp() instead?\n", errout_str());
+              "}", dinit(CheckOptions, $.cpp = false));
+        ASSERT_EQUALS("[test.c:2:16]: (warning) String literal compared with variable 'c+foo'. Did you intend to use strcmp() instead? [literalWithCharPtrCompare]\n", errout_str());
 
         check("bool foo(Foo c) {\n"
               "    return \"x\" == c.foo;\n"
@@ -347,8 +344,8 @@ private:
 
         check("bool foo(Foo c) {\n"
               "    return \"x\" == c.foo;\n"
-              "}", dinit(CheckOptions, $.filename = "test.c"));
-        ASSERT_EQUALS("[test.c:2]: (warning) String literal compared with variable 'c.foo'. Did you intend to use strcmp() instead?\n", errout_str());
+              "}", dinit(CheckOptions, $.cpp = false));
+        ASSERT_EQUALS("[test.c:2:16]: (warning) String literal compared with variable 'c.foo'. Did you intend to use strcmp() instead? [literalWithCharPtrCompare]\n", errout_str());
 
         check("bool foo(const std::string& c) {\n"
               "    return \"x\" == c;\n"
@@ -363,8 +360,8 @@ private:
         // Ticket #4257
         check("bool foo() {\n"
               "MyString *str=Getter();\n"
-              "return *str==\"bug\"; }\n", dinit(CheckOptions, $.filename = "test.c"));
-        ASSERT_EQUALS("[test.c:3]: (warning) String literal compared with variable '*str'. Did you intend to use strcmp() instead?\n", errout_str());
+              "return *str==\"bug\"; }\n", dinit(CheckOptions, $.cpp = false));
+        ASSERT_EQUALS("[test.c:3:12]: (warning) String literal compared with variable '*str'. Did you intend to use strcmp() instead? [literalWithCharPtrCompare]\n", errout_str());
 
         // Ticket #4257
         check("bool foo() {\n"
@@ -375,27 +372,27 @@ private:
         // Ticket #4257
         check("bool foo() {\n"
               "MyString **str=OtherGetter();\n"
-              "return *str==\"bug\"; }", dinit(CheckOptions, $.filename = "test.c"));
-        ASSERT_EQUALS("[test.c:3]: (warning) String literal compared with variable '*str'. Did you intend to use strcmp() instead?\n", errout_str());
+              "return *str==\"bug\"; }", dinit(CheckOptions, $.cpp = false));
+        ASSERT_EQUALS("[test.c:3:12]: (warning) String literal compared with variable '*str'. Did you intend to use strcmp() instead? [literalWithCharPtrCompare]\n", errout_str());
 
         // Ticket #4257
         check("bool foo() {\n"
               "MyString str=OtherGetter2();\n"
-              "return &str==\"bug\"; }", dinit(CheckOptions, $.filename = "test.c"));
-        ASSERT_EQUALS("[test.c:3]: (warning) String literal compared with variable '&str'. Did you intend to use strcmp() instead?\n", errout_str());
+              "return &str==\"bug\"; }", dinit(CheckOptions, $.cpp = false));
+        ASSERT_EQUALS("[test.c:3:12]: (warning) String literal compared with variable '&str'. Did you intend to use strcmp() instead? [literalWithCharPtrCompare]\n", errout_str());
 
         // Ticket #5734
         check("int foo(char c) {\n"
               "return c == '4';}");
         ASSERT_EQUALS("", errout_str());
         check("int foo(char c) {\n"
-              "return c == '4';}", dinit(CheckOptions, $.filename = "test.c"));
+              "return c == '4';}", dinit(CheckOptions, $.cpp = false));
         ASSERT_EQUALS("", errout_str());
         check("int foo(char c) {\n"
               "return c == \"42\"[0];}");
         ASSERT_EQUALS("", errout_str());
         check("int foo(char c) {\n"
-              "return c == \"42\"[0];}", dinit(CheckOptions, $.filename = "test.c"));
+              "return c == \"42\"[0];}", dinit(CheckOptions, $.cpp = false));
         ASSERT_EQUALS("", errout_str());
 
         // 5639 String literal compared with char buffer in a struct
@@ -406,15 +403,15 @@ private:
               "   struct Example example;\n"
               "   if (example.buffer == \"test\") ;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:6]: (warning) String literal compared with variable 'example.buffer'. Did you intend to use strcmp() instead?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:6:23]: (warning) String literal compared with variable 'example.buffer'. Did you intend to use strcmp() instead? [literalWithCharPtrCompare]\n", errout_str());
         check("struct Example {\n"
               "   char buffer[200];\n"
               "};\n"
               "void foo() {\n"
               "   struct Example example;\n"
               "   if (example.buffer == \"test\") ;\n"
-              "}\n", dinit(CheckOptions, $.filename = "test.c"));
-        ASSERT_EQUALS("[test.c:6]: (warning) String literal compared with variable 'example.buffer'. Did you intend to use strcmp() instead?\n", errout_str());
+              "}\n", dinit(CheckOptions, $.cpp = false));
+        ASSERT_EQUALS("[test.c:6:23]: (warning) String literal compared with variable 'example.buffer'. Did you intend to use strcmp() instead? [literalWithCharPtrCompare]\n", errout_str());
 
         // #9726
         check("void f(std::vector<std::string> theArgs) {\n"
@@ -428,17 +425,17 @@ private:
         check("bool foo(char* c) {\n"
               "    return c == 'x';\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Char literal compared with pointer 'c'. Did you intend to dereference it?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:14]: (warning) Char literal compared with pointer 'c'. Did you intend to dereference it? [charLiteralWithCharPtrCompare]\n", errout_str());
 
         check("bool foo(wchar_t* c) {\n"
               "    return c == L'x';\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Char literal compared with pointer 'c'. Did you intend to dereference it?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:14]: (warning) Char literal compared with pointer 'c'. Did you intend to dereference it? [charLiteralWithCharPtrCompare]\n", errout_str());
 
         check("bool foo(char* c) {\n"
               "    return '\\0' != c;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Char literal compared with pointer 'c'. Did you intend to dereference it?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:17]: (warning) Char literal compared with pointer 'c'. Did you intend to dereference it? [charLiteralWithCharPtrCompare]\n", errout_str());
 
         check("bool foo(char c) {\n"
               "    return c == '\\0';\n"
@@ -453,12 +450,12 @@ private:
         check("bool foo(char** c) {\n"
               "    return c[0] == '\\0';\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Char literal compared with pointer 'c[0]'. Did you intend to dereference it?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:17]: (warning) Char literal compared with pointer 'c[0]'. Did you intend to dereference it? [charLiteralWithCharPtrCompare]\n", errout_str());
 
         check("bool foo(char** c) {\n"
               "    return *c == '\\0';\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Char literal compared with pointer '*c'. Did you intend to dereference it?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:15]: (warning) Char literal compared with pointer '*c'. Did you intend to dereference it? [charLiteralWithCharPtrCompare]\n", errout_str());
 
         check("bool foo(char c) {\n"
               "    return c == 0;\n"
@@ -467,7 +464,7 @@ private:
 
         check("bool foo(char* c) {\n"
               "    return *c == 0;\n"
-              "}", dinit(CheckOptions, $.filename = "test.c"));
+              "}", dinit(CheckOptions, $.cpp = false));
         ASSERT_EQUALS("", errout_str());
 
         check("bool foo(char* c) {\n"
@@ -483,13 +480,13 @@ private:
         check("void foo(char* c) {\n"
               "    if(c == '\\0') bar();\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Char literal compared with pointer 'c'. Did you intend to dereference it?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:10]: (warning) Char literal compared with pointer 'c'. Did you intend to dereference it? [charLiteralWithCharPtrCompare]\n", errout_str());
 
         check("void f() {\n"
               "  struct { struct { char *str; } x; } a;\n"
               "  return a.x.str == '\\0';"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (warning) Char literal compared with pointer 'a.x.str'. Did you intend to dereference it?\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:18]: (warning) Char literal compared with pointer 'a.x.str'. Did you intend to dereference it? [charLiteralWithCharPtrCompare]\n", errout_str());
 
         check("void f() {\n"
               "  struct { struct { char *str; } x; } a;\n"
@@ -505,7 +502,7 @@ private:
               "    char buf[100];\n"
               "    snprintf(buf,100,\"%s\",buf);\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:4]: (error) Undefined behavior: Variable 'buf' is used as parameter and destination in snprintf().\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:4:27]: (error) Undefined behavior: Variable 'buf' is used as parameter and destination in snprintf(). [sprintfOverlappingData]\n", errout_str());
     }
 
     void sprintf1() {
@@ -514,7 +511,7 @@ private:
               "    char buf[100];\n"
               "    sprintf(buf,\"%s\",buf);\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:4]: (error) Undefined behavior: Variable 'buf' is used as parameter and destination in sprintf().\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:4:22]: (error) Undefined behavior: Variable 'buf' is used as parameter and destination in sprintf(). [sprintfOverlappingData]\n", errout_str());
     }
 
     void sprintf2() {
@@ -561,7 +558,7 @@ private:
               "{\n"
               "    snprintf(a->filename, 128, \"%s\", a->filename);\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:8]: (error) Undefined behavior: Variable 'a->filename' is used as parameter and destination in snprintf().\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:8:39]: (error) Undefined behavior: Variable 'a->filename' is used as parameter and destination in snprintf(). [sprintfOverlappingData]\n", errout_str());
     }
 
     void sprintf6() {
@@ -570,7 +567,7 @@ private:
               "    char buf[100];\n"
               "    sprintf((char*)buf,\"%s\",(char*)buf);\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:4]: (error) Undefined behavior: Variable 'buf' is used as parameter and destination in sprintf().\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:4:29]: (error) Undefined behavior: Variable 'buf' is used as parameter and destination in sprintf(). [sprintfOverlappingData]\n", errout_str());
     }
 
     void sprintf7() {
@@ -579,7 +576,7 @@ private:
               "    char buf[100];\n"
               "    sprintf((char*)(void*)buf,\"%s\",(void*)(char*)buf);\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:4]: (error) Undefined behavior: Variable 'buf' is used as parameter and destination in sprintf().\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:4:36]: (error) Undefined behavior: Variable 'buf' is used as parameter and destination in sprintf(). [sprintfOverlappingData]\n", errout_str());
     }
 
     void wsprintf1() {
@@ -588,7 +585,7 @@ private:
               "    wchar_t buf[100];\n"
               "    swprintf(buf,10, \"%s\",buf);\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:4]: (error) Undefined behavior: Variable 'buf' is used as parameter and destination in swprintf().\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:4:27]: (error) Undefined behavior: Variable 'buf' is used as parameter and destination in swprintf(). [sprintfOverlappingData]\n", errout_str());
     }
 
     void strPlusChar1() {
@@ -597,7 +594,7 @@ private:
               "{\n"
               "    const char *p = \"/usr\" + '/';\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (error) Unusual pointer arithmetic. A value of type 'char' is added to a string literal.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:28]: (error) Unusual pointer arithmetic. A value of type 'char' is added to a string literal. [strPlusChar]\n", errout_str());
     }
 
     void strPlusChar2() {
@@ -635,25 +632,25 @@ private:
               "{\n"
               "    const wchar_t *p = L\"/usr\" + L'/';\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (error) Unusual pointer arithmetic. A value of type 'wchar_t' is added to a string literal.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:32]: (error) Unusual pointer arithmetic. A value of type 'wchar_t' is added to a string literal. [strPlusChar]\n", errout_str());
 
         check("void foo(wchar_t c)\n"
               "{\n"
               "    const wchar_t *p = L\"/usr\" + c;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:3]: (error) Unusual pointer arithmetic. A value of type 'wchar_t' is added to a string literal.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:3:32]: (error) Unusual pointer arithmetic. A value of type 'wchar_t' is added to a string literal. [strPlusChar]\n", errout_str());
     }
 
     void incorrectStringCompare() {
         check("int f() {\n"
               "    return test.substr( 0 , 4 ) == \"Hello\" ? 0 : 1 ;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) String literal \"Hello\" doesn't match length argument for substr().\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:17]: (warning) String literal \"Hello\" doesn't match length argument for substr(). [incorrectStringCompare]\n", errout_str());
 
         check("int f() {\n"
               "    return test.substr( 0 , 4 ) == L\"Hello\" ? 0 : 1 ;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) String literal L\"Hello\" doesn't match length argument for substr().\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:17]: (warning) String literal L\"Hello\" doesn't match length argument for substr(). [incorrectStringCompare]\n", errout_str());
 
         check("int f() {\n"
               "    return test.substr( 0 , 5 ) == \"Hello\" ? 0 : 1 ;\n"
@@ -663,12 +660,12 @@ private:
         check("int f() {\n"
               "    return \"Hello\" == test.substr( 0 , 4 ) ? 0 : 1 ;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) String literal \"Hello\" doesn't match length argument for substr().\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:28]: (warning) String literal \"Hello\" doesn't match length argument for substr(). [incorrectStringCompare]\n", errout_str());
 
         check("int f() {\n"
               "    return \"Hello\" == foo.bar<int>().z[1].substr(i+j*4, 4) ? 0 : 1 ;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) String literal \"Hello\" doesn't match length argument for substr().\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:43]: (warning) String literal \"Hello\" doesn't match length argument for substr(). [incorrectStringCompare]\n", errout_str());
 
         check("int f() {\n"
               "    return \"Hello\" == test.substr( 0 , 5 ) ? 0 : 1 ;\n"
@@ -678,32 +675,32 @@ private:
         check("int f() {\n"
               "    if (\"Hello\") { }\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:9]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true. [incorrectStringBooleanError]\n", errout_str());
 
         check("int f() {\n"
               "    if (\"Hello\" && test) { }\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:9]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true. [incorrectStringBooleanError]\n", errout_str());
 
         check("int f() {\n"
               "    if (test && \"Hello\") { }\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:17]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true. [incorrectStringBooleanError]\n", errout_str());
 
         check("int f() {\n"
               "    while (\"Hello\") { }\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:12]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true. [incorrectStringBooleanError]\n", errout_str());
 
         check("int f() {\n"
               "    return \"Hello\" ? 1 : 2;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:12]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true. [incorrectStringBooleanError]\n", errout_str());
 
         check("int f() {\n"
               "    assert (test || \"Hello\");\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:21]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true. [incorrectStringBooleanError]\n", errout_str());
 
         check("int f() {\n"
               "    assert (test && \"Hello\");\n"
@@ -713,7 +710,7 @@ private:
         check("int f() {\n"
               "    assert (\"Hello\" || test);\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:13]: (warning) Conversion of string literal \"Hello\" to bool always evaluates to true. [incorrectStringBooleanError]\n", errout_str());
 
         check("int f() {\n"
               "    assert (\"Hello\" && test);\n"
@@ -737,33 +734,33 @@ private:
               "  if(1 && 'c'){}\n"
               "  int x = 'd' ? 1 : 2;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Conversion of char literal 'a' to bool always evaluates to true.\n"
-                      "[test.cpp:3]: (warning) Conversion of char literal L'b' to bool always evaluates to true.\n"
-                      "[test.cpp:4]: (warning) Conversion of char literal 'c' to bool always evaluates to true.\n"
-                      "[test.cpp:5]: (warning) Conversion of char literal 'd' to bool always evaluates to true.\n"
+        ASSERT_EQUALS("[test.cpp:2:6]: (warning) Conversion of char literal 'a' to bool always evaluates to true. [incorrectCharBooleanError]\n"
+                      "[test.cpp:3:6]: (warning) Conversion of char literal L'b' to bool always evaluates to true. [incorrectCharBooleanError]\n"
+                      "[test.cpp:4:11]: (warning) Conversion of char literal 'c' to bool always evaluates to true. [incorrectCharBooleanError]\n"
+                      "[test.cpp:5:11]: (warning) Conversion of char literal 'd' to bool always evaluates to true. [incorrectCharBooleanError]\n"
                       , errout_str());
 
         check("void f() {\n"
               "  if('\\0'){}\n"
               "  if(L'\\0'){}\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Conversion of char literal '\\0' to bool always evaluates to false.\n"
-                      "[test.cpp:3]: (warning) Conversion of char literal L'\\0' to bool always evaluates to false.\n",
+        ASSERT_EQUALS("[test.cpp:2:6]: (warning) Conversion of char literal '\\0' to bool always evaluates to false. [incorrectCharBooleanError]\n"
+                      "[test.cpp:3:6]: (warning) Conversion of char literal L'\\0' to bool always evaluates to false. [incorrectCharBooleanError]\n",
                       errout_str());
 
         check("void f() {\n"
               "  if('\\0' || cond){}\n"
               "  if(L'\\0' || cond){}\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) Conversion of char literal '\\0' to bool always evaluates to false.\n"
-                      "[test.cpp:3]: (warning) Conversion of char literal L'\\0' to bool always evaluates to false.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:6]: (warning) Conversion of char literal '\\0' to bool always evaluates to false. [incorrectCharBooleanError]\n"
+                      "[test.cpp:3:6]: (warning) Conversion of char literal L'\\0' to bool always evaluates to false. [incorrectCharBooleanError]\n", errout_str());
 
         check("void f(bool b);\n" // #9450
               "void f(std::string s);\n"
               "void g() {\n"
               "    f(\"abc\");\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:4]: (warning) Conversion of string literal \"abc\" to bool always evaluates to true.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:4:7]: (warning) Conversion of string literal \"abc\" to bool always evaluates to true. [incorrectStringBooleanError]\n", errout_str());
 
         check("void g(bool);\n"
               "    void f(std::map<std::string, std::vector<int>>&m) {\n"
@@ -777,8 +774,8 @@ private:
               "    g('\\0');\n"
               "    g('a');\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:3]: (warning) Conversion of char literal '\\0' to bool always evaluates to false.\n"
-                      "[test.cpp:4]: (warning) Conversion of char literal 'a' to bool always evaluates to true.\n",
+        ASSERT_EQUALS("[test.cpp:3:7]: (warning) Conversion of char literal '\\0' to bool always evaluates to false. [incorrectCharBooleanError]\n"
+                      "[test.cpp:4:7]: (warning) Conversion of char literal 'a' to bool always evaluates to true. [incorrectCharBooleanError]\n",
                       errout_str());
 
         check("#define ERROR(msg) if (msg) printf(\"%s\\n\", msg);\n"
@@ -792,7 +789,7 @@ private:
               "    MyAssert(!\"abc\");\n"
               "    g(2, !\"def\");\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:4]: (warning) Conversion of string literal \"def\" to bool always evaluates to true.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:4:11]: (warning) Conversion of string literal \"def\" to bool always evaluates to true. [incorrectStringBooleanError]\n", errout_str());
 
         check("bool f(const char *p) {\n"
               "    if (*p == '\\0')\n"
@@ -813,7 +810,7 @@ private:
               "        check(\"class A<B&, C>;\", \"test.C\");\n"
               "    }\n"
               "};\n");
-        ASSERT_EQUALS("[test.cpp:4]: (warning) Conversion of string literal \"test.C\" to bool always evaluates to true.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:4:34]: (warning) Conversion of string literal \"test.C\" to bool always evaluates to true. [incorrectStringBooleanError]\n", errout_str());
 
         check("#define MACRO(C) if(!(C)) { error(__FILE__, __LINE__, __FUNCTION__, #C); return; }\n" // #13067
               "void f() {\n"
@@ -832,12 +829,12 @@ private:
         check("void f(const char *str) {\n"
               "  if (strcmp(str, \"abc\") == 0 || strcmp(str, \"def\")) {}\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) The expression 'strcmp(str,\"def\") != 0' is suspicious. It overlaps 'strcmp(str,\"abc\") == 0'.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:40]: (warning) The expression 'strcmp(str,\"def\") != 0' is suspicious. It overlaps 'strcmp(str,\"abc\") == 0'. [overlappingStrcmp]\n", errout_str());
 
         check("void f(const wchar_t *str) {\n"
               "  if (wcscmp(str, L\"abc\") == 0 || wcscmp(str, L\"def\")) {}\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (warning) The expression 'wcscmp(str,L\"def\") != 0' is suspicious. It overlaps 'wcscmp(str,L\"abc\") == 0'.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:2:41]: (warning) The expression 'wcscmp(str,L\"def\") != 0' is suspicious. It overlaps 'wcscmp(str,L\"abc\") == 0'. [overlappingStrcmp]\n", errout_str());
 
         check("struct X {\n"
               "  char *str;\n"
@@ -846,7 +843,7 @@ private:
               "void f(const struct X *x) {\n"
               "  if (strcmp(x->str, \"abc\") == 0 || strcmp(x->str, \"def\")) {}\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:6]: (warning) The expression 'strcmp(x->str,\"def\") != 0' is suspicious. It overlaps 'strcmp(x->str,\"abc\") == 0'.\n", errout_str());
+        ASSERT_EQUALS("[test.cpp:6:43]: (warning) The expression 'strcmp(x->str,\"def\") != 0' is suspicious. It overlaps 'strcmp(x->str,\"abc\") == 0'. [overlappingStrcmp]\n", errout_str());
     }
 };
 
