@@ -52,18 +52,32 @@ private:
         ASSERT_EQUALS(true, ::isValidGlobPattern("x*"));
         ASSERT_EQUALS(true, ::isValidGlobPattern("*/x/*"));
         ASSERT_EQUALS(true, ::isValidGlobPattern("x/*/z"));
-        ASSERT_EQUALS(false, ::isValidGlobPattern("**"));
-        ASSERT_EQUALS(false, ::isValidGlobPattern("**x"));
-        ASSERT_EQUALS(false, ::isValidGlobPattern("x**"));
+        ASSERT_EQUALS(true, ::isValidGlobPattern("**"));
+        ASSERT_EQUALS(true, ::isValidGlobPattern("**x"));
+        ASSERT_EQUALS(true, ::isValidGlobPattern("x**"));
 
         ASSERT_EQUALS(true, ::isValidGlobPattern("?"));
         ASSERT_EQUALS(true, ::isValidGlobPattern("?x"));
         ASSERT_EQUALS(true, ::isValidGlobPattern("x?"));
         ASSERT_EQUALS(true, ::isValidGlobPattern("?/x/?"));
         ASSERT_EQUALS(true, ::isValidGlobPattern("x/?/z"));
-        ASSERT_EQUALS(false, ::isValidGlobPattern("??"));
-        ASSERT_EQUALS(false, ::isValidGlobPattern("??x"));
-        ASSERT_EQUALS(false, ::isValidGlobPattern("x??"));
+        ASSERT_EQUALS(true, ::isValidGlobPattern("??"));
+        ASSERT_EQUALS(true, ::isValidGlobPattern("????"));
+        ASSERT_EQUALS(true, ::isValidGlobPattern("??x"));
+        ASSERT_EQUALS(true, ::isValidGlobPattern("x??"));
+
+        ASSERT_EQUALS(true, ::isValidGlobPattern("?*"));
+        ASSERT_EQUALS(true, ::isValidGlobPattern("?**"));
+        ASSERT_EQUALS(false, ::isValidGlobPattern("?***"));
+        ASSERT_EQUALS(true, ::isValidGlobPattern("???*"));
+        ASSERT_EQUALS(true, ::isValidGlobPattern("???**"));
+        ASSERT_EQUALS(false, ::isValidGlobPattern("???***"));
+
+        ASSERT_EQUALS(false, ::isValidGlobPattern("*?"));
+        ASSERT_EQUALS(true,  ::isValidGlobPattern("*x?"));
+        ASSERT_EQUALS(false, ::isValidGlobPattern("**?"));
+        ASSERT_EQUALS(false, ::isValidGlobPattern("***"));
+        ASSERT_EQUALS(true,  ::isValidGlobPattern("**x*"));
     }
 
     void matchglob() const {
@@ -76,11 +90,26 @@ private:
         ASSERT_EQUALS(true, ::matchglob("*", "x/y/z"));
         ASSERT_EQUALS(true, ::matchglob("*/y/z", "x/y/z"));
 
+        ASSERT_EQUALS(true, ::matchglob("**", ""));
+        ASSERT_EQUALS(true, ::matchglob("**", "abcdefg"));
+        ASSERT_EQUALS(true, ::matchglob("**", "abcde/foo/bar"));
+        ASSERT_EQUALS(false, ::matchglob("*/**", "abcde"));
+        ASSERT_EQUALS(true, ::matchglob("*/**", "abcde/foo"));
+        ASSERT_EQUALS(true, ::matchglob("*/**", "abcde/foo/bar"));
+
         ASSERT_EQUALS(false, ::matchglob("?", "xyz"));
         ASSERT_EQUALS(false, ::matchglob("x?", "xyz"));
         ASSERT_EQUALS(false, ::matchglob("?z", "xyz"));
         ASSERT_EQUALS(true, ::matchglob("?y?", "xyz"));
         ASSERT_EQUALS(true, ::matchglob("?/?/?", "x/y/z"));
+
+        ASSERT_EQUALS(true, ::matchglob("??", "xy"));
+        ASSERT_EQUALS(false, ::matchglob("??", "x"));
+        ASSERT_EQUALS(false, ::matchglob("??", "xyz"));
+
+        ASSERT_EQUALS(true, ::matchglob("????", "wxyz"));
+        ASSERT_EQUALS(false, ::matchglob("????", "xyz"));
+        ASSERT_EQUALS(false, ::matchglob("????", "vwxyz"));
     }
 
     void isStringLiteral() const {
