@@ -14,9 +14,10 @@ CPPCHECK = os.path.expanduser('~/cppcheck/cppcheck')
 def run_cppcheck(cppcheck_parameters:str, clang:str):
     cmd = '{} {} {} --debug --verbose'.format(CPPCHECK, cppcheck_parameters, clang)
     #print(cmd)
-    p = subprocess.Popen(cmd.split(), stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-    comm = p.communicate()
-    return comm[0].decode('utf-8', 'ignore')
+    with subprocess.Popen(cmd.split(), stdout=subprocess.PIPE, stderr=subprocess.PIPE) as p:
+        # TODO: handle p.returncode?
+        stdout, _ = p.communicate()
+    return stdout.decode('utf-8', 'ignore')
 
 
 def get_ast(debug):
