@@ -6,11 +6,11 @@ TRACDB = 'trac.db'
 
 
 def readdb():
-    global TRACDB
     cmds = ['sqlite3', TRACDB, 'SELECT id,keywords FROM ticket WHERE status<>"closed";']
-    p = subprocess.Popen(cmds, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-    comm = p.communicate()
-    data = comm[0]
+    with subprocess.Popen(cmds, stdout=subprocess.PIPE, stderr=subprocess.PIPE) as p:
+        # TODO: handle p.returncode?
+        stdout, _ = p.communicate()
+    data = stdout
     ret = {}
     for line in data.splitlines():
         pos1 = line.find('|')
@@ -25,9 +25,9 @@ def readdb():
             ret[kw].append(nr)
     return ret
 
+
 for arg in sys.argv[1:]:
     if arg.endswith('/trac.db'):
-        global TRACDB
         TRACDB = arg
 
 data = readdb()
