@@ -1,4 +1,4 @@
-/*
+/* -*- C++ -*-
  * Cppcheck - A tool for static C/C++ code analysis
  * Copyright (C) 2007-2021 Cppcheck team.
  *
@@ -47,7 +47,7 @@ public slots:
     void loadFile();
     void loadFromClipboard();
     void filter(const QString& filter);
-    void showResult(const QListWidgetItem *item);
+    void showResult(QListWidgetItem *item);
     void refreshResults();
     void fileTreeFilter(const QString &str);
     void findInFilesClicked();
@@ -62,7 +62,7 @@ private:
     bool runProcess(const QString &programName, const QStringList & arguments);
     bool wget(const QString &url);
     bool unpackArchive(const QString &archiveName);
-    void showSrcFile(const QString &fileName, const QString &url, const int lineNumber);
+    void showSrcFile(const QString &fileName, const QString &url, int lineNumber);
 
     QStringList mAllErrors;
     QFileSystemModel mFSmodel;
